'use strict';

const utils = require('./utils-dd3b6f4c.js');

class NylasAbstractProvider {
    constructor(host, stores, automaticComponentRegistration = true, eventOverrides) {
        this.automaticComponentRegistration = true;
        this.registeredComponents = {};
        this.propStateRegistrations = new Map();
        this.eventListenerRegistrations = new Map();
        this.host = host;
        this.stores = stores;
        this.automaticComponentRegistration = automaticComponentRegistration;
        this.eventOverrides = eventOverrides;
        utils.debug(`[${this.hostTagName}] Initializing (abstract) provider.`, { eventOverrides });
        this.registerComponent = this.registerComponent.bind(this);
        this.getStore = this.getStore.bind(this);
        Object.keys(this.stores).forEach(storeName => {
            this.propStateRegistrations.set(storeName, new Map());
        });
    }
    async componentWillLoad(nylasConnector) {
        utils.debug(`[${this.hostTagName}] Will load`);
        this.setupStoreListeners();
        this.nylasConnector = nylasConnector;
        const childComponents = Array.from(this.host.querySelectorAll('*')).filter(child => child.tagName.toLowerCase().startsWith('nylas-'));
        utils.debug(`[${this.hostTagName}] Found ${childComponents.length} child component(s).`, { childComponents });
        const registrations = childComponents.map(async (child) => {
            const component = child;
            if (!component) {
                utils.debug(`[~${this.hostTagName}] (componentWillLoad) Component ${component.tagName} does not have a name. Skipping.`);
                return;
            }
            if (!component.registerNylasComponent) {
                utils.debug(`[~${this.hostTagName}] (componentWillLoad) Component ${component.tagName} is not a component that can be registered. Skipping.`, { component });
                return;
            }
            const registeredComponent = {
                element: component,
                name: component.tagName.toLowerCase(),
                getStoresToProp: component.getStoresToProp,
                storeToProps: component.storeToProps,
                stateToProps: component.stateToProps,
                authToProp: component.authToProp,
                eventToProps: component.eventToProps,
                connectorToProp: component.connectorToProp,
                localPropsToProp: component.localPropsToProp,
            };
            await this.registerComponent(registeredComponent);
        });
        await Promise.all(registrations);
    }
    async componentDidLoad() {
        utils.debug(`[~${this.hostTagName}] (componentDidLoad) Did load`);
    }
    async componentDisconnected() {
        Object.values(this.stores).forEach(store => {
            store.dispose();
        });
    }
    async registerComponentHandler(event) {
        event.stopPropagation();
        if (!this.automaticComponentRegistration) {
            utils.debug(`~[${this.hostTagName}] (registerComponentHandler) Automatic component registration disabled. Skipping registration of ${event.detail.name}.`);
            return;
        }
        await this.registerComponent(event.detail);
    }
    async unregisterComponentHandler(event) {
        event.stopPropagation();
        if (!this.automaticComponentRegistration) {
            utils.debug(`~[${this.hostTagName}] (unregisterComponentHandler) Automatic component registration disabled. Skipping unregistration of ${event.detail.name}.`);
            return;
        }
        this.unregisterComponent(event.detail);
    }
    async registerComponent(component) {
        utils.debug(`~[${this.hostTagName}] (registerComponent) Registering component ${component.name}.`);
        const elementId = component.element.dataset.nylasId;
        const isReregistration = elementId && this.registeredComponents[elementId];
        if (isReregistration) {
            utils.debug(`[${this.hostTagName}] (registerComponent) Component ${component.name} already registered. Updating registration.`);
            this.cleanupComponentRegistration(elementId, false);
        }
        else {
            component.element.dataset.nylasId = elementId || utils.uniqueID();
        }
        const nylasId = component.element.dataset.nylasId;
        if (nylasId) {
            this.registeredComponents[nylasId] = component;
        }
        utils.debug(`[${this.hostTagName}] (registerComponent) Waiting for "${component.element.localName}" component to be defined`, { component });
        try {
            await customElements.whenDefined(component.element.tagName.toLowerCase());
            utils.debug(`[${this.hostTagName}] (registerComponent) Component "${component.element.localName}" is now defined`);
        }
        catch (error) {
            utils.debug(`[${this.hostTagName}] (registerComponent) Error waiting for component "${component.element.localName}" to be defined:`, error);
        }
        const eventOverrides = this.eventOverrides;
        const { stateToProps, getStoresToProp, eventToProps, storeToProps, connectorToProp, localPropsToProp, element } = component;
        eventToProps?.forEach((customEventHandler, propKey) => {
            const nylasConnector = this.nylasConnector;
            const handler = async (event) => {
                utils.debug(`[${this.hostTagName}] (registerComponent) Handling "${component.name}" prop "${String(propKey)}" event.`, { event });
                if (propKey in eventOverrides) {
                    utils.debug(`[${this.hostTagName}] (registerComponent) Found event override for "${String(propKey)}" event. Calling override.`);
                    await eventOverrides[propKey](event, nylasConnector);
                }
                if (!event.defaultPrevented) {
                    await customEventHandler(event, nylasConnector);
                }
                return;
            };
            const elementId = component.element.dataset.nylasId;
            if (elementId && !this.eventListenerRegistrations.has(elementId)) {
                this.eventListenerRegistrations.set(elementId, []);
            }
            if (elementId) {
                this.eventListenerRegistrations.get(elementId)?.push([element, propKey, handler]);
            }
            utils.debug(`[${this.hostTagName}] (registerComponent) Setting "${component.name}" event "${String(propKey)}" to automcially call NylasConnector method.`);
            const eventName = utils.formatEventName(propKey.toString());
            utils.debug(`[${this.hostTagName}] (registerComponent) Adding event listener for "${eventName}" on "${element.tagName}"`);
            element.addEventListener(eventName, handler);
        });
        stateToProps?.forEach((propKey, stateKey) => {
            const [storeName, stateName] = stateKey.split('.');
            const store = this.getStore(storeName);
            const stateValue = store.state[stateName];
            if (!element.dataset.nylasId) {
                utils.debug(`[${this.hostTagName}] (registerComponent) Component "${component.name}" not registered. Skipping.`, { component });
                return;
            }
            if (!this.propStateRegistrations.has(storeName)) {
                this.propStateRegistrations.set(storeName, new Map());
            }
            if (!this.propStateRegistrations.get(storeName)?.has(stateName)) {
                this.propStateRegistrations.get(storeName)?.set(stateName, [
                    {
                        elementId: element.dataset.nylasId,
                        propKey,
                    },
                ]);
            }
            else {
                this.propStateRegistrations
                    .get(storeName)
                    ?.get(stateName)
                    ?.push({
                    elementId: element.dataset.nylasId,
                    propKey,
                });
            }
            element[propKey.toString()] = stateValue;
            utils.debug(`[${this.hostTagName}] Setting "${component.name}" prop "${propKey.toString()}" to "${stateKey}" value.`, { stateValue });
        });
        localPropsToProp?.forEach((propKey, value) => {
            const mappedPropValue = this.host[value];
            element[propKey.toString()] = mappedPropValue;
            utils.debug(`[${this.hostTagName}] Setting "${component.name}" prop "${propKey.toString()}" to the value of "${value}" value.`, { value, mappedPropValue });
        });
        if (getStoresToProp) {
            element[getStoresToProp?.toString()] = this.getStore;
            utils.debug(`[${this.hostTagName}] Setting "${component.name}" prop "${getStoresToProp.toString()}" to "getStore" method.`);
        }
        storeToProps?.forEach((propKey, storeKey) => {
            const store = this.getStore(storeKey);
            element[propKey.toString()] = store;
            utils.debug(`[${this.hostTagName}] Setting "${component.name}" prop "${propKey.toString()}" to "${storeKey}" store.`, { store });
        });
        if (connectorToProp) {
            element[connectorToProp?.toString()] = this.nylasConnector;
            utils.debug(`[${this.hostTagName}] Setting "${component.name}" prop "${connectorToProp.toString()}" to "nylasConnector" value.`, { connectorToProp });
        }
        if (typeof element.registerCallback === 'function') {
            utils.debug(`[${this.hostTagName}] (registerComponent) Calling registerCallback method for "${component.name}".`);
            await element.registerCallback();
        }
        utils.debug(`[${this.hostTagName}] (registerComponent) Component ${component.name} registered.`);
    }
    cleanupComponentRegistration(elementId, removeFromRegistry = true) {
        const eventListenerRegistrations = this.eventListenerRegistrations.get(elementId);
        if (eventListenerRegistrations) {
            eventListenerRegistrations.forEach(([element, propKey, handler]) => {
                const eventName = utils.formatEventName(propKey.toString());
                utils.debug(`[${this.hostTagName}] (cleanupComponentRegistration) Removing event listener for "${eventName}" on "${element.tagName}"`);
                element.removeEventListener(eventName, handler);
            });
            this.eventListenerRegistrations.delete(elementId);
        }
        this.propStateRegistrations.forEach((stateToProps, storeName) => {
            stateToProps.forEach((props, stateKey) => {
                const filteredProps = props.filter(prop => prop.elementId !== elementId);
                if (filteredProps.length !== props.length) {
                    this.propStateRegistrations.get(storeName)?.set(stateKey, filteredProps);
                }
            });
        });
        if (removeFromRegistry) {
            delete this.registeredComponents[elementId];
        }
    }
    unregisterComponent(component) {
        utils.debug(`[${this.hostTagName}] Unregistering component ${component.name}.`);
        const elementId = component.element.dataset.nylasId;
        if (!elementId) {
            utils.debug(`[${this.hostTagName}] (unregisterComponent) Unregistering component ${component.name}.`);
            return;
        }
        if (this.registeredComponents[elementId]) {
            utils.debug(`[${this.hostTagName}] (unregisterComponent) Component ${component.name} not registered. Skipping.`);
            return;
        }
        this.propStateRegistrations.forEach((stateToProps, storeName) => {
            stateToProps.forEach((_, stateKey) => {
                const props = this.propStateRegistrations.get(storeName)?.get(stateKey);
                const filteredProps = props?.filter(prop => prop.elementId !== elementId);
                if (filteredProps) {
                    this.propStateRegistrations.get(storeName)?.set(stateKey, filteredProps);
                }
            });
        });
        const eventListenerRegistrations = this.eventListenerRegistrations.get(elementId);
        eventListenerRegistrations?.forEach(([element, propKey, handler]) => {
            const eventName = utils.formatEventName(propKey.toString());
            utils.debug(`[${this.hostTagName}] (unregisterComponent) Removing event listener for "${eventName}" on "${element.tagName}"`);
            element.removeEventListener(eventName, handler);
        });
        delete this.registeredComponents[elementId];
    }
    getStore(name) {
        const store = this.stores[name];
        if (!store) {
            throw new Error(`[${this.hostTagName}] Store "${name.toString()}" not found.`);
        }
        return store;
    }
    async setupStoreListeners() {
        const self = this;
        Object.entries(this.stores).forEach(([storeName, store]) => {
            utils.debug(`[${self.hostTagName}] (setupStoreListeners) Listening for changes in "${storeName}" store.`);
            store.use({
                set(stateKey, newValue, oldValue) {
                    utils.debug(`[${self.hostTagName}] (setupStoreListeners) Store "${storeName}" state "${stateKey.toString()}" changed`, { newValue, oldValue });
                    if (newValue === oldValue) {
                        utils.debug(`[${self.hostTagName}] (setupStoreListeners) Store "${storeName}" state "${stateKey.toString()}" unchanged. Skipping.`);
                        return;
                    }
                    const registeredComponents = self.registeredComponents;
                    if (!registeredComponents) {
                        utils.debug(`[${self.hostTagName}] (setupStoreListeners) No registered components found. Skipping.`);
                        return;
                    }
                    const props = self.propStateRegistrations.get(storeName)?.get(stateKey.toString()) || [];
                    utils.debug(`[${self.hostTagName}] (setupStoreListeners) Found ${props.length} prop(s) registered for "${stateKey.toString()}" store.`, {
                        props,
                        propStateRegistrations: self.propStateRegistrations,
                    });
                    props.forEach(({ elementId, propKey }) => {
                        const component = registeredComponents[elementId];
                        if (!component) {
                            utils.debug(`[${self.hostTagName}] (setupStoreListeners) Component "${elementId}" not found. Skipping.`, { component });
                            return;
                        }
                        const loadedStore = self.getStore(storeName);
                        const stateValue = loadedStore.state[stateKey];
                        component.element[propKey.toString()] = stateValue;
                        utils.debug(`[${self.hostTagName}] (setupStoreListeners) Setting "${component.name}" prop "${propKey.toString()}" to "${stateKey.toString()}" value.`, { stateValue });
                    });
                },
            });
        });
    }
    get hostTagName() {
        return this.host?.tagName?.toLowerCase() ?? 'nylas-provider';
    }
}
class NylasBaseProvider extends NylasAbstractProvider {
}

exports.NylasBaseProvider = NylasBaseProvider;

//# sourceMappingURL=abstract-provider-ca4f7e4f.js.map