'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index$1 = require('./index-e07e3a7e.js');
const abstractProvider = require('./abstract-provider-ca4f7e4f.js');
const nylasApiRequest = require('./nylas-api-request-4d148ff1.js');
const utils = require('./utils-dd3b6f4c.js');
const index_es = require('./index.es-c563f3ba.js');
const index = require('./index-1efd27c0.js');
const constants = require('./constants-27331d2d.js');

utils.dayjs.extend(utils.utc);
utils.dayjs.extend(utils.timezone);
class NylasSchedulerConfigAPIConnector {
    constructor({ nylasApiRequest, nylasSchedulerConfigStore }) {
        this.groupEventsCache = new Map();
        this.CACHE_DURATION = 1 * 60 * 1000;
        this.nylasApiRequest = nylasApiRequest;
        this.nylasSchedulerConfigStore = nylasSchedulerConfigStore;
    }
    async currentUser() {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return null;
        }
        return this.nylasApiRequest.currentUser();
    }
    async getCalendars() {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error fetching calendars: Nylas API Request is not initialized',
            });
        }
        const allCalendars = [];
        let cursor = null;
        const limit = 50;
        do {
            const [response, error] = await this.nylasApiRequest.request({
                method: 'GET',
                path: `calendars?limit=${limit}${cursor ? `&page_token=${cursor}` : ''}`,
            });
            if (error) {
                return utils.dataResponse(null, {
                    message: 'Error fetching calendars: ' + error.message,
                });
            }
            if (index_es.Xr(response)) {
                return utils.dataResponse(null, {
                    message: 'Error fetching calendars: ' + response.error?.message,
                });
            }
            allCalendars.push(...response.data);
            cursor = response.next_cursor || null;
        } while (cursor);
        this.nylasSchedulerConfigStore.state.calendars = allCalendars;
        return utils.dataResponse(allCalendars);
    }
    async getConfigurationById(configurationId, forceFetch = false) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error fetching configuration: Nylas API Request is not initialized',
            });
        }
        if (!forceFetch) {
            const existingConfig = this.nylasSchedulerConfigStore.state.configurations.find(c => c.id === configurationId);
            if (existingConfig) {
                this.nylasSchedulerConfigStore.state.selectedConfiguration = existingConfig;
                return utils.dataResponse(existingConfig);
            }
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `scheduling/configurations/${configurationId}`,
        });
        if (error) {
            return utils.dataResponse(null, {
                message: 'Error fetching configuration: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            return utils.dataResponse(null, {
                message: 'Error fetching configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedConfiguration = response.data;
        if (this.nylasSchedulerConfigStore.state.configurations.find(c => c.id === configurationId)) {
            this.nylasSchedulerConfigStore.state.configurations = this.nylasSchedulerConfigStore.state.configurations.map(c => (c.id === configurationId ? response.data : c));
        }
        else {
            this.nylasSchedulerConfigStore.state.configurations = [...this.nylasSchedulerConfigStore.state.configurations, response.data];
        }
        return utils.dataResponse(response.data);
    }
    async getConfigurations(cursor) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error fetching configurations: Nylas API Request is not initialized',
            });
        }
        const limit = 50;
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `scheduling/configurations?limit=${limit}${cursor ? `&page_token=${cursor}` : ''}`,
        });
        if (error) {
            return utils.dataResponse(null, {
                message: 'Error fetching configurations: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            return utils.dataResponse(null, {
                message: 'Error fetching configurations: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.configurations = response.data;
        this.nylasSchedulerConfigStore.state.listConfigurationsNextCursor = response.next_cursor || null;
        return utils.dataResponse(response.data);
    }
    async getMasterEventById(masterEventId) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error fetching master event: Nylas API Request is not initialized',
            });
        }
        const selectedGroupEvent = this.nylasSchedulerConfigStore.state.selectedGroupEvent;
        const calendar_id = selectedGroupEvent?.event?.calendar_id;
        if (!calendar_id) {
            console.warn('Calendar ID is not present');
            return utils.dataResponse(null, {
                message: 'Error fetching master event: Calendar ID is not present',
            });
        }
        const queryParamsObject = new URLSearchParams();
        queryParamsObject.append('calendar_id', calendar_id);
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `events/${masterEventId}?${queryParamsObject.toString()}`,
        });
        if (error) {
            return utils.dataResponse(null, {
                message: 'Error fetching master event: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            return utils.dataResponse(null, {
                message: 'Error fetching master event: ' + response.error?.message,
            });
        }
        const masterGroupEvents = this.nylasSchedulerConfigStore.state.masterGroupEvents;
        if (masterGroupEvents[masterEventId]) {
            this.nylasSchedulerConfigStore.state.masterGroupEvents[masterEventId] = response.data;
        }
        else {
            this.nylasSchedulerConfigStore.state.masterGroupEvents = { ...masterGroupEvents, [masterEventId]: response.data };
        }
        return utils.dataResponse(response.data);
    }
    async createConfiguration(configuration) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error creating configuration: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'POST',
            path: `scheduling/configurations`,
            body: configuration,
        });
        if (error) {
            return utils.dataResponse(null, {
                message: 'Error creating configuration: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            return utils.dataResponse(null, {
                message: 'Error creating configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedConfiguration = response.data;
        this.nylasSchedulerConfigStore.state.configurations = [...this.nylasSchedulerConfigStore.state.configurations, response.data];
        return utils.dataResponse(response.data);
    }
    async updateConfiguration(configuration) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error updating configuration: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'PUT',
            path: `scheduling/configurations/${configuration.id}`,
            body: configuration,
        });
        if (error) {
            return utils.dataResponse(null, {
                message: 'Error updating configuration: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            return utils.dataResponse(null, {
                message: 'Error updating configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedConfiguration = response.data;
        if (this.nylasSchedulerConfigStore.state.configurations.find(c => c.id === configuration.id)) {
            this.nylasSchedulerConfigStore.state.configurations = this.nylasSchedulerConfigStore.state.configurations.map(c => (c.id === configuration.id ? response.data : c));
        }
        else {
            this.nylasSchedulerConfigStore.state.configurations = [...this.nylasSchedulerConfigStore.state.configurations, response.data];
        }
        return utils.dataResponse(response.data);
    }
    async deleteConfiguration(configurationId) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error deleting configuration: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'DELETE',
            path: `scheduling/configurations/${configurationId}`,
        });
        if (error) {
            return utils.dataResponse(null, {
                message: 'Error deleting configuration: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            return utils.dataResponse(null, {
                message: 'Error deleting configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.configurations = this.nylasSchedulerConfigStore.state.configurations.filter(c => c.id !== configurationId);
        if (this.nylasSchedulerConfigStore.state.selectedConfiguration?.id === configurationId) {
            this.nylasSchedulerConfigStore.resetSelectedConfiguration();
        }
        return utils.dataResponse(response.data);
    }
    async createGroupEvent(eventDetails, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error creating group event: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'POST',
            path: `scheduling/configurations/${configurationId}/group-events`,
            body: eventDetails,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error creating group event: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error creating group event: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedGroupEvent = response.data;
        await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return utils.dataResponse(response.data);
    }
    async getGroupEvents(configurationId, selectedConfiguration) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error fetching group events: Nylas API Request is not initialized',
            });
        }
        const queryParamsObject = new URLSearchParams();
        queryParamsObject.append('show_all', 'true');
        const calendarViewDateRange = this.nylasSchedulerConfigStore.state.calendarViewDateRange;
        let startTime;
        let endTime;
        if (calendarViewDateRange) {
            startTime = calendarViewDateRange.start_time;
            endTime = calendarViewDateRange.end_time;
        }
        else {
            const range = utils.getCalendarRange(new Date().toISOString(), 'week');
            startTime = range.startTime.toString();
            endTime = range.endTime.toString();
        }
        const cacheKey = `${configurationId}-${startTime}-${endTime}`;
        const cachedData = this.groupEventsCache.get(cacheKey);
        if (cachedData && Date.now() - cachedData.timestamp < this.CACHE_DURATION) {
            this.nylasSchedulerConfigStore.state.groupEvents = cachedData.data;
            return utils.dataResponse(cachedData.data);
        }
        queryParamsObject.append('start_time', startTime);
        queryParamsObject.append('end_time', endTime);
        const calendar_id = selectedConfiguration?.group_booking?.calendar_id;
        if (calendar_id) {
            queryParamsObject.append('calendar_id', calendar_id);
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `scheduling/configurations/${configurationId}/group-events?${queryParamsObject.toString()}`,
        });
        if (error) {
            return utils.dataResponse(null, {
                message: 'Error fetching group events: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            return utils.dataResponse(null, {
                message: 'Error fetching group events: ' + response.error?.message,
            });
        }
        this.groupEventsCache.set(cacheKey, {
            data: response.data,
            timestamp: Date.now(),
        });
        this.cleanupExpiredCache();
        this.nylasSchedulerConfigStore.state.groupEvents = response.data;
        return utils.dataResponse(response.data);
    }
    cleanupExpiredCache() {
        const now = Date.now();
        for (const [key, value] of this.groupEventsCache.entries()) {
            if (now - value.timestamp > this.CACHE_DURATION) {
                this.groupEventsCache.delete(key);
            }
        }
    }
    async updateGroupEventById(groupEventDetails, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error updating group event: Nylas API Request is not initialized',
            });
        }
        const groupEventId = groupEventDetails.id;
        delete groupEventDetails.id;
        const [response, error] = await this.nylasApiRequest.request({
            method: 'PATCH',
            path: `scheduling/configurations/${configurationId}/group-events/${groupEventId}`,
            body: groupEventDetails,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error updating group event: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error updating group event: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedGroupEvent = response.data;
        await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return utils.dataResponse(response.data);
    }
    async updateGroupEvent(groupEventDetails, chosenOption, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        const selectedGroupEvent = this.nylasSchedulerConfigStore.state.selectedGroupEvent;
        const masterEventId = selectedGroupEvent?.event?.master_event_id;
        const selectedGroupEventId = selectedGroupEvent?.event?.id;
        const selectedGroupEventStartTime = selectedGroupEvent?.event?.when?.start_time;
        const rruleString = selectedGroupEvent?.group_event_info?.rrule?.[0];
        const rruleStringWithoutUntil = rruleString
            ? rruleString
                .split(';')
                .filter(s => !s.startsWith('UNTIL'))
                .join(';')
            : '';
        const until = selectedGroupEventStartTime
            ? utils.dayjs(selectedGroupEventStartTime * 1000)
                .subtract(1, 'minute')
                .format('YYYYMMDDTHHmmss[Z]')
            : '';
        if (chosenOption === 'this') {
            return this.updateGroupEventById({
                ...groupEventDetails,
                id: selectedGroupEventId,
                recurrence: masterEventId ? undefined : groupEventDetails.recurrence,
            }, configurationId);
        }
        else if (chosenOption === 'future' && masterEventId) {
            const newRecurrenceEvent = await this.createGroupEvent(groupEventDetails, configurationId);
            const updatedMasterEvent = {
                location: selectedGroupEvent?.event?.location,
                conferencing: selectedGroupEvent?.event?.conferencing,
                title: selectedGroupEvent?.event?.title,
                description: selectedGroupEvent?.event?.description,
                capacity: selectedGroupEvent?.group_event_info?.capacity,
                calendar_id: selectedGroupEvent?.event?.calendar_id,
                recurrence: rruleStringWithoutUntil ? [rruleStringWithoutUntil + ';UNTIL=' + until] : [`RRULE:FREQ=DAILY;UNTIL=${until}`],
            };
            await this.updateGroupEventById({
                ...updatedMasterEvent,
                id: masterEventId,
            }, configurationId);
            return [updatedMasterEvent, newRecurrenceEvent];
        }
        else if (chosenOption === 'all') {
            const groupEventDetailsWhen = groupEventDetails?.when;
            const selectedGroupEventWhen = selectedGroupEvent?.event?.when;
            const masterEvent = this.nylasSchedulerConfigStore.state.masterGroupEvents?.[masterEventId];
            let when = masterEvent?.when;
            if (groupEventDetailsWhen?.start_time !== selectedGroupEventWhen?.start_time) {
                when = {
                    ...when,
                    start_time: groupEventDetailsWhen?.start_time || when?.start_time,
                };
            }
            if (groupEventDetailsWhen?.end_time !== selectedGroupEventWhen?.end_time) {
                when = {
                    ...when,
                    end_time: groupEventDetailsWhen?.end_time || when?.end_time,
                };
            }
            if (groupEventDetailsWhen?.start_timezone !== selectedGroupEventWhen?.start_timezone) {
                when = {
                    ...when,
                    start_timezone: groupEventDetailsWhen?.start_timezone || when?.start_timezone,
                };
            }
            if (groupEventDetailsWhen?.end_timezone !== selectedGroupEventWhen?.end_timezone) {
                when = {
                    ...when,
                    end_timezone: groupEventDetailsWhen?.end_timezone || when?.end_timezone,
                };
            }
            return this.updateGroupEventById({
                ...groupEventDetails,
                when: when,
                id: masterEventId,
            }, configurationId);
        }
        this.nylasSchedulerConfigStore.state.isLoading = false;
        throw new Error('Invalid option');
    }
    async deleteGroupEvent(_groupEventDetails, chosenOption, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        const selectedGroupEvent = this.nylasSchedulerConfigStore.state.selectedGroupEvent;
        const masterEventId = selectedGroupEvent?.event?.master_event_id;
        const selectedGroupEventId = selectedGroupEvent?.event?.id;
        const selectedGroupEventStartTime = selectedGroupEvent?.event?.when?.start_time;
        const rruleString = selectedGroupEvent?.group_event_info?.rrule?.[0];
        const rruleStringWithoutUntil = rruleString
            ? rruleString
                .split(';')
                .filter(s => !s.startsWith('UNTIL'))
                .join(';')
            : '';
        const until = selectedGroupEventStartTime ? utils.dayjs(selectedGroupEventStartTime * 1000).format('YYYYMMDDTHHmmss[Z]') : '';
        const updatedMasterEvent = {
            location: selectedGroupEvent?.event?.location,
            conferencing: selectedGroupEvent?.event?.conferencing,
            title: selectedGroupEvent?.event?.title,
            description: selectedGroupEvent?.event?.description,
            capacity: selectedGroupEvent?.group_event_info?.capacity,
            calendar_id: selectedGroupEvent?.event?.calendar_id,
            recurrence: rruleStringWithoutUntil ? [rruleStringWithoutUntil + ';UNTIL=' + until] : [`RRULE:UNTIL=${until}`],
        };
        if (chosenOption === 'this' && selectedGroupEventId) {
            return this.deleteGroupEventById(selectedGroupEventId, configurationId);
        }
        else if (chosenOption === 'future' && masterEventId && selectedGroupEventId) {
            await this.deleteGroupEventById(selectedGroupEventId, configurationId);
            return await this.updateGroupEventById({
                ...updatedMasterEvent,
                id: masterEventId,
            }, configurationId);
        }
        else if (chosenOption === 'all' && masterEventId) {
            return this.deleteGroupEventById(masterEventId, configurationId);
        }
        this.nylasSchedulerConfigStore.state.isLoading = false;
        throw new Error('Invalid option');
    }
    async deleteGroupEventById(groupEventId, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error deleting group event: Nylas API Request is not initialized',
            });
        }
        const queryParamsObject = new URLSearchParams();
        const calendar_id = this.nylasSchedulerConfigStore.state.selectedConfiguration?.group_booking?.calendar_id;
        if (calendar_id) {
            queryParamsObject.append('calendar_id', calendar_id);
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'DELETE',
            path: `scheduling/configurations/${configurationId}/group-events/${groupEventId}?calendar_id=${calendar_id}`,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error deleting group event: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error deleting group event: ' + response.error?.message,
            });
        }
        await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return utils.dataResponse(response.data);
    }
    async importGroupEvent(groupEventDetails, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return utils.dataResponse(null, {
                message: 'Error importing group event: Nylas API Request is not initialized',
            });
        }
        const queryParamsObject = new URLSearchParams();
        const calendar_id = this.nylasSchedulerConfigStore.state.selectedConfiguration?.group_booking?.calendar_id;
        if (calendar_id) {
            queryParamsObject.append('calendar_id', calendar_id);
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'POST',
            path: `scheduling/configurations/${configurationId}/import-group-events?${queryParamsObject.toString()}`,
            body: groupEventDetails,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error importing group event: ' + error.message,
            });
        }
        if (index_es.Xr(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return utils.dataResponse(null, {
                message: 'Error importing group event: ' + response.error?.message,
            });
        }
        if (response.data?.imported_events?.length > 0) {
            await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        }
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return utils.dataResponse(response.data);
    }
}

class NylasSchedulerConfigConnector {
    constructor({ nylasApiRequest, nylasSchedulerConfigStore }) {
        this.nylasApiRequest = nylasApiRequest;
        this.nylasSchedulerConfigStore = nylasSchedulerConfigStore;
    }
    init() {
        utils.debug('NylasSchedulerConfigConnector init');
    }
    get schedulerConfigStore() {
        return this.nylasSchedulerConfigStore;
    }
    get schedulerConfig() {
        if (this._schedulerConfigConnector) {
            return this._schedulerConfigConnector;
        }
        this._schedulerConfigConnector = new NylasSchedulerConfigAPIConnector({
            nylasApiRequest: this.nylasApiRequest,
            nylasSchedulerConfigStore: this.nylasSchedulerConfigStore,
        });
        return this._schedulerConfigConnector;
    }
    resetStores() {
        utils.debug('NylasSchedulerConfigConnector resetStores');
        this.nylasSchedulerConfigStore.reset();
    }
    async logout() {
        utils.debug('NylasSchedulerConfigConnector logout');
        this.resetStores();
    }
}

function CreateNylasSchedulerConfigStore(defaultState = {}) {
    const defaultSchedulerConfigState = {
        selectedConfiguration: {},
        configurations: [],
        groupEvents: [],
        listConfigurationsNextCursor: null,
        calendars: [],
        currentUser: null,
        action: null,
        additionalParticipants: [],
        requiresSlug: false,
        masterGroupEvents: {},
        isLoading: false,
        ...defaultState,
    };
    const store = index.createStore(defaultSchedulerConfigState);
    function resetSelectedConfiguration() {
        store.set('selectedConfiguration', { ...defaultState['selectedConfiguration'] });
    }
    store.onChange('action', async (action) => {
        if (!action) {
            resetSelectedConfiguration();
        }
    });
    return {
        ...store,
        resetSelectedConfiguration,
    };
}

class LocalStorage {
    get(key) {
        return new Promise((res) => {
            const record = window.localStorage.getItem(key);
            if (!record) {
                res(null);
            }
            else {
                res(JSON.parse(record));
            }
        });
    }
    async remove(key) {
        window.localStorage.removeItem(key);
        return new Promise((res) => {
            res(null);
        });
    }
    set(key, value) {
        window.localStorage.setItem(key, JSON.stringify(value));
        return new Promise((res) => {
            res(null);
        });
    }
}

const PKCE_KEY = "pkce";
const GRANT_KEY = "grant";
const USER_KEY = "user";
class Storage {
    Storage = new LocalStorage();
    constructor(store) {
        if (store) {
            this.Storage = store;
            return;
        }
    }
    setPKCE(value) {
        const encrypt = utils.Buffer.from(value);
        this.Storage.set(PKCE_KEY, encrypt.toString("base64"));
    }
    async getPKCE() {
        try {
            const pkce = await this.Storage.get(PKCE_KEY);
            if (pkce) {
                const b = utils.Buffer.from(pkce, "base64");
                return b.toString("utf8");
            }
        }
        catch (error) {
            return null;
        }
        return null;
    }
    removePKCE() {
        this.Storage.remove(PKCE_KEY);
    }
    setGrant(resp, multiAccount = false) {
        const { grant_id } = resp;
        this.Storage.set(`${GRANT_KEY}${multiAccount ? "-" + grant_id : ""}`, resp);
    }
    removeGrant(id, multiAccount = false) {
        this.Storage.remove(`${GRANT_KEY}${multiAccount ? "-" + id : ""}`);
    }
    async getGrant(id, multiAccount = false) {
        const grant = await this.Storage.get(`${GRANT_KEY}${multiAccount ? "-" + id : ""}`);
        if (grant) {
            return grant;
        }
        return null;
    }
    // setUserToken is used to store the IDToken in storage
    async setUserToken(token) {
        const userTokens = await this.getUserTokens();
        // If userTokens exist, check if the token is already in the array
        if (userTokens) {
            const userToken = userTokens.find((t) => t.sub === token.sub);
            // If the token is not in the array, add it
            if (!userToken) {
                const newTokens = [...userTokens, token];
                this.Storage.set(USER_KEY, newTokens);
            }
            else {
                // If the token is in the array, update it
                const newUserTokens = userTokens.map((t) => {
                    if (t.sub === token.sub) {
                        t = token;
                    }
                    return t;
                });
                this.Storage.set(USER_KEY, newUserTokens);
            }
        }
        else {
            // If userTokens do not exist, create a new array with the token
            this.Storage.set(USER_KEY, [token]);
        }
    }
    // getUserToken is used to retrieve a specific IDToken from storage
    async getUserToken(id = "") {
        const tokens = await this.Storage.get(USER_KEY);
        if (tokens) {
            if (id === "") {
                // If no id is passed, return the first token
                return tokens[0];
            }
            // Find the token with the matching sub
            const userToken = tokens.find((token) => token.sub === id);
            return userToken;
        }
        return null;
    }
    // getUserTokens is used to retrieve all IDTokens from storage
    async getUserTokens() {
        const tokens = await this.Storage.get(USER_KEY);
        if (tokens) {
            return tokens;
        }
        return null;
    }
    // removeUserTokens is used to remove all IDTokens from storage
    removeUserTokens() {
        this.Storage.remove(USER_KEY);
    }
    // removeUserToken is used to remove a specific IDToken from storage
    async removeUserToken(id) {
        const userTokens = await this.getUserTokens();
        // Filter out the token with the matching sub
        const tokens = userTokens?.filter((token) => token.sub !== id);
        // If there are tokens left, store them
        this.Storage.set(USER_KEY, tokens);
    }
    async clearSession() {
        const tokens = await this.getUserTokens();
        tokens?.forEach((token) => {
            this.removeGrant(token.sub);
        });
        this.removePKCE();
        this.removeUserTokens();
    }
}

class IndexedDBStorage {
    databaseName = "identity-db";
    storeName = "identity";
    get(key) {
        const self = this;
        return new Promise((resolve, reject) => {
            self.openDatabase().then(function (db) {
                const transaction = db.transaction(self.storeName, "readwrite");
                const objectStore = transaction.objectStore(self.storeName);
                const getRequest = objectStore.get(key);
                getRequest.onsuccess = () => {
                    resolve(getRequest.result);
                };
                getRequest.onerror = () => {
                    reject(getRequest.error);
                };
                transaction.oncomplete = () => {
                    db.close();
                };
            });
        });
    }
    async remove(key) {
        const self = this;
        return new Promise((resolve, reject) => {
            const request = indexedDB.open(this.databaseName);
            request.onupgradeneeded = function (event) {
                const db = event.target.result;
                db.createObjectStore(self.storeName);
            };
            request.onerror = () => {
                reject(request.error);
            };
            request.onsuccess = (event) => {
                const db = event.target.result;
                const transaction = db.transaction(this.storeName, "readwrite");
                const objectStore = transaction.objectStore(this.storeName);
                const deleteRequest = objectStore.delete(key);
                deleteRequest.onsuccess = () => {
                    resolve(null);
                };
                deleteRequest.onerror = () => {
                    reject(deleteRequest.error);
                };
                transaction.oncomplete = () => {
                    db.close();
                };
            };
        });
    }
    set(key, value) {
        return new Promise((resolve, reject) => {
            const request = indexedDB.open(this.databaseName);
            request.onerror = () => {
                reject(request.error);
            };
            request.onupgradeneeded = (event) => {
                const db = event.target.result;
                db.createObjectStore(this.storeName);
            };
            request.onsuccess = (event) => {
                const db = event.target.result;
                const transaction = db.transaction(this.storeName, "readwrite");
                const objectStore = transaction.objectStore(this.storeName);
                const setRequest = objectStore.put(value, key);
                setRequest.onsuccess = () => {
                    resolve(value);
                };
                setRequest.onerror = () => {
                    reject(setRequest.error);
                };
                transaction.oncomplete = () => {
                    db.close();
                };
            };
        });
    }
    openDatabase() {
        const self = this;
        return new Promise(function (resolve, reject) {
            const request = indexedDB.open(self.databaseName, 2);
            request.onupgradeneeded = function (event) {
                const db = event.target.result;
                db.createObjectStore(self.storeName);
            };
            request.onsuccess = function (event) {
                resolve(event.target.result);
            };
            request.onerror = function (event) {
                reject(event.error);
            };
        });
    }
}

var sha256 = {exports: {}};

(function (module) {
/*jslint bitwise: true */
(function () {

  var ERROR = 'input is invalid type';
  var WINDOW = typeof window === 'object';
  var root = WINDOW ? window : {};
  if (root.JS_SHA256_NO_WINDOW) {
    WINDOW = false;
  }
  var WEB_WORKER = !WINDOW && typeof self === 'object';
  var NODE_JS = !root.JS_SHA256_NO_NODE_JS && typeof utils.process === 'object' && utils.process.versions && utils.process.versions.node;
  if (NODE_JS) {
    root = utils.commonjsGlobal;
  } else if (WEB_WORKER) {
    root = self;
  }
  var COMMON_JS = !root.JS_SHA256_NO_COMMON_JS && 'object' === 'object' && module.exports;
  var ARRAY_BUFFER = !root.JS_SHA256_NO_ARRAY_BUFFER && typeof ArrayBuffer !== 'undefined';
  var HEX_CHARS = '0123456789abcdef'.split('');
  var EXTRA = [-2147483648, 8388608, 32768, 128];
  var SHIFT = [24, 16, 8, 0];
  var K = [
    0x428a2f98, 0x71374491, 0xb5c0fbcf, 0xe9b5dba5, 0x3956c25b, 0x59f111f1, 0x923f82a4, 0xab1c5ed5,
    0xd807aa98, 0x12835b01, 0x243185be, 0x550c7dc3, 0x72be5d74, 0x80deb1fe, 0x9bdc06a7, 0xc19bf174,
    0xe49b69c1, 0xefbe4786, 0x0fc19dc6, 0x240ca1cc, 0x2de92c6f, 0x4a7484aa, 0x5cb0a9dc, 0x76f988da,
    0x983e5152, 0xa831c66d, 0xb00327c8, 0xbf597fc7, 0xc6e00bf3, 0xd5a79147, 0x06ca6351, 0x14292967,
    0x27b70a85, 0x2e1b2138, 0x4d2c6dfc, 0x53380d13, 0x650a7354, 0x766a0abb, 0x81c2c92e, 0x92722c85,
    0xa2bfe8a1, 0xa81a664b, 0xc24b8b70, 0xc76c51a3, 0xd192e819, 0xd6990624, 0xf40e3585, 0x106aa070,
    0x19a4c116, 0x1e376c08, 0x2748774c, 0x34b0bcb5, 0x391c0cb3, 0x4ed8aa4a, 0x5b9cca4f, 0x682e6ff3,
    0x748f82ee, 0x78a5636f, 0x84c87814, 0x8cc70208, 0x90befffa, 0xa4506ceb, 0xbef9a3f7, 0xc67178f2
  ];
  var OUTPUT_TYPES = ['hex', 'array', 'digest', 'arrayBuffer'];

  var blocks = [];

  if (root.JS_SHA256_NO_NODE_JS || !Array.isArray) {
    Array.isArray = function (obj) {
      return Object.prototype.toString.call(obj) === '[object Array]';
    };
  }

  if (ARRAY_BUFFER && (root.JS_SHA256_NO_ARRAY_BUFFER_IS_VIEW || !ArrayBuffer.isView)) {
    ArrayBuffer.isView = function (obj) {
      return typeof obj === 'object' && obj.buffer && obj.buffer.constructor === ArrayBuffer;
    };
  }

  var createOutputMethod = function (outputType, is224) {
    return function (message) {
      return new Sha256(is224, true).update(message)[outputType]();
    };
  };

  var createMethod = function (is224) {
    var method = createOutputMethod('hex', is224);
    if (NODE_JS) {
      method = nodeWrap(method, is224);
    }
    method.create = function () {
      return new Sha256(is224);
    };
    method.update = function (message) {
      return method.create().update(message);
    };
    for (var i = 0; i < OUTPUT_TYPES.length; ++i) {
      var type = OUTPUT_TYPES[i];
      method[type] = createOutputMethod(type, is224);
    }
    return method;
  };

  var nodeWrap = function (method, is224) {
    var crypto = eval("require('crypto')");
    var Buffer = eval("require('buffer').Buffer");
    var algorithm = is224 ? 'sha224' : 'sha256';
    var nodeMethod = function (message) {
      if (typeof message === 'string') {
        return crypto.createHash(algorithm).update(message, 'utf8').digest('hex');
      } else {
        if (message === null || message === undefined) {
          throw new Error(ERROR);
        } else if (message.constructor === ArrayBuffer) {
          message = new Uint8Array(message);
        }
      }
      if (Array.isArray(message) || ArrayBuffer.isView(message) ||
        message.constructor === Buffer) {
        return crypto.createHash(algorithm).update(new Buffer(message)).digest('hex');
      } else {
        return method(message);
      }
    };
    return nodeMethod;
  };

  var createHmacOutputMethod = function (outputType, is224) {
    return function (key, message) {
      return new HmacSha256(key, is224, true).update(message)[outputType]();
    };
  };

  var createHmacMethod = function (is224) {
    var method = createHmacOutputMethod('hex', is224);
    method.create = function (key) {
      return new HmacSha256(key, is224);
    };
    method.update = function (key, message) {
      return method.create(key).update(message);
    };
    for (var i = 0; i < OUTPUT_TYPES.length; ++i) {
      var type = OUTPUT_TYPES[i];
      method[type] = createHmacOutputMethod(type, is224);
    }
    return method;
  };

  function Sha256(is224, sharedMemory) {
    if (sharedMemory) {
      blocks[0] = blocks[16] = blocks[1] = blocks[2] = blocks[3] =
        blocks[4] = blocks[5] = blocks[6] = blocks[7] =
        blocks[8] = blocks[9] = blocks[10] = blocks[11] =
        blocks[12] = blocks[13] = blocks[14] = blocks[15] = 0;
      this.blocks = blocks;
    } else {
      this.blocks = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
    }

    if (is224) {
      this.h0 = 0xc1059ed8;
      this.h1 = 0x367cd507;
      this.h2 = 0x3070dd17;
      this.h3 = 0xf70e5939;
      this.h4 = 0xffc00b31;
      this.h5 = 0x68581511;
      this.h6 = 0x64f98fa7;
      this.h7 = 0xbefa4fa4;
    } else { // 256
      this.h0 = 0x6a09e667;
      this.h1 = 0xbb67ae85;
      this.h2 = 0x3c6ef372;
      this.h3 = 0xa54ff53a;
      this.h4 = 0x510e527f;
      this.h5 = 0x9b05688c;
      this.h6 = 0x1f83d9ab;
      this.h7 = 0x5be0cd19;
    }

    this.block = this.start = this.bytes = this.hBytes = 0;
    this.finalized = this.hashed = false;
    this.first = true;
    this.is224 = is224;
  }

  Sha256.prototype.update = function (message) {
    if (this.finalized) {
      return;
    }
    var notString, type = typeof message;
    if (type !== 'string') {
      if (type === 'object') {
        if (message === null) {
          throw new Error(ERROR);
        } else if (ARRAY_BUFFER && message.constructor === ArrayBuffer) {
          message = new Uint8Array(message);
        } else if (!Array.isArray(message)) {
          if (!ARRAY_BUFFER || !ArrayBuffer.isView(message)) {
            throw new Error(ERROR);
          }
        }
      } else {
        throw new Error(ERROR);
      }
      notString = true;
    }
    var code, index = 0, i, length = message.length, blocks = this.blocks;

    while (index < length) {
      if (this.hashed) {
        this.hashed = false;
        blocks[0] = this.block;
        blocks[16] = blocks[1] = blocks[2] = blocks[3] =
          blocks[4] = blocks[5] = blocks[6] = blocks[7] =
          blocks[8] = blocks[9] = blocks[10] = blocks[11] =
          blocks[12] = blocks[13] = blocks[14] = blocks[15] = 0;
      }

      if (notString) {
        for (i = this.start; index < length && i < 64; ++index) {
          blocks[i >> 2] |= message[index] << SHIFT[i++ & 3];
        }
      } else {
        for (i = this.start; index < length && i < 64; ++index) {
          code = message.charCodeAt(index);
          if (code < 0x80) {
            blocks[i >> 2] |= code << SHIFT[i++ & 3];
          } else if (code < 0x800) {
            blocks[i >> 2] |= (0xc0 | (code >> 6)) << SHIFT[i++ & 3];
            blocks[i >> 2] |= (0x80 | (code & 0x3f)) << SHIFT[i++ & 3];
          } else if (code < 0xd800 || code >= 0xe000) {
            blocks[i >> 2] |= (0xe0 | (code >> 12)) << SHIFT[i++ & 3];
            blocks[i >> 2] |= (0x80 | ((code >> 6) & 0x3f)) << SHIFT[i++ & 3];
            blocks[i >> 2] |= (0x80 | (code & 0x3f)) << SHIFT[i++ & 3];
          } else {
            code = 0x10000 + (((code & 0x3ff) << 10) | (message.charCodeAt(++index) & 0x3ff));
            blocks[i >> 2] |= (0xf0 | (code >> 18)) << SHIFT[i++ & 3];
            blocks[i >> 2] |= (0x80 | ((code >> 12) & 0x3f)) << SHIFT[i++ & 3];
            blocks[i >> 2] |= (0x80 | ((code >> 6) & 0x3f)) << SHIFT[i++ & 3];
            blocks[i >> 2] |= (0x80 | (code & 0x3f)) << SHIFT[i++ & 3];
          }
        }
      }

      this.lastByteIndex = i;
      this.bytes += i - this.start;
      if (i >= 64) {
        this.block = blocks[16];
        this.start = i - 64;
        this.hash();
        this.hashed = true;
      } else {
        this.start = i;
      }
    }
    if (this.bytes > 4294967295) {
      this.hBytes += this.bytes / 4294967296 << 0;
      this.bytes = this.bytes % 4294967296;
    }
    return this;
  };

  Sha256.prototype.finalize = function () {
    if (this.finalized) {
      return;
    }
    this.finalized = true;
    var blocks = this.blocks, i = this.lastByteIndex;
    blocks[16] = this.block;
    blocks[i >> 2] |= EXTRA[i & 3];
    this.block = blocks[16];
    if (i >= 56) {
      if (!this.hashed) {
        this.hash();
      }
      blocks[0] = this.block;
      blocks[16] = blocks[1] = blocks[2] = blocks[3] =
        blocks[4] = blocks[5] = blocks[6] = blocks[7] =
        blocks[8] = blocks[9] = blocks[10] = blocks[11] =
        blocks[12] = blocks[13] = blocks[14] = blocks[15] = 0;
    }
    blocks[14] = this.hBytes << 3 | this.bytes >>> 29;
    blocks[15] = this.bytes << 3;
    this.hash();
  };

  Sha256.prototype.hash = function () {
    var a = this.h0, b = this.h1, c = this.h2, d = this.h3, e = this.h4, f = this.h5, g = this.h6,
      h = this.h7, blocks = this.blocks, j, s0, s1, maj, t1, t2, ch, ab, da, cd, bc;

    for (j = 16; j < 64; ++j) {
      // rightrotate
      t1 = blocks[j - 15];
      s0 = ((t1 >>> 7) | (t1 << 25)) ^ ((t1 >>> 18) | (t1 << 14)) ^ (t1 >>> 3);
      t1 = blocks[j - 2];
      s1 = ((t1 >>> 17) | (t1 << 15)) ^ ((t1 >>> 19) | (t1 << 13)) ^ (t1 >>> 10);
      blocks[j] = blocks[j - 16] + s0 + blocks[j - 7] + s1 << 0;
    }

    bc = b & c;
    for (j = 0; j < 64; j += 4) {
      if (this.first) {
        if (this.is224) {
          ab = 300032;
          t1 = blocks[0] - 1413257819;
          h = t1 - 150054599 << 0;
          d = t1 + 24177077 << 0;
        } else {
          ab = 704751109;
          t1 = blocks[0] - 210244248;
          h = t1 - 1521486534 << 0;
          d = t1 + 143694565 << 0;
        }
        this.first = false;
      } else {
        s0 = ((a >>> 2) | (a << 30)) ^ ((a >>> 13) | (a << 19)) ^ ((a >>> 22) | (a << 10));
        s1 = ((e >>> 6) | (e << 26)) ^ ((e >>> 11) | (e << 21)) ^ ((e >>> 25) | (e << 7));
        ab = a & b;
        maj = ab ^ (a & c) ^ bc;
        ch = (e & f) ^ (~e & g);
        t1 = h + s1 + ch + K[j] + blocks[j];
        t2 = s0 + maj;
        h = d + t1 << 0;
        d = t1 + t2 << 0;
      }
      s0 = ((d >>> 2) | (d << 30)) ^ ((d >>> 13) | (d << 19)) ^ ((d >>> 22) | (d << 10));
      s1 = ((h >>> 6) | (h << 26)) ^ ((h >>> 11) | (h << 21)) ^ ((h >>> 25) | (h << 7));
      da = d & a;
      maj = da ^ (d & b) ^ ab;
      ch = (h & e) ^ (~h & f);
      t1 = g + s1 + ch + K[j + 1] + blocks[j + 1];
      t2 = s0 + maj;
      g = c + t1 << 0;
      c = t1 + t2 << 0;
      s0 = ((c >>> 2) | (c << 30)) ^ ((c >>> 13) | (c << 19)) ^ ((c >>> 22) | (c << 10));
      s1 = ((g >>> 6) | (g << 26)) ^ ((g >>> 11) | (g << 21)) ^ ((g >>> 25) | (g << 7));
      cd = c & d;
      maj = cd ^ (c & a) ^ da;
      ch = (g & h) ^ (~g & e);
      t1 = f + s1 + ch + K[j + 2] + blocks[j + 2];
      t2 = s0 + maj;
      f = b + t1 << 0;
      b = t1 + t2 << 0;
      s0 = ((b >>> 2) | (b << 30)) ^ ((b >>> 13) | (b << 19)) ^ ((b >>> 22) | (b << 10));
      s1 = ((f >>> 6) | (f << 26)) ^ ((f >>> 11) | (f << 21)) ^ ((f >>> 25) | (f << 7));
      bc = b & c;
      maj = bc ^ (b & d) ^ cd;
      ch = (f & g) ^ (~f & h);
      t1 = e + s1 + ch + K[j + 3] + blocks[j + 3];
      t2 = s0 + maj;
      e = a + t1 << 0;
      a = t1 + t2 << 0;
    }

    this.h0 = this.h0 + a << 0;
    this.h1 = this.h1 + b << 0;
    this.h2 = this.h2 + c << 0;
    this.h3 = this.h3 + d << 0;
    this.h4 = this.h4 + e << 0;
    this.h5 = this.h5 + f << 0;
    this.h6 = this.h6 + g << 0;
    this.h7 = this.h7 + h << 0;
  };

  Sha256.prototype.hex = function () {
    this.finalize();

    var h0 = this.h0, h1 = this.h1, h2 = this.h2, h3 = this.h3, h4 = this.h4, h5 = this.h5,
      h6 = this.h6, h7 = this.h7;

    var hex = HEX_CHARS[(h0 >> 28) & 0x0F] + HEX_CHARS[(h0 >> 24) & 0x0F] +
      HEX_CHARS[(h0 >> 20) & 0x0F] + HEX_CHARS[(h0 >> 16) & 0x0F] +
      HEX_CHARS[(h0 >> 12) & 0x0F] + HEX_CHARS[(h0 >> 8) & 0x0F] +
      HEX_CHARS[(h0 >> 4) & 0x0F] + HEX_CHARS[h0 & 0x0F] +
      HEX_CHARS[(h1 >> 28) & 0x0F] + HEX_CHARS[(h1 >> 24) & 0x0F] +
      HEX_CHARS[(h1 >> 20) & 0x0F] + HEX_CHARS[(h1 >> 16) & 0x0F] +
      HEX_CHARS[(h1 >> 12) & 0x0F] + HEX_CHARS[(h1 >> 8) & 0x0F] +
      HEX_CHARS[(h1 >> 4) & 0x0F] + HEX_CHARS[h1 & 0x0F] +
      HEX_CHARS[(h2 >> 28) & 0x0F] + HEX_CHARS[(h2 >> 24) & 0x0F] +
      HEX_CHARS[(h2 >> 20) & 0x0F] + HEX_CHARS[(h2 >> 16) & 0x0F] +
      HEX_CHARS[(h2 >> 12) & 0x0F] + HEX_CHARS[(h2 >> 8) & 0x0F] +
      HEX_CHARS[(h2 >> 4) & 0x0F] + HEX_CHARS[h2 & 0x0F] +
      HEX_CHARS[(h3 >> 28) & 0x0F] + HEX_CHARS[(h3 >> 24) & 0x0F] +
      HEX_CHARS[(h3 >> 20) & 0x0F] + HEX_CHARS[(h3 >> 16) & 0x0F] +
      HEX_CHARS[(h3 >> 12) & 0x0F] + HEX_CHARS[(h3 >> 8) & 0x0F] +
      HEX_CHARS[(h3 >> 4) & 0x0F] + HEX_CHARS[h3 & 0x0F] +
      HEX_CHARS[(h4 >> 28) & 0x0F] + HEX_CHARS[(h4 >> 24) & 0x0F] +
      HEX_CHARS[(h4 >> 20) & 0x0F] + HEX_CHARS[(h4 >> 16) & 0x0F] +
      HEX_CHARS[(h4 >> 12) & 0x0F] + HEX_CHARS[(h4 >> 8) & 0x0F] +
      HEX_CHARS[(h4 >> 4) & 0x0F] + HEX_CHARS[h4 & 0x0F] +
      HEX_CHARS[(h5 >> 28) & 0x0F] + HEX_CHARS[(h5 >> 24) & 0x0F] +
      HEX_CHARS[(h5 >> 20) & 0x0F] + HEX_CHARS[(h5 >> 16) & 0x0F] +
      HEX_CHARS[(h5 >> 12) & 0x0F] + HEX_CHARS[(h5 >> 8) & 0x0F] +
      HEX_CHARS[(h5 >> 4) & 0x0F] + HEX_CHARS[h5 & 0x0F] +
      HEX_CHARS[(h6 >> 28) & 0x0F] + HEX_CHARS[(h6 >> 24) & 0x0F] +
      HEX_CHARS[(h6 >> 20) & 0x0F] + HEX_CHARS[(h6 >> 16) & 0x0F] +
      HEX_CHARS[(h6 >> 12) & 0x0F] + HEX_CHARS[(h6 >> 8) & 0x0F] +
      HEX_CHARS[(h6 >> 4) & 0x0F] + HEX_CHARS[h6 & 0x0F];
    if (!this.is224) {
      hex += HEX_CHARS[(h7 >> 28) & 0x0F] + HEX_CHARS[(h7 >> 24) & 0x0F] +
        HEX_CHARS[(h7 >> 20) & 0x0F] + HEX_CHARS[(h7 >> 16) & 0x0F] +
        HEX_CHARS[(h7 >> 12) & 0x0F] + HEX_CHARS[(h7 >> 8) & 0x0F] +
        HEX_CHARS[(h7 >> 4) & 0x0F] + HEX_CHARS[h7 & 0x0F];
    }
    return hex;
  };

  Sha256.prototype.toString = Sha256.prototype.hex;

  Sha256.prototype.digest = function () {
    this.finalize();

    var h0 = this.h0, h1 = this.h1, h2 = this.h2, h3 = this.h3, h4 = this.h4, h5 = this.h5,
      h6 = this.h6, h7 = this.h7;

    var arr = [
      (h0 >> 24) & 0xFF, (h0 >> 16) & 0xFF, (h0 >> 8) & 0xFF, h0 & 0xFF,
      (h1 >> 24) & 0xFF, (h1 >> 16) & 0xFF, (h1 >> 8) & 0xFF, h1 & 0xFF,
      (h2 >> 24) & 0xFF, (h2 >> 16) & 0xFF, (h2 >> 8) & 0xFF, h2 & 0xFF,
      (h3 >> 24) & 0xFF, (h3 >> 16) & 0xFF, (h3 >> 8) & 0xFF, h3 & 0xFF,
      (h4 >> 24) & 0xFF, (h4 >> 16) & 0xFF, (h4 >> 8) & 0xFF, h4 & 0xFF,
      (h5 >> 24) & 0xFF, (h5 >> 16) & 0xFF, (h5 >> 8) & 0xFF, h5 & 0xFF,
      (h6 >> 24) & 0xFF, (h6 >> 16) & 0xFF, (h6 >> 8) & 0xFF, h6 & 0xFF
    ];
    if (!this.is224) {
      arr.push((h7 >> 24) & 0xFF, (h7 >> 16) & 0xFF, (h7 >> 8) & 0xFF, h7 & 0xFF);
    }
    return arr;
  };

  Sha256.prototype.array = Sha256.prototype.digest;

  Sha256.prototype.arrayBuffer = function () {
    this.finalize();

    var buffer = new ArrayBuffer(this.is224 ? 28 : 32);
    var dataView = new DataView(buffer);
    dataView.setUint32(0, this.h0);
    dataView.setUint32(4, this.h1);
    dataView.setUint32(8, this.h2);
    dataView.setUint32(12, this.h3);
    dataView.setUint32(16, this.h4);
    dataView.setUint32(20, this.h5);
    dataView.setUint32(24, this.h6);
    if (!this.is224) {
      dataView.setUint32(28, this.h7);
    }
    return buffer;
  };

  function HmacSha256(key, is224, sharedMemory) {
    var i, type = typeof key;
    if (type === 'string') {
      var bytes = [], length = key.length, index = 0, code;
      for (i = 0; i < length; ++i) {
        code = key.charCodeAt(i);
        if (code < 0x80) {
          bytes[index++] = code;
        } else if (code < 0x800) {
          bytes[index++] = (0xc0 | (code >> 6));
          bytes[index++] = (0x80 | (code & 0x3f));
        } else if (code < 0xd800 || code >= 0xe000) {
          bytes[index++] = (0xe0 | (code >> 12));
          bytes[index++] = (0x80 | ((code >> 6) & 0x3f));
          bytes[index++] = (0x80 | (code & 0x3f));
        } else {
          code = 0x10000 + (((code & 0x3ff) << 10) | (key.charCodeAt(++i) & 0x3ff));
          bytes[index++] = (0xf0 | (code >> 18));
          bytes[index++] = (0x80 | ((code >> 12) & 0x3f));
          bytes[index++] = (0x80 | ((code >> 6) & 0x3f));
          bytes[index++] = (0x80 | (code & 0x3f));
        }
      }
      key = bytes;
    } else {
      if (type === 'object') {
        if (key === null) {
          throw new Error(ERROR);
        } else if (ARRAY_BUFFER && key.constructor === ArrayBuffer) {
          key = new Uint8Array(key);
        } else if (!Array.isArray(key)) {
          if (!ARRAY_BUFFER || !ArrayBuffer.isView(key)) {
            throw new Error(ERROR);
          }
        }
      } else {
        throw new Error(ERROR);
      }
    }

    if (key.length > 64) {
      key = (new Sha256(is224, true)).update(key).array();
    }

    var oKeyPad = [], iKeyPad = [];
    for (i = 0; i < 64; ++i) {
      var b = key[i] || 0;
      oKeyPad[i] = 0x5c ^ b;
      iKeyPad[i] = 0x36 ^ b;
    }

    Sha256.call(this, is224, sharedMemory);

    this.update(iKeyPad);
    this.oKeyPad = oKeyPad;
    this.inner = true;
    this.sharedMemory = sharedMemory;
  }
  HmacSha256.prototype = new Sha256();

  HmacSha256.prototype.finalize = function () {
    Sha256.prototype.finalize.call(this);
    if (this.inner) {
      this.inner = false;
      var innerHash = this.array();
      Sha256.call(this, this.is224, this.sharedMemory);
      this.update(this.oKeyPad);
      this.update(innerHash);
      Sha256.prototype.finalize.call(this);
    }
  };

  var exports = createMethod();
  exports.sha256 = exports;
  exports.sha224 = createMethod(true);
  exports.sha256.hmac = createHmacMethod();
  exports.sha224.hmac = createHmacMethod(true);

  if (COMMON_JS) {
    module.exports = exports;
  } else {
    root.sha256 = exports.sha256;
    root.sha224 = exports.sha224;
  }
})();
}(sha256));

// Unique ID creation requires a high quality random # generator. In the browser we therefore
// require the crypto API and do not support built-in fallback to lower quality random number
// generators (like Math.random()).
var getRandomValues;
var rnds8 = new Uint8Array(16);
function rng() {
  // lazy load so that environments that need to polyfill have a chance to do so
  if (!getRandomValues) {
    // getRandomValues needs to be invoked in a context where "this" is a Crypto implementation. Also,
    // find the complete implementation of crypto (msCrypto) on IE11.
    getRandomValues = typeof crypto !== 'undefined' && crypto.getRandomValues && crypto.getRandomValues.bind(crypto) || typeof msCrypto !== 'undefined' && typeof msCrypto.getRandomValues === 'function' && msCrypto.getRandomValues.bind(msCrypto);

    if (!getRandomValues) {
      throw new Error('crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported');
    }
  }

  return getRandomValues(rnds8);
}

const REGEX = /^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000)$/i;

function validate(uuid) {
  return typeof uuid === 'string' && REGEX.test(uuid);
}

/**
 * Convert array of 16 byte values to UUID string format of the form:
 * XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX
 */

var byteToHex = [];

for (var i = 0; i < 256; ++i) {
  byteToHex.push((i + 0x100).toString(16).substr(1));
}

function stringify(arr) {
  var offset = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  // Note: Be careful editing this code!  It's been tuned for performance
  // and works in ways you may not expect. See https://github.com/uuidjs/uuid/pull/434
  var uuid = (byteToHex[arr[offset + 0]] + byteToHex[arr[offset + 1]] + byteToHex[arr[offset + 2]] + byteToHex[arr[offset + 3]] + '-' + byteToHex[arr[offset + 4]] + byteToHex[arr[offset + 5]] + '-' + byteToHex[arr[offset + 6]] + byteToHex[arr[offset + 7]] + '-' + byteToHex[arr[offset + 8]] + byteToHex[arr[offset + 9]] + '-' + byteToHex[arr[offset + 10]] + byteToHex[arr[offset + 11]] + byteToHex[arr[offset + 12]] + byteToHex[arr[offset + 13]] + byteToHex[arr[offset + 14]] + byteToHex[arr[offset + 15]]).toLowerCase(); // Consistency check for valid UUID.  If this throws, it's likely due to one
  // of the following:
  // - One or more input array values don't map to a hex octet (leading to
  // "undefined" in the uuid)
  // - Invalid input values for the RFC `version` or `variant` fields

  if (!validate(uuid)) {
    throw TypeError('Stringified UUID is invalid');
  }

  return uuid;
}

function v4(options, buf, offset) {
  options = options || {};
  var rnds = options.random || (options.rng || rng)(); // Per 4.4, set bits for version and `clock_seq_hi_and_reserved`

  rnds[6] = rnds[6] & 0x0f | 0x40;
  rnds[8] = rnds[8] & 0x3f | 0x80; // Copy bytes to buffer, if provided

  if (buf) {
    offset = offset || 0;

    for (var i = 0; i < 16; ++i) {
      buf[offset + i] = rnds[i];
    }

    return buf;
  }

  return stringify(rnds);
}

async function getBytes(stream, onChunk) {
    const reader = stream.getReader();
    let result;
    while (!(result = await reader.read()).done) {
        onChunk(result.value);
    }
}
function getLines(onLine) {
    let buffer;
    let position;
    let fieldLength;
    let discardTrailingNewline = false;
    return function onChunk(arr) {
        if (buffer === undefined) {
            buffer = arr;
            position = 0;
            fieldLength = -1;
        }
        else {
            buffer = concat(buffer, arr);
        }
        const bufLength = buffer.length;
        let lineStart = 0;
        while (position < bufLength) {
            if (discardTrailingNewline) {
                if (buffer[position] === 10) {
                    lineStart = ++position;
                }
                discardTrailingNewline = false;
            }
            let lineEnd = -1;
            for (; position < bufLength && lineEnd === -1; ++position) {
                switch (buffer[position]) {
                    case 58:
                        if (fieldLength === -1) {
                            fieldLength = position - lineStart;
                        }
                        break;
                    case 13:
                        discardTrailingNewline = true;
                    case 10:
                        lineEnd = position;
                        break;
                }
            }
            if (lineEnd === -1) {
                break;
            }
            onLine(buffer.subarray(lineStart, lineEnd), fieldLength);
            lineStart = position;
            fieldLength = -1;
        }
        if (lineStart === bufLength) {
            buffer = undefined;
        }
        else if (lineStart !== 0) {
            buffer = buffer.subarray(lineStart);
            position -= lineStart;
        }
    };
}
function getMessages(onId, onRetry, onMessage) {
    let message = newMessage();
    const decoder = new TextDecoder();
    return function onLine(line, fieldLength) {
        if (line.length === 0) {
            onMessage === null || onMessage === void 0 ? void 0 : onMessage(message);
            message = newMessage();
        }
        else if (fieldLength > 0) {
            const field = decoder.decode(line.subarray(0, fieldLength));
            const valueOffset = fieldLength + (line[fieldLength + 1] === 32 ? 2 : 1);
            const value = decoder.decode(line.subarray(valueOffset));
            switch (field) {
                case 'data':
                    message.data = message.data
                        ? message.data + '\n' + value
                        : value;
                    break;
                case 'event':
                    message.event = value;
                    break;
                case 'id':
                    onId(message.id = value);
                    break;
                case 'retry':
                    const retry = parseInt(value, 10);
                    if (!isNaN(retry)) {
                        onRetry(message.retry = retry);
                    }
                    break;
            }
        }
    };
}
function concat(a, b) {
    const res = new Uint8Array(a.length + b.length);
    res.set(a);
    res.set(b, a.length);
    return res;
}
function newMessage() {
    return {
        data: '',
        event: '',
        id: '',
        retry: undefined,
    };
}

var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
const EventStreamContentType = 'text/event-stream';
const DefaultRetryInterval = 1000;
const LastEventId = 'last-event-id';
function fetchEventSource(input, _a) {
    var { signal: inputSignal, headers: inputHeaders, onopen: inputOnOpen, onmessage, onclose, onerror, openWhenHidden, fetch: inputFetch } = _a, rest = __rest(_a, ["signal", "headers", "onopen", "onmessage", "onclose", "onerror", "openWhenHidden", "fetch"]);
    return new Promise((resolve, reject) => {
        const headers = Object.assign({}, inputHeaders);
        if (!headers.accept) {
            headers.accept = EventStreamContentType;
        }
        let curRequestController;
        function onVisibilityChange() {
            curRequestController.abort();
            if (!document.hidden) {
                create();
            }
        }
        if (!openWhenHidden) {
            document.addEventListener('visibilitychange', onVisibilityChange);
        }
        let retryInterval = DefaultRetryInterval;
        let retryTimer = 0;
        function dispose() {
            document.removeEventListener('visibilitychange', onVisibilityChange);
            window.clearTimeout(retryTimer);
            curRequestController.abort();
        }
        inputSignal === null || inputSignal === void 0 ? void 0 : inputSignal.addEventListener('abort', () => {
            dispose();
            resolve();
        });
        const fetch = inputFetch !== null && inputFetch !== void 0 ? inputFetch : window.fetch;
        const onopen = inputOnOpen !== null && inputOnOpen !== void 0 ? inputOnOpen : defaultOnOpen;
        async function create() {
            var _a;
            curRequestController = new AbortController();
            try {
                const response = await fetch(input, Object.assign(Object.assign({}, rest), { headers, signal: curRequestController.signal }));
                await onopen(response);
                await getBytes(response.body, getLines(getMessages(id => {
                    if (id) {
                        headers[LastEventId] = id;
                    }
                    else {
                        delete headers[LastEventId];
                    }
                }, retry => {
                    retryInterval = retry;
                }, onmessage)));
                onclose === null || onclose === void 0 ? void 0 : onclose();
                dispose();
                resolve();
            }
            catch (err) {
                if (!curRequestController.signal.aborted) {
                    try {
                        const interval = (_a = onerror === null || onerror === void 0 ? void 0 : onerror(err)) !== null && _a !== void 0 ? _a : retryInterval;
                        window.clearTimeout(retryTimer);
                        retryTimer = window.setTimeout(create, interval);
                    }
                    catch (innerErr) {
                        dispose();
                        reject(innerErr);
                    }
                }
            }
        }
        create();
    });
}
function defaultOnOpen(response) {
    const contentType = response.headers.get('content-type');
    if (!(contentType === null || contentType === void 0 ? void 0 : contentType.startsWith(EventStreamContentType))) {
        throw new Error(`Expected content-type to be ${EventStreamContentType}, Actual: ${contentType}`);
    }
}

function Base64EncodeUrl(str) {
    return str.replace(/\+/g, "-").replace(/\//g, "_").replace(/=+$/, "");
}
function getTimestamp() {
    return Math.floor(Date.now() / 1000);
}

function e(e){this.message=e;}e.prototype=new Error,e.prototype.name="InvalidCharacterError";var r$1="undefined"!=typeof window&&window.atob&&window.atob.bind(window)||function(r){var t=String(r).replace(/=+$/,"");if(t.length%4==1)throw new e("'atob' failed: The string to be decoded is not correctly encoded.");for(var n,o,a=0,i=0,c="";o=t.charAt(i++);~o&&(n=a%4?64*n+o:o,a++%4)?c+=String.fromCharCode(255&n>>(-2*a&6)):0)o="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".indexOf(o);return c};function t$1(e){var t=e.replace(/-/g,"+").replace(/_/g,"/");switch(t.length%4){case 0:break;case 2:t+="==";break;case 3:t+="=";break;default:throw "Illegal base64url string!"}try{return function(e){return decodeURIComponent(r$1(e).replace(/(.)/g,(function(e,r){var t=r.charCodeAt(0).toString(16).toUpperCase();return t.length<2&&(t="0"+t),"%"+t})))}(t)}catch(e){return r$1(t)}}function n$1(e){this.message=e;}function o(e,r){if("string"!=typeof e)throw new n$1("Invalid token specified");var o=!0===(r=r||{}).header?0:1;try{return JSON.parse(t$1(e.split(".")[o]))}catch(e){throw new n$1("Invalid token specified: "+e.message)}}n$1.prototype=new Error,n$1.prototype.name="InvalidTokenError";

class NylasSessions {
    clientId;
    redirectUri;
    accessType = "online";
    domain = "http://api.nylas.com";
    versioned = false;
    Storage;
    hosted = false;
    multiAccount = false;
    loginId = "";
    constructor(config) {
        this.clientId = config.clientId;
        this.redirectUri = config.redirectUri;
        if (config.domain) {
            this.domain = config.domain;
            const versionedPart = this.domain.substring(this.domain.length - 3);
            if (versionedPart.includes("/v")) {
                this.versioned = true;
            }
        }
        if (config.multiAccount) {
            this.multiAccount = config.multiAccount;
        }
        if (config.sw) {
            const storage = new IndexedDBStorage();
            this.Storage = new Storage(storage);
        }
        else {
            this.Storage = new Storage();
        }
        if (config.accessType) {
            this.accessType = config.accessType;
        }
        if (config.loginId) {
            this.loginId = config.loginId;
        }
        if (config.hosted) {
            this.hosted = config.hosted;
        }
        if (config.disableInitCodeExchange !== true) {
            this.codeExchange(null);
        }
        // check();
        // registerServiceWorker();
    }
    // Validates access token
    async validateAccessToken(grant_id = "") {
        const grant = await this.Storage.getGrant(grant_id, this.multiAccount);
        if (!grant) {
            return false;
        }
        const { access_token } = grant;
        try {
            const response = await fetch(`${this.domain}/connect/tokeninfo?access_token=${access_token}`, {
                method: "GET",
            });
            const responseData = await response.json();
            if (!responseData.data) {
                return false;
            }
            return true;
        }
        catch (error) {
            return false;
        }
    }
    // Validates id token
    async validateIDToken(grant_id = "") {
        const grant = await this.Storage.getGrant(grant_id, this.multiAccount);
        if (!grant) {
            return false;
        }
        const { id_token } = grant;
        try {
            const response = await fetch(`${this.domain}/connect/tokeninfo?id_token=${id_token}`, {
                method: "GET",
            });
            if (response.status !== 200) {
                return false;
            }
            const responseData = await response.json();
            if (!responseData.data) {
                return false;
            }
            return true;
        }
        catch (error) {
            return false;
        }
    }
    // Gets domain of UAS
    getDomain() {
        return this.domain;
    }
    // Gets auth link
    async auth(config) {
        if (this.hosted &&
            (this.domain === window.location.origin ||
                (this.versioned && this.domain.includes(window.location.origin)))) {
            await this.hostedSetCodeChallenge();
        }
        const url = await this.generateAuthURL(config);
        if (config.popup) {
            this.popUp(url);
            return;
        }
        return url;
    }
    // Generates auth URL
    async generateAuthURL(config) {
        const codeChallenge = await this.getCodeChallege();
        let url = `${this.domain}/connect/auth?client_id=${this.clientId}&redirect_uri=${this.redirectUri}&access_type=${this.accessType}&response_type=code`;
        if (codeChallenge) {
            url += `&code_challenge=${codeChallenge}&code_challenge_method=S256&options=rotate_refresh_token`;
        }
        if (config.provider) {
            url += `&provider=${config.provider}`;
        }
        if (config.loginHint) {
            url += `&login_hint=${config.loginHint}`;
            if (config.includeGrantScopes) {
                url += `&include_grant_scopes=${config.includeGrantScopes}`;
            }
        }
        if (config.scope) {
            url += `&scope=${config.scope.join(" ")}`;
        }
        if (config.prompt) {
            url += `&prompt=${config.prompt}`;
        }
        if (config.metadata) {
            url += `&metadata=${config.metadata}`;
        }
        if (config.state || this.loginId) {
            url += `&state=${this.loginId ? this.loginId : config.state}`;
        }
        return url;
    }
    // Generates auth URL
    async generateReauthURL(grant_id, scopes) {
        if (!grant_id) {
            throw new Error("Grant ID is required");
        }
        const userToken = await this.Storage.getUserToken(grant_id);
        const codeChallenge = await this.getCodeChallege();
        let url = `${this.domain}/connect/auth?client_id=${this.clientId}&redirect_uri=${this.redirectUri}&access_type=${this.accessType}&response_type=code`;
        if (codeChallenge) {
            url += `&code_challenge=${codeChallenge}&code_challenge_method=S256&options=rotate_refresh_token`;
        }
        if (userToken?.provider) {
            url += `&provider=${userToken.provider}`;
        }
        if (userToken?.email) {
            url += `&login_hint=${userToken.email}`;
        }
        if (scopes) {
            url += `&scope=${scopes.join(" ")}`;
        }
        return url;
    }
    // Generates UUID code challenge
    async generateCodeChallenge() {
        const code_verifier = await this.Storage.getPKCE();
        if (code_verifier) {
            return;
        }
        const codeChallenge = v4();
        this.Storage.setPKCE(codeChallenge);
        return;
    }
    // Gets code challenge from URL query params
    async hostedSetCodeChallenge() {
        if (!this.hosted) {
            throw console.error("Method only used with hosted flag enabled");
        }
        const params = new URLSearchParams(window.location.search);
        const codeChallenge = params.get("code_challenge");
        if (!codeChallenge) {
            const code_verifier = await this.Storage.getPKCE();
            if (code_verifier) {
                return;
            }
            console.warn("Code challenge is recomended");
            return;
        }
        this.Storage.setPKCE(codeChallenge);
    }
    // Gets code challenge from store
    async getCodeChallege() {
        if (this.hosted &&
            (this.domain === window.location.origin ||
                (this.versioned && this.domain.includes(window.location.origin)))) {
            const params = new URLSearchParams(window.location.search);
            const codeChallenge = params.get("code_challenge");
            if (!codeChallenge) {
                console.warn("Code challenge is recomended");
                return "";
            }
            return codeChallenge;
        }
        const code_verifier = await this.Storage.getPKCE();
        if (code_verifier) {
            const codeChallengeHashed = sha256.exports.sha256(code_verifier);
            let codeChallengeEncrypted = utils.Buffer.from(codeChallengeHashed).toString("base64");
            codeChallengeEncrypted = Base64EncodeUrl(codeChallengeEncrypted);
            return codeChallengeEncrypted;
        }
        return "";
    }
    // checks if user is logged in
    async isLoggedIn() {
        // if hosted identity isLoggedIn always returns false
        if (this.hosted &&
            (this.domain === window.location.origin ||
                (this.versioned && this.domain.includes(window.location.origin)))) {
            return false;
        }
        const tokens = await this.Storage.getUserTokens();
        if (tokens && tokens.length > 0) {
            if (this.multiAccount) {
                await this.generateCodeChallenge();
            }
            return true;
        }
        await this.generateCodeChallenge();
        return false;
    }
    // Checks if user is multi account
    isMultiAccount() {
        return this.multiAccount;
    }
    // Logs user out
    async logout() {
        const profile = await this.getProfile();
        await this.Storage.clearSession();
        const payload = { detail: profile };
        window.dispatchEvent(new CustomEvent("onLogoutSuccess", payload));
    }
    // Gets profile info from ID token
    async getProfile(grant_id = "") {
        let tok;
        if (grant_id) {
            tok = await this.Storage.getUserToken(grant_id);
        }
        else {
            tok = await this.Storage.getUserToken();
        }
        if (tok) {
            return tok;
        }
        return null;
    }
    // Gets profile info from ID tokens
    async getProfiles() {
        const tok = await this.Storage.getUserTokens();
        if (tok) {
            return tok;
        }
        return null;
    }
    // Remove a specific profile
    async removeProfile(id) {
        await this.Storage.removeUserToken(id);
        await this.Storage.removeGrant(id);
        return null;
    }
    // IMAP authentication
    async authIMAP(data) {
        const code_challenge = await this.getCodeChallege();
        const payload = {
            imap_username: data.imap_username,
            imap_password: data.imap_password,
            imap_host: data.imap_host,
            imap_port: data.imap_port,
            type: data.type,
            smtp_host: data.smtp_host,
            smtp_port: data.smtp_port,
            provider: data.provider,
            redirect_uri: this.redirectUri,
            state: data.state,
            public_application_id: this.clientId,
            access_type: this.accessType,
        };
        if (this.loginId) {
            payload.id = this.loginId;
        }
        if (data.smtp_username && data.smtp_password) {
            payload.smtp_username = data.smtp_username;
            payload.smtp_password = data.smtp_password;
        }
        if (code_challenge != "") {
            payload.code_challenge = code_challenge;
            payload.code_challenge_method = "S256";
        }
        const response = await fetch(`${this.domain}/connect/login/imap`, {
            method: "POST",
            headers: new Headers({ "content-type": "application/json" }),
            body: JSON.stringify(payload),
        });
        const responseData = await response.json();
        return responseData;
    }
    // EWS authentication
    async authEWS(data) {
        const code_challenge = await this.getCodeChallege();
        const payload = {
            ...data,
            provider: "ews",
            redirect_uri: this.redirectUri,
            public_application_id: this.clientId,
            access_type: this.accessType,
        };
        if (this.loginId) {
            payload.id = this.loginId;
        }
        if (code_challenge != "") {
            payload.code_challenge = code_challenge;
            payload.code_challenge_method = "S256";
        }
        const response = await fetch(`${this.domain}/connect/login/ews`, {
            method: "POST",
            headers: new Headers({ "content-type": "application/json" }),
            body: JSON.stringify(payload),
        });
        const responseData = await response.json();
        return responseData;
    }
    // Detects email
    async detectEmail(email) {
        const response = await fetch(`${this.versioned ? this.domain : this.domain + "/connect"}/providers/detect?client_id=${this.clientId}&email=${email}`, {
            method: "POST",
            headers: new Headers({ "content-type": "application/json" }),
        });
        const responseData = await response.json();
        return responseData;
    }
    // Gets app info from UAS
    async applicationInfo() {
        const response = await fetch(`${this.versioned ? this.domain : this.domain + "/connect"}/applications?client_id=${this.clientId}`, {
            method: "GET",
            headers: new Headers({ "content-type": "application/json" }),
        });
        const responseData = await response.json();
        return responseData.data;
    }
    // Gets providers form UAS
    async getAvailableProviders() {
        const response = await fetch(`${this.domain}/connect/providers/find?client_id=${this.clientId}`, {
            method: "GET",
            headers: new Headers({ "content-type": "application/json" }),
        });
        if (response) {
            const responseData = await response.json();
            const providers = responseData.data;
            return providers;
        }
        return null;
    }
    // EVENT HOOKS
    onLoginSuccess(callback) {
        window.addEventListener("onLoginSuccess", (e) => callback(e));
    }
    onLogoutSuccess(callback) {
        window.addEventListener("onLogoutSuccess", (e) => callback(e));
    }
    onLoginFail(callback) {
        window.addEventListener("onLoginFail", (e) => callback(e));
    }
    onTokenRefreshSuccess(callback) {
        window.addEventListener("onTokenRefreshSuccess", (e) => callback(e));
    }
    onTokenRefreshFail(callback) {
        window.addEventListener("onTokenRefreshFail", (e) => callback(e));
    }
    onSessionExpired(callback) {
        window.addEventListener("onSessionExpired", (e) => callback(e));
    }
    // Exchanges code for ID token and refresh and access tokens
    async codeExchange(search) {
        let params = new URLSearchParams(window.location.search);
        if (search) {
            params = new URLSearchParams(search);
        }
        const code = params.get("code");
        const state = params.get("state");
        const error = params.get("error");
        const error_description = params.get("error_description");
        const error_code = params.get("error_code");
        if (error && error_description && error_code) {
            const payload = {
                detail: { error, error_description, error_code },
            };
            window.dispatchEvent(new CustomEvent("onLoginFail", payload));
            window.history.pushState({}, document.title, window.location.pathname);
            return false;
        }
        if (!code) {
            console.warn("No code found");
            return false;
        }
        // If popup window stop internal code exchange
        if (window.opener && window.name === "uas-popup") {
            console.warn("Popup window detected");
            return false;
        }
        // Get PKCE code_challenge from local storage
        const code_verifier = await this.Storage.getPKCE();
        if (!code_verifier) {
            console.warn("No code verifier found");
            return false;
        }
        // Prepare request
        try {
            const payload = {
                client_id: this.clientId,
                redirect_uri: this.redirectUri,
                code: code,
                grant_type: "authorization_code",
                code_verifier: code_verifier,
            };
            const response = await fetch(`${this.domain}/connect/token`, {
                method: "POST",
                headers: new Headers({ "content-type": "application/json" }),
                body: JSON.stringify(payload),
            });
            const responseData = await response.json();
            // Parse response
            // Store ID token
            if (responseData) {
                if (responseData.error) {
                    const payload = { detail: responseData };
                    window.dispatchEvent(new CustomEvent("onLoginFail", payload));
                    return true;
                }
                const exchangeResponse = await this.handleCodeExchangeResponse(responseData);
                if (!exchangeResponse.valid) {
                    const payload = { detail: exchangeResponse.data };
                    window.dispatchEvent(new CustomEvent("onLoginFail", payload));
                    return true;
                }
                else {
                    if (state) {
                        exchangeResponse.data.state = state;
                    }
                    const payload = { detail: exchangeResponse.data };
                    window.dispatchEvent(new CustomEvent("onLoginSuccess", payload));
                    window.history.pushState({}, document.title, window.location.pathname);
                }
            }
            this.Storage.removePKCE();
            return true;
            // Remove PKCE code_challenge from local storage
        }
        catch (error) {
            const payload = { detail: error };
            window.dispatchEvent(new CustomEvent("onLoginFail", payload));
            window.history.pushState({}, document.title, window.location.pathname);
            return false;
        }
    }
    // Token Exchange for session  maintenece
    async tokenExchange(grant_id = "") {
        const grant = await this.Storage.getGrant(grant_id, this.multiAccount);
        if (!grant) {
            return false;
        }
        const refresh_token = grant.refresh_token;
        try {
            const payload = {
                client_id: this.clientId,
                redirect_uri: this.redirectUri,
                refresh_token,
                grant_type: "refresh_token",
            };
            const response = await fetch(`${this.domain}/connect/token`, {
                method: "POST",
                headers: new Headers({ "content-type": "application/json" }),
                body: JSON.stringify(payload),
            });
            const responseData = await response.json();
            // Parse response
            // Store ID token
            if (responseData) {
                if (responseData.error) {
                    const payload = { detail: responseData };
                    window.dispatchEvent(new CustomEvent("onTokenRefreshFail", payload));
                    return true;
                }
                const now = getTimestamp();
                responseData.expires_in = now + responseData.expires_in;
                this.Storage.setGrant(responseData, this.multiAccount);
                const isValidToken = await this.validateIDToken(grant_id);
                if (!isValidToken) {
                    const payload = { detail: responseData };
                    window.dispatchEvent(new CustomEvent("onTokenRefreshFail", payload));
                    return true;
                }
                const payload = { detail: responseData };
                window.dispatchEvent(new CustomEvent("onTokenRefreshSuccess", payload));
                return true;
            }
            // Remove PKCE code_challenge from local storage
            this.Storage.removePKCE();
        }
        catch (error) {
            const payload = { detail: error };
            window.dispatchEvent(new CustomEvent("onTokenRefreshFail", payload));
            return false;
        }
    }
    // Handles the response of code exchange
    async handleCodeExchangeResponse(responseData) {
        const isValid = true;
        if (responseData.error) {
            return {
                data: responseData,
                valid: false,
            };
        }
        const now = getTimestamp();
        responseData.expires_in = now + responseData.expires_in;
        this.Storage.setGrant(responseData, this.multiAccount);
        const user = o(responseData.id_token);
        user.status = "authenticated";
        this.Storage.setUserToken(user);
        const isValidToken = await this.validateIDToken(user.sub);
        if (!isValidToken) {
            return {
                data: responseData,
                valid: false,
            };
        }
        return {
            data: responseData,
            valid: isValid,
        };
    }
    // Regulates POPUP behaivior
    async popUp(url) {
        const width = 500;
        const height = 600;
        const left = window.screenX + (window.outerWidth - width) / 2;
        const top = window.screenY + (window.outerHeight - height) / 2.5;
        const title = `uas-popup`;
        const popupURL = url;
        const externalPopup = window.open(popupURL, title, `width=${width},height=${height},left=${left},top=${top}`);
        if (!externalPopup) {
            return;
        }
        const timer = setInterval(async () => {
            if (externalPopup.closed) {
                const payload = {
                    detail: { error_description: "OAuth provider window closed" },
                };
                window.dispatchEvent(new CustomEvent("onLoginFail", payload));
                timer && clearInterval(timer);
                return;
            }
            try {
                const currentUrl = externalPopup.location.href.split("?");
                if (!currentUrl[0]) {
                    return;
                }
                const search = externalPopup.location.search;
                externalPopup.history.pushState({}, document.title, window.location.pathname);
                if (currentUrl[0] === this.redirectUri && currentUrl.length > 1) {
                    const success = await this.codeExchange(search);
                    externalPopup.close();
                    if (success) {
                        location.reload();
                    }
                    timer && clearInterval(timer);
                    return;
                }
            }
            catch (error) {
                return;
            }
        }, 1000);
    }
    // Returns access token
    async getAccessToken(grant_id = "") {
        const now = getTimestamp();
        const grantResponse = await this.Storage.getGrant(grant_id, this.multiAccount);
        if (!grantResponse) {
            return null;
        }
        const { access_token, expires_in } = grantResponse;
        const token = access_token;
        if (token) {
            if (expires_in && expires_in > getTimestamp()) {
                const timeLeft = expires_in - now;
                // If more then 30 secounds remain return access token
                if (timeLeft > 30) {
                    return token;
                }
            }
        }
        await this.tokenExchange(grant_id);
        const grant = await this.Storage.getGrant(grant_id, this.multiAccount);
        return grant.access_token;
    }
    async sse(url, request) {
        const headers = request.headers || {};
        const grant_id = headers["Grant-ID"];
        let token = "";
        if (this.multiAccount) {
            if (!grant_id) {
                this.logout();
                throw new Error("Grant ID is required for multi account calls");
            }
            token = await this.getAccessToken(grant_id);
        }
        else {
            token = await this.getAccessToken();
        }
        delete headers["Grant-ID"];
        headers["Authorization"] = `Bearer ${token}`;
        if (!headers["content-type"]) {
            headers["content-type"] = "application/json";
        }
        return fetchEventSource(`${this.domain}/${url}`, {
            ...request,
            headers,
        });
    }
    // Used to call Nylas API endpoints
    async fetch(url, request, parseJSON = true, domain) {
        let token = "";
        let profileCount = 1;
        if (this.multiAccount) {
            if (!request.grant_id) {
                this.logout();
                throw new Error("Grant ID is required for multi account calls");
            }
            const profiles = await this.getProfiles();
            profileCount = profiles ? profiles.length : 1;
            token = await this.getAccessToken(request.grant_id);
        }
        else {
            token = await this.getAccessToken();
        }
        if (!token) {
            throw new Error("Access token not found");
        }
        let headers = request.headers;
        if (!Headers.prototype.isPrototypeOf(headers)) {
            headers = new Headers({
                Authorization: `Bearer ${token}`,
                "content-type": "application/json",
            });
        }
        else {
            headers.append("Authorization", `Bearer ${token}`);
            if (!headers.has("content-type")) {
                headers.append("content-type", "application/json");
            }
        }
        try {
            if (request?.body) {
                request.body = JSON.stringify(request?.body);
            }
            const response = await fetch(`${domain || this.domain}/${url}`, {
                ...request,
                headers,
            });
            if (!parseJSON) {
                return response;
            }
            const responseData = await response?.json();
            const isAuthenticated = await this.isAuthenticatedResponse(response.status, responseData);
            if (!isAuthenticated) {
                if (profileCount > 1) {
                    const user = await this.getProfile(request.grant_id);
                    if (user) {
                        user.status = "unauthorized";
                        await this.Storage.setUserToken(user);
                        const payload = {
                            detail: { user },
                        };
                        window.dispatchEvent(new CustomEvent("onSessionExpired", payload));
                    }
                }
                else {
                    const user = await this.Storage.getUserToken();
                    const payload = {
                        detail: { user },
                    };
                    window.dispatchEvent(new CustomEvent("onSessionExpired", payload));
                }
                this.logout();
                return;
            }
            return responseData;
        }
        catch (e) {
            throw e;
        }
    }
    async fetchRequest(path, method, body, parseJSON = true, domain, request) {
        const isLoggedIn = await this.isLoggedIn();
        const url = new URL(path, domain ?? this.domain);
        const headers = new Headers();
        headers.append("Accept", "application/json");
        headers.append("Content-Type", "application/json");
        headers.append("User-Agent", "nylas-identity");
        if (isLoggedIn) {
            const accessToken = await this.getAccessToken();
            headers.append("Authorization", `Bearer ${accessToken}`);
        }
        const response = await fetch(url.toString(), {
            method: method || "GET",
            headers,
            mode: "cors",
            referrer: location.origin,
            body: body ? JSON.stringify(body) : undefined,
            ...(request || {}),
        });
        // If we don't want to parse the response as JSON, return the raw response
        if (!parseJSON) {
            return response.body;
        }
        const json = await response.json();
        return json;
    }
    // Checks if the response is not 401
    async isAuthenticatedResponse(status, responseData) {
        if (status == 401 &&
            responseData?.error?.type == "token.unauthorized_access") {
            return false;
        }
        return true;
    }
    addAPIKey(grant_id, email, key) {
        this.Storage.setUserToken({
            aud: "https://api-staging.us.nylas.com/",
            exp: 2000000000,
            email_verified: true,
            iat: getTimestamp(),
            iss: "",
            email,
            provider: "virtual-calendar",
            status: "authenticated",
            name: email,
            sub: grant_id,
        });
        this.Storage.setGrant({
            grant_id,
            access_token: key,
            expires_in: 2000000000,
        }, this.multiAccount);
    }
}

var react_production_min = {};

/**
 * @license React
 * react.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var l=Symbol.for("react.element"),n=Symbol.for("react.portal"),p=Symbol.for("react.fragment"),q=Symbol.for("react.strict_mode"),r=Symbol.for("react.profiler"),t=Symbol.for("react.provider"),u=Symbol.for("react.context"),v=Symbol.for("react.forward_ref"),w=Symbol.for("react.suspense"),x=Symbol.for("react.memo"),y=Symbol.for("react.lazy"),z=Symbol.iterator;function A(a){if(null===a||"object"!==typeof a)return null;a=z&&a[z]||a["@@iterator"];return "function"===typeof a?a:null}
var B={isMounted:function(){return !1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},C=Object.assign,D={};function E(a,b,e){this.props=a;this.context=b;this.refs=D;this.updater=e||B;}E.prototype.isReactComponent={};
E.prototype.setState=function(a,b){if("object"!==typeof a&&"function"!==typeof a&&null!=a)throw Error("setState(...): takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,a,b,"setState");};E.prototype.forceUpdate=function(a){this.updater.enqueueForceUpdate(this,a,"forceUpdate");};function F(){}F.prototype=E.prototype;function G(a,b,e){this.props=a;this.context=b;this.refs=D;this.updater=e||B;}var H=G.prototype=new F;
H.constructor=G;C(H,E.prototype);H.isPureReactComponent=!0;var I=Array.isArray,J=Object.prototype.hasOwnProperty,K={current:null},L={key:!0,ref:!0,__self:!0,__source:!0};
function M(a,b,e){var d,c={},k=null,h=null;if(null!=b)for(d in void 0!==b.ref&&(h=b.ref),void 0!==b.key&&(k=""+b.key),b)J.call(b,d)&&!L.hasOwnProperty(d)&&(c[d]=b[d]);var g=arguments.length-2;if(1===g)c.children=e;else if(1<g){for(var f=Array(g),m=0;m<g;m++)f[m]=arguments[m+2];c.children=f;}if(a&&a.defaultProps)for(d in g=a.defaultProps,g)void 0===c[d]&&(c[d]=g[d]);return {$$typeof:l,type:a,key:k,ref:h,props:c,_owner:K.current}}
function N(a,b){return {$$typeof:l,type:a.type,key:b,ref:a.ref,props:a.props,_owner:a._owner}}function O(a){return "object"===typeof a&&null!==a&&a.$$typeof===l}function escape(a){var b={"=":"=0",":":"=2"};return "$"+a.replace(/[=:]/g,function(a){return b[a]})}var P=/\/+/g;function Q(a,b){return "object"===typeof a&&null!==a&&null!=a.key?escape(""+a.key):b.toString(36)}
function R(a,b,e,d,c){var k=typeof a;if("undefined"===k||"boolean"===k)a=null;var h=!1;if(null===a)h=!0;else switch(k){case "string":case "number":h=!0;break;case "object":switch(a.$$typeof){case l:case n:h=!0;}}if(h)return h=a,c=c(h),a=""===d?"."+Q(h,0):d,I(c)?(e="",null!=a&&(e=a.replace(P,"$&/")+"/"),R(c,b,e,"",function(a){return a})):null!=c&&(O(c)&&(c=N(c,e+(!c.key||h&&h.key===c.key?"":(""+c.key).replace(P,"$&/")+"/")+a)),b.push(c)),1;h=0;d=""===d?".":d+":";if(I(a))for(var g=0;g<a.length;g++){k=
a[g];var f=d+Q(k,g);h+=R(k,b,e,f,c);}else if(f=A(a),"function"===typeof f)for(a=f.call(a),g=0;!(k=a.next()).done;)k=k.value,f=d+Q(k,g++),h+=R(k,b,e,f,c);else if("object"===k)throw b=String(a),Error("Objects are not valid as a React child (found: "+("[object Object]"===b?"object with keys {"+Object.keys(a).join(", ")+"}":b)+"). If you meant to render a collection of children, use an array instead.");return h}
function S(a,b,e){if(null==a)return a;var d=[],c=0;R(a,d,"","",function(a){return b.call(e,a,c++)});return d}function T(a){if(-1===a._status){var b=a._result;b=b();b.then(function(b){if(0===a._status||-1===a._status)a._status=1,a._result=b;},function(b){if(0===a._status||-1===a._status)a._status=2,a._result=b;});-1===a._status&&(a._status=0,a._result=b);}if(1===a._status)return a._result.default;throw a._result;}
var U={current:null},V={transition:null},W={ReactCurrentDispatcher:U,ReactCurrentBatchConfig:V,ReactCurrentOwner:K};react_production_min.Children={map:S,forEach:function(a,b,e){S(a,function(){b.apply(this,arguments);},e);},count:function(a){var b=0;S(a,function(){b++;});return b},toArray:function(a){return S(a,function(a){return a})||[]},only:function(a){if(!O(a))throw Error("React.Children.only expected to receive a single React element child.");return a}};react_production_min.Component=E;react_production_min.Fragment=p;
react_production_min.Profiler=r;react_production_min.PureComponent=G;react_production_min.StrictMode=q;react_production_min.Suspense=w;react_production_min.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED=W;
react_production_min.cloneElement=function(a,b,e){if(null===a||void 0===a)throw Error("React.cloneElement(...): The argument must be a React element, but you passed "+a+".");var d=C({},a.props),c=a.key,k=a.ref,h=a._owner;if(null!=b){void 0!==b.ref&&(k=b.ref,h=K.current);void 0!==b.key&&(c=""+b.key);if(a.type&&a.type.defaultProps)var g=a.type.defaultProps;for(f in b)J.call(b,f)&&!L.hasOwnProperty(f)&&(d[f]=void 0===b[f]&&void 0!==g?g[f]:b[f]);}var f=arguments.length-2;if(1===f)d.children=e;else if(1<f){g=Array(f);
for(var m=0;m<f;m++)g[m]=arguments[m+2];d.children=g;}return {$$typeof:l,type:a.type,key:c,ref:k,props:d,_owner:h}};react_production_min.createContext=function(a){a={$$typeof:u,_currentValue:a,_currentValue2:a,_threadCount:0,Provider:null,Consumer:null,_defaultValue:null,_globalName:null};a.Provider={$$typeof:t,_context:a};return a.Consumer=a};react_production_min.createElement=M;react_production_min.createFactory=function(a){var b=M.bind(null,a);b.type=a;return b};react_production_min.createRef=function(){return {current:null}};
react_production_min.forwardRef=function(a){return {$$typeof:v,render:a}};react_production_min.isValidElement=O;react_production_min.lazy=function(a){return {$$typeof:y,_payload:{_status:-1,_result:a},_init:T}};react_production_min.memo=function(a,b){return {$$typeof:x,type:a,compare:void 0===b?null:b}};react_production_min.startTransition=function(a){var b=V.transition;V.transition={};try{a();}finally{V.transition=b;}};react_production_min.unstable_act=function(){throw Error("act(...) is not supported in production builds of React.");};
react_production_min.useCallback=function(a,b){return U.current.useCallback(a,b)};react_production_min.useContext=function(a){return U.current.useContext(a)};react_production_min.useDebugValue=function(){};react_production_min.useDeferredValue=function(a){return U.current.useDeferredValue(a)};react_production_min.useEffect=function(a,b){return U.current.useEffect(a,b)};react_production_min.useId=function(){return U.current.useId()};react_production_min.useImperativeHandle=function(a,b,e){return U.current.useImperativeHandle(a,b,e)};
react_production_min.useInsertionEffect=function(a,b){return U.current.useInsertionEffect(a,b)};react_production_min.useLayoutEffect=function(a,b){return U.current.useLayoutEffect(a,b)};react_production_min.useMemo=function(a,b){return U.current.useMemo(a,b)};react_production_min.useReducer=function(a,b,e){return U.current.useReducer(a,b,e)};react_production_min.useRef=function(a){return U.current.useRef(a)};react_production_min.useState=function(a){return U.current.useState(a)};react_production_min.useSyncExternalStore=function(a,b,e){return U.current.useSyncExternalStore(a,b,e)};
react_production_min.useTransition=function(){return U.current.useTransition()};react_production_min.version="18.2.0";

const LoginRequired = ({ authenticationUrl }) => (index$1.h("div", { class: 'login-required', part: "nse__login-required login-component" },
    index$1.h("div", { class: 'card', part: "nse__login-required-card" },
        index$1.h("p", { part: "nse__login-required-text" }, "Log into your account to use the Scheduler Editor."),
        index$1.h("button", { class: "google-button", part: "nse__login-required-google-button", onClick: async (event) => {
                event.preventDefault();
                const authUrl = await authenticationUrl('google');
                if (authUrl) {
                    window.location.href = authUrl;
                }
                else {
                    console.error(`[nylas-scheduler-editor] Unable to get authentication URL.`);
                }
            } },
            index$1.h("span", { class: "icon" },
                index$1.h("google-logo-icon", { width: "15", height: "15" })),
            "Continue with Google"),
        index$1.h("button", { class: "microsoft-button", part: "nse__login-required-microsoft-button", onClick: async (event) => {
                event.preventDefault();
                const authUrl = await authenticationUrl('microsoft');
                if (authUrl) {
                    window.location.href = authUrl;
                }
                else {
                    console.error(`[nylas-scheduler-editor] Unable to get authentication URL.`);
                }
            } },
            index$1.h("span", { class: "icon" },
                index$1.h("microsoft-logo-icon", { width: "15", height: "15" })),
            "Continue with Microsoft"),
        index$1.h("button", { class: "other-provider-button", part: "nse__login-required-other-provider-button", onClick: async (event) => {
                event.preventDefault();
                const authUrl = await authenticationUrl();
                if (authUrl) {
                    window.location.href = authUrl;
                }
                else {
                    console.error(`[nylas-scheduler-editor] Unable to get authentication URL.`);
                }
            } },
            "View all providers ",
            index$1.h("chevron-icon", { width: "17", height: "17" })),
        index$1.h("small", { class: "disclaimer-text", part: "nse__login-required-disclaimer-text" }, "* You will be redirected to authenticate your account."))));

function ExpressFlow({ currentUser, calendars, selectedEventType }) {
    const defaultCalendarOption = calendars?.find(c => c.is_primary) || calendars?.[0];
    switch (selectedEventType) {
        case constants.CONFIGURATION_EVENT_TYPE.one_on_one:
        case constants.CONFIGURATION_EVENT_TYPE.max_availability:
        case constants.CONFIGURATION_EVENT_TYPE.max_fairness: {
            return (index$1.h(index$1.Fragment, null,
                index$1.h("nylas-event-info", null,
                    index$1.h("div", { slot: "inputs" },
                        index$1.h("nylas-event-title", null),
                        index$1.h("nylas-event-duration", null),
                        index$1.h("nylas-event-location", { userProvider: currentUser.provider }))),
                index$1.h("nylas-booking-calendar-picker", { exportparts: "nbcp, nbcp__header, nbcp__dropdown, nbcp__dropdown-button, nbcp__dropdown-content", expressFlow: true, calendars: calendars, currentUser: currentUser, defaultBookingCalendar: defaultCalendarOption?.id }),
                index$1.h("nylas-custom-event-slug", { name: "custom-event-slug", exportparts: "nces, nces__body, nces__header, nces__drawer-toggle--container, nces__input-textfield" })));
        }
        case constants.CONFIGURATION_EVENT_TYPE.collective: {
            return (index$1.h(index$1.Fragment, null,
                index$1.h("nylas-event-info", null,
                    index$1.h("div", { slot: "inputs" },
                        index$1.h("nylas-event-title", null),
                        index$1.h("nylas-event-duration", null),
                        index$1.h("nylas-event-location", { userProvider: currentUser.provider }))),
                index$1.h("nylas-booking-calendar-picker", { exportparts: "nbcp, nbcp__header, nbcp__dropdown, nbcp__dropdown-button, nbcp__dropdown-content", expressFlow: true, calendars: calendars, currentUser: currentUser, defaultBookingCalendar: defaultCalendarOption?.id }),
                index$1.h("nylas-custom-event-slug", { name: "custom-event-slug", exportparts: "nces, nces__body, nces__header, nces__drawer-toggle--container, nces__input-textfield" }),
                index$1.h("nylas-additional-participants", { name: "participants", eventParticipants: [{ name: currentUser?.name || currentUser?.email, email: currentUser?.email || '', is_organizer: true }], exportparts: "nadtnlpart, nadtnlpart__title, nadtnlpart__subtitle, nadtnlpart__content, nadtnlpart__input_group, nadtnlpart__input_wrapper, nadtnlpart__input, nadtnlpart__remove-participant" })));
        }
        case constants.CONFIGURATION_EVENT_TYPE.group: {
            return (index$1.h(index$1.Fragment, null,
                index$1.h("nylas-event-info", null,
                    index$1.h("div", { slot: "inputs" },
                        index$1.h("nylas-event-title", { noTemplates: true }),
                        index$1.h("nylas-event-description", { noTemplates: true, hideAutoPopulateButton: true }),
                        index$1.h("nylas-event-location", { userProvider: currentUser.provider }),
                        index$1.h("nylas-event-timeslot", { name: "event-timeslot" }),
                        index$1.h("nylas-event-capacity", null))),
                index$1.h("nylas-booking-calendar-picker", { exportparts: "nbcp, nbcp__header, nbcp__dropdown, nbcp__dropdown-button, nbcp__dropdown-content", expressFlow: true, calendars: calendars, currentUser: currentUser, defaultBookingCalendar: defaultCalendarOption?.id }),
                index$1.h("nylas-additional-participants", { name: "participants", eventParticipants: [{ name: currentUser?.name || currentUser?.email, email: currentUser?.email || '', is_organizer: true }], exportparts: "nadtnlpart, nadtnlpart__title, nadtnlpart__subtitle, nadtnlpart__content, nadtnlpart__input_group, nadtnlpart__input_wrapper, nadtnlpart__input, nadtnlpart__remove-participant" }),
                index$1.h("nylas-page-name", { requirePageName: true, pageName: "Group events page" }),
                index$1.h("nylas-custom-event-slug", { name: "custom-event-slug", exportparts: "nces, nces__body, nces__header, nces__drawer-toggle--container, nces__input-textfield" })));
        }
    }
}

const nylasSchedulerEditorCss = ":host{display:flex;flex-direction:column;overflow:visible;border-radius:var(--nylas-border-radius-2x);width:fit-content;background:var(--nylas-base-0);position:relative;box-shadow:0px 0px 6px -2px rgba(0, 0, 0, 0.05), 0px 5px 15px -3px rgba(0, 0, 0, 0.1);--nylas-primary:#2563eb;--nylas-error:#cc4841;--nylas-error-pressed:#992222;--nylas-wraning:#f06c00;--nylas-success:#16a392;--nylas-info:#2b8fc2;--nylas-base-0:#ffffff;--nylas-base-25:#fcfcfd;--nylas-base-50:#f8f9fc;--nylas-base-100:#eaecf5;--nylas-base-200:#d5d9eb;--nylas-base-300:#b3b8d8;--nylas-base-400:#717bbc;--nylas-base-500:#4e5ba6;--nylas-base-600:#3e4784;--nylas-base-700:#263f72;--nylas-base-800:#293056;--nylas-base-900:#101323;--nylas-base-950:#0e101b;--nylas-color-blue-100:#e0e6f9;--nylas-border-radius:0.25rem;--nylas-border-radius-2x:0.5rem;--nylas-border-radius-3x:0.75rem;--nylas-font-family:\"Inter\", sans-serif;--nylas-color-black:#000000;--nylas-color-grey-900:#2c2c2c;--nylas-color-grey-800:#4b4b4b;--nylas-color-grey-700:#6e6e6e;--nylas-color-grey-600:#8e8e8e;--nylas-color-grey-500:#b3b3b3;--nylas-color-grey-400:#cacaca;--nylas-color-grey-300:#e1e1e1;--nylas-color-grey-200:#eaeaea;--nylas-color-grey-100:#f5f5f5;--nylas-color-grey-50:#fbfcfe;--nylas-color-white:#ffffff;--nylas-color-red-900:#992222;--nylas-color-red-700:#cc4841;--nylas-color-red-500:#ff786a;--nylas-color-red-300:#ffa79e;--nylas-color-red-100:#ffc5bf;--nylas-color-red-50:#ffeae8;--nylas-color-blue-900:#213571;--nylas-color-blue-700:#314fa9;--nylas-color-blue-500:#4169e1;--nylas-color-blue-300:#bdccf9;--nylas-color-blue-100:#e0e6f9;--nylas-color-blue-50:#f6f8fd;--nylas-color-yellow-900:#7c6506;--nylas-color-yellow-700:#c29f09;--nylas-color-yellow-500:#f7c90b;--nylas-color-yellow-300:#f9de70;--nylas-color-yellow-100:#fceba9;--nylas-color-yellow-50:#fdf4ce;--nylas-color-green-900:#0e6b60;--nylas-color-green-700:#16a392;--nylas-color-green-500:#17c3b2;--nylas-color-green-300:#74dbd1;--nylas-color-green-100:#a2e7e0;--nylas-color-green-50:#d1f3f0;--nylas-color-purple-900:#643554;--nylas-color-purple-700:#954f7d;--nylas-color-purple-500:#c769a7;--nylas-color-purple-300:#dda5ca;--nylas-color-purple-100:#e0bdd6;--nylas-color-purple-50:#e9dde5;--nylas-color-sky-900:#20698f;--nylas-color-sky-700:#2b8fc2;--nylas-color-sky-500:#6dceff;--nylas-color-sky-300:#8fdaff;--nylas-color-sky-100:#b8e7ff;--nylas-color-sky-50:#d9f2ff}@media screen and (max-width: 768px){:host{width:-moz-available;width:-webkit-fill-available;width:fill-available;min-width:325px}}:host nylas-notification{position:absolute;top:0;right:0}div.scheduler-editor-content{height:800px}@media screen and (max-width: 768px){div.scheduler-editor-content{height:auto}}div.scheduler-editor-content--group{height:800px}@media screen and (max-width: 768px){div.scheduler-editor-content--group{height:auto}}div.scheduler-editor-header{display:grid;grid-template-columns:1fr auto auto;align-items:center;justify-content:space-between;padding:1rem;border-bottom:1px solid var(--nylas-base-200);color:var(--nylas-base-900);min-width:924px}@media screen and (max-width: 768px){div.scheduler-editor-header{width:auto;min-width:calc(325px - 1rem)}}div.scheduler-editor-header h1.scheduler-editor-title{display:flex;align-items:center;gap:0.5rem;margin:0;font-size:18px;line-height:24px;font-weight:600}div.scheduler-editor-header button{background:transparent;border:none;cursor:pointer}div.scheduler-editor-header button:hover,div.scheduler-editor-header button:active{color:var(--nylas-primary);background-color:transparent}div.scheduler-editor-header button:disabled{cursor:not-allowed}div.scheduler-editor-header div.language select-dropdown::part(sd_dropdown-button){border:none;padding:4px;margin-right:8px}div.scheduler-editor-header div.language select-dropdown::part(sd_dropdown-button):hover{outline:none;color:var(--nylas-primary)}div.scheduler-editor-header div.language select-dropdown::part(sd_dropdown-content){min-width:132px}@media screen and (max-width: 768px){div.scheduler-editor-header div.language select-dropdown::part(sd_dropdown-content){width:-webkit-fill-available;width:fill-available;width:-moz-available}}nylas-select-event-type{height:inherit;width:calc(924px + 2rem)}@media screen and (max-width: 768px){nylas-select-event-type{width:auto}}nylas-editor-tabs,nylas-editor-tabs-group{width:auto;height:inherit}nylas-editor-tabs .row,nylas-editor-tabs-group .row{display:flex;gap:1rem}nylas-editor-tabs .composable,nylas-editor-tabs-group .composable{height:inherit;overflow:auto}nylas-editor-tabs nylas-event-info div[slot=inputs],nylas-editor-tabs nylas-event-limits div[slot=inputs],nylas-editor-tabs-group nylas-event-info div[slot=inputs],nylas-editor-tabs-group nylas-event-limits div[slot=inputs]{display:flex;flex-direction:column;gap:1rem}.card{display:flex;flex-direction:column;padding:2rem;background-color:var(--nylas-base-0);border:1px solid var(--nylas-base-200);border-radius:5px;max-width:fit-content;align-self:center}.login-required{height:inherit;overflow-y:auto;display:flex;flex-direction:column;justify-content:center;padding:2rem 1rem;background-color:var(--nylas-base-25);border-radius:var(--nylas-border-radius-2x)}@media screen and (max-width: 768px){.login-required{height:auto}}.login-required p{margin:0 0 1rem}.login-required .microsoft-button,.login-required .google-button{height:48px;border:1px solid var(--nylas-base-300);border-radius:var(--nylas-border-radius-2x);font-size:16px;line-height:24px;padding:0 1rem;background-color:var(--nylas-base-0);font-weight:600;cursor:pointer;display:flex;margin-bottom:1rem;background-color:var(--nylas-base-0);border:1px solid var(--nylas-base-200);border-radius:5px;justify-content:center;gap:0.5rem;align-items:center}.login-required .microsoft-button:hover,.login-required .google-button:hover{background-color:var(--nylas-base-25)}.login-required .microsoft-button:hover,.login-required .google-button:hover{background-color:var(--nylas-base-25)}.login-required .other-provider-button{height:48px;border:1px solid var(--nylas-base-300);border-radius:var(--nylas-border-radius-2x);font-size:16px;line-height:24px;padding:0 1rem;background-color:var(--nylas-base-0);font-weight:600;cursor:pointer;display:flex;border:0;background-color:var(--nylas-base-0);height:48px;margin-bottom:1rem;font-size:0.95rem;justify-content:center;gap:0.25rem;align-items:center}.login-required .other-provider-button:hover{background-color:var(--nylas-base-25)}.login-required .other-provider-button svg{transform:rotate(180deg)}.login-required .other-provider-button:hover{background-color:var(--nylas-base-25)}.login-required .disclaimer-text{font-size:0.75rem;color:var(--nylas-base-600);align-self:center}.list-configurations{padding:2rem;height:inherit;background:var(--nylas-base-25);border-radius:var(--nylas-border-radius-2x)}@media screen and (max-width: 768px){.list-configurations{height:auto;padding:2rem 1rem}}.list-configurations nylas-list-configurations{height:inherit;display:flex;flex-direction:column}";
const NylasSchedulerEditorStyle0 = nylasSchedulerEditorCss;

const NylasSchedulerEditor = class {
    constructor(hostRef) {
        index$1.registerInstance(this, hostRef);
        this.init = index$1.createEvent(this, "init", 7);
        this.loggedIn = index$1.createEvent(this, "loggedIn", 7);
        this.loggedOut = index$1.createEvent(this, "loggedOut", 7);
        this.schedulerConfigCloseClicked = index$1.createEvent(this, "schedulerConfigCloseClicked", 7);
        this.handleSchedulerConfigCloseClicked = (_event) => {
            const event = this.schedulerConfigCloseClicked.emit(this.host);
            if ('schedulerConfigCloseClicked' in this.eventOverrides) {
                this.eventOverrides.schedulerConfigCloseClicked(event, this.nylasSchedulerConfigConnector);
            }
            if (!event.defaultPrevented) {
                localStorage.removeItem('grant');
                localStorage.removeItem('user');
                window.location.reload();
            }
        };
        this.authenticationUrl = async (provider) => {
            if (!this.nylasApiRequest) {
                console.error(`[nylas-scheduler-editor] Nylas API Request is not initialized.`);
                return '';
            }
            const url = await this.nylasApiRequest.authenticationUrl({ provider });
            return url || '';
        };
        this.configurationId = undefined;
        this.nylasApiRequest = undefined;
        this.nylasSessionsConfig = undefined;
        this.defaultAuthArgs = undefined;
        this.eventOverrides = {};
        this.schedulerPreviewLink = '';
        this.defaultSchedulerConfigState = undefined;
        this.mode = 'app';
        this.additionalParticipants = undefined;
        this.hideEditorTabs = [];
        this.conferenceProviders = undefined;
        this.requiresSlug = false;
        this.enableUserFeedback = true;
        this.defaultLanguage = undefined;
        this.localization = undefined;
        this.nylasBranding = true;
        this.experimentalFeatures = undefined;
        this.enableEventTypes = {
            one_on_one: true,
            collective: true,
            max_fairness: true,
            max_availability: true,
            group: true,
        };
        this.automaticComponentRegistration = true;
        this.selectedLanguage = this.defaultLanguage || constants.LANGUAGE_CODE.en;
        this.langVersion = 0;
        this.version = "2.0.1" ;
    }
    connectedCallback() {
        utils.debug(`[nylas-scheduler-editor] connectedCallback`);
    }
    async componentWillLoad() {
        utils.debug(`[nylas-scheduler-editor] componentWillLoad`);
        const filteredAdditionalParticipants = this.additionalParticipants?.filter(participant => {
            const filteredCalendars = participant.calendars?.length > 0 ? participant.calendars.filter(calendar => calendar.id && calendar.name) : [];
            if (participant.name && participant.email && filteredCalendars.length > 0) {
                return {
                    name: participant.name,
                    email: participant.email,
                    calendars: filteredCalendars,
                };
            }
        });
        this.stores = {
            schedulerConfig: CreateNylasSchedulerConfigStore({
                ...this.defaultSchedulerConfigState,
                additionalParticipants: filteredAdditionalParticipants,
                conferenceProviders: this.conferenceProviders,
                requiresSlug: this.requiresSlug,
                selectedLanguage: this.defaultLanguage || constants.LANGUAGE_CODE.en,
                nylasBranding: this.nylasBranding,
                experimentalFeatures: this.experimentalFeatures,
                enableEventTypes: this.enableEventTypes,
            }),
        };
        if (!this.nylasApiRequest && this.nylasSessionsConfig) {
            const nylasSession = new NylasSessions(this.nylasSessionsConfig);
            await nylasSession.isLoggedIn();
            nylasSession.onLoginSuccess(async () => {
                const currentUser = await this.nylasSchedulerConfigConnector?.schedulerConfig?.currentUser();
                if (currentUser) {
                    const loggedInEvent = this.loggedIn.emit(this.host);
                    if ('loggedIn' in this.eventOverrides) {
                        await this.eventOverrides.loggedIn(loggedInEvent, this.nylasSchedulerConfigConnector);
                    }
                    if (!loggedInEvent.defaultPrevented) {
                        await this.loggedInHandler(currentUser);
                    }
                }
            });
            nylasSession.onLoginFail(async () => {
                this.stores?.schedulerConfig?.set('currentUser', null);
                const loggedOutEvent = this.loggedOut.emit(this.host);
                if ('loggedOut' in this.eventOverrides) {
                    await this.eventOverrides.loggedOut(loggedOutEvent, this.nylasSchedulerConfigConnector);
                    if (loggedOutEvent.defaultPrevented) {
                        return;
                    }
                }
            });
            this.nylasApiRequest = new nylasApiRequest.NylasIdentityRequestWrapper(nylasSession);
        }
        if (this.nylasApiRequest && this.defaultAuthArgs) {
            this.nylasApiRequest.setDefaultAuthArgs(this.defaultAuthArgs);
        }
        this.baseProvider = new abstractProvider.NylasBaseProvider(this.host, this.stores, this.automaticComponentRegistration, this.eventOverrides);
        const nylasSchedulerConfigStore = this.baseProvider.getStore('schedulerConfig');
        this.nylasSchedulerConfigConnector = new NylasSchedulerConfigConnector({
            nylasApiRequest: this.nylasApiRequest,
            nylasSchedulerConfigStore: nylasSchedulerConfigStore,
        });
        const initEvent = this.init.emit(this.host);
        if ('init' in this.eventOverrides) {
            await this.eventOverrides.init(initEvent, this.nylasSchedulerConfigConnector);
        }
        if (!initEvent.defaultPrevented) {
            const currentUser = await this.nylasSchedulerConfigConnector?.schedulerConfig?.currentUser();
            if (currentUser) {
                const loggedInEvent = this.loggedIn.emit(this.host);
                if ('loggedIn' in this.eventOverrides) {
                    await this.eventOverrides.loggedIn(loggedInEvent, this.nylasSchedulerConfigConnector);
                }
                if (!loggedInEvent.defaultPrevented) {
                    await this.loggedInHandler(currentUser);
                }
            }
            else {
                this.stores?.schedulerConfig?.set('currentUser', null);
                const loggedOutEvent = this.loggedOut.emit(this.host);
                if ('loggedOut' in this.eventOverrides) {
                    await this.eventOverrides.loggedOut(loggedOutEvent, this.nylasSchedulerConfigConnector);
                    if (loggedOutEvent.defaultPrevented) {
                        return;
                    }
                }
            }
        }
        this.stores?.schedulerConfig?.onChange('selectedConfiguration', async (config) => {
            if (config && config.id) {
                this.configurationId = config.id;
            }
        });
        this.baseProvider?.componentWillLoad(this.nylasSchedulerConfigConnector);
    }
    async componentDidLoad() {
        utils.debug(`[nylas-scheduler-editor] componentDidLoad`);
        await this.baseProvider?.componentDidLoad();
        this.updateLocalization(this.localization);
        this.version = "2.0.1" ;
    }
    async componentDisconnected() {
        await this.baseProvider?.componentDisconnected();
    }
    async configurationIdChanged(newConfigurationId) {
        if (newConfigurationId) {
            await this.nylasSchedulerConfigConnector?.schedulerConfig?.getConfigurationById(newConfigurationId);
            this.stores?.schedulerConfig?.set('action', 'edit');
        }
        else {
            this.stores?.schedulerConfig?.set('selectedConfiguration', {});
            this.stores?.schedulerConfig?.set('action', null);
        }
    }
    updateLocalization(newVal) {
        if (!newVal) {
            return;
        }
        Object.keys(newVal).forEach(lang => {
            if (!(lang in constants.LANGUAGE_CODE)) {
                return;
            }
            utils.instance.addResourceBundle(lang, 'translation', newVal[lang], false, true);
        });
        this.langVersion++;
    }
    updateNylasBranding(newVal) {
        this.stores?.schedulerConfig?.set('nylasBranding', newVal);
    }
    updateExperimentalFeatures(newVal) {
        this.stores?.schedulerConfig?.set('experimentalFeatures', newVal);
    }
    updateEnableEventTypes(newVal) {
        this.stores?.schedulerConfig?.set('enableEventTypes', newVal);
    }
    async store() {
        return this.stores?.schedulerConfig;
    }
    async schedulerConnector() {
        return this.nylasSchedulerConfigConnector;
    }
    async registerComponentHandler(event) {
        this.baseProvider?.registerComponent(event.detail);
    }
    async unregisterComponentHandler(event) {
        this.baseProvider?.unregisterComponent(event.detail);
    }
    nylasFormDropdownChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'language') {
            this.selectedLanguage = constants.LANGUAGE_CODE[value];
            utils.instance.changeLanguage(this.selectedLanguage);
            this.stores?.schedulerConfig?.set('selectedLanguage', this.selectedLanguage);
        }
    }
    async loggedInHandler(currentUser) {
        this.stores?.schedulerConfig?.set('currentUser', currentUser);
        if (!this.nylasSchedulerConfigConnector) {
            return;
        }
        await this.nylasSchedulerConfigConnector.schedulerConfig?.getCalendars();
        if (this.configurationId) {
            const data = await this.nylasSchedulerConfigConnector.schedulerConfig?.getConfigurationById(this.configurationId);
            if (data && data[0]?.id) {
                this.stores?.schedulerConfig?.set('action', 'edit');
            }
        }
    }
    render() {
        const hasSlot = this.host.querySelector('[slot="custom-page-style-inputs"]');
        const selectedConfigId = this.stores?.schedulerConfig?.state.selectedConfiguration?.id;
        const languageOptions = Object.keys(constants.LANGUAGE_MAP).map(key => ({
            label: constants.LANGUAGE_MAP[key],
            value: key,
        }));
        const isGroupType = this.stores?.schedulerConfig?.state.selectedEventType === constants.CONFIGURATION_EVENT_TYPE.group ||
            this.stores?.schedulerConfig?.state.selectedConfiguration?.type === constants.CONFIGURATION_EVENT_TYPE.group;
        return (index$1.h(index$1.Host, { key: 'f2ff98b69f59cf94f68e0a72750db304d5f5781c' }, index$1.h("div", { key: '382bac7a0ba7735ce0c6704f825d8a18a3faf412', class: "scheduler-editor-header", part: "nse__header" }, index$1.h("h1", { key: 'eb011947ed70b8f7b2bd73a1d57c8de743782acd', class: "scheduler-editor-title", part: "nse__title" }, index$1.h("calendar-icon", { key: 'd6a3bdf5d3c7501e865c363a58cbfd78b9ee10b1', width: "18", height: "18" }), utils.instance.t('schedulerEditorTitle'), index$1.h("tooltip-component", { key: 'd2cde09b0b5ac91a306d81dba57838ce373cda92' }, index$1.h("info-icon", { key: 'af00e8fa6ca5ef8baaaf5a9abdf14a7138b030fd', slot: "tooltip-icon" }), index$1.h("span", { key: '24a185bac54f44abf7ffe9bf3cd2723dc363a12f', slot: "tooltip-content" }, this.version))), index$1.h("div", { key: '6fdf10c991b049d0a96a09faddf056de7b80a1de', class: {
                language: true,
            }, part: "nse__language" }, index$1.h("select-dropdown", { key: 'd733d65ad4fd639f94b5fde41ae32725949fe429', name: "language", searchPlaceholder: utils.instance.t('search'), options: languageOptions, withChevron: false, defaultSelectedOption: languageOptions.find(lang => lang.value == this.selectedLanguage), exportparts: "sd_dropdown: nse__language-dropdown, sd_dropdown-button: nse__language-drop-button, sd_dropdown-content: nse__language-drop-content, sd_dropdown_label: nse__language-drop-label" }, index$1.h("span", { key: '9ae3abafd8aa09ec54f70c9d950eb1569eff6870', slot: "select-icon" }, index$1.h("translate-icon", { key: 'e435ec08d11c784caca91cf97887e261409b559b', width: "20", height: "20" })))), index$1.h("button", { key: '2bd03fa6333f11f3da17f8ce1db6516a4f936a6f', class: "scheduler-editor-close", title: "logout", onClick: e => this.handleSchedulerConfigCloseClicked(e), part: "nse__close-button" }, index$1.h("close-icon", { key: 'b7e1ab191b7bfd4c892e101c5662ebeb42ad67a2', width: "18", height: "18" }))), index$1.h("div", { key: '3a19a2dde27979aa7428a388e68b9eb8c8d266a2', class: {
                'scheduler-editor-content': true,
                'scheduler-editor-content--group': isGroupType,
            }, part: "nse__content" }, this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === null && (index$1.h("div", { class: "list-configurations", part: "nse__list-configurations" }, index$1.h("nylas-list-configurations", { exportparts: "nlc__create-new-cta, actions__dropdown,  actions__dropdown-button, actions__dropdown-content, actions-Copy, actions-Preview, actions-Delete" }))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'create-select' && index$1.h("nylas-select-event-type", null), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'create' && isGroupType && (index$1.h("nylas-editor-tabs-group", { mode: "composable" }, index$1.h(ExpressFlow, { selectedEventType: this.stores?.schedulerConfig?.state?.selectedEventType || constants.CONFIGURATION_EVENT_TYPE.one_on_one, currentUser: this.stores?.schedulerConfig?.state.currentUser, calendars: this.stores?.schedulerConfig?.state?.calendars, selectedConfiguration: this.stores?.schedulerConfig?.state?.selectedConfiguration }))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'create' && !isGroupType && (index$1.h("nylas-editor-tabs", { mode: "composable" }, index$1.h(ExpressFlow, { selectedEventType: this.stores?.schedulerConfig?.state?.selectedEventType || constants.CONFIGURATION_EVENT_TYPE.one_on_one, currentUser: this.stores?.schedulerConfig?.state.currentUser, calendars: this.stores?.schedulerConfig?.state?.calendars, selectedConfiguration: this.stores?.schedulerConfig?.state?.selectedConfiguration }))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'edit' && isGroupType && (index$1.h("nylas-editor-tabs-group", { key: selectedConfigId, mode: this.mode }, this.mode === 'composable' && index$1.h("slot", null), this.mode === 'app' && hasSlot && (index$1.h("div", { style: { display: 'none' }, slot: "custom-page-style-inputs", key: selectedConfigId }, index$1.h("slot", { name: "custom-page-style-inputs" }))))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'edit' && !isGroupType && (index$1.h("nylas-editor-tabs", { key: selectedConfigId, mode: this.mode }, this.mode === 'composable' && index$1.h("slot", null), this.mode === 'app' && hasSlot && (index$1.h("div", { style: { display: 'none' }, slot: "custom-page-style-inputs", key: selectedConfigId }, index$1.h("slot", { name: "custom-page-style-inputs" }))))), !this.stores?.schedulerConfig?.state.currentUser && (index$1.h("slot", { name: "login-required" }, index$1.h(LoginRequired, { authenticationUrl: this.authenticationUrl }))))));
    }
    get host() { return index$1.getElement(this); }
    static get watchers() { return {
        "configurationId": ["configurationIdChanged"],
        "localization": ["updateLocalization"],
        "nylasBranding": ["updateNylasBranding"],
        "experimentalFeatures": ["updateExperimentalFeatures"],
        "enableEventTypes": ["updateEnableEventTypes"]
    }; }
};
NylasSchedulerEditor.style = NylasSchedulerEditorStyle0;

exports.nylas_scheduler_editor = NylasSchedulerEditor;

//# sourceMappingURL=nylas-scheduler-editor.cjs.entry.js.map