'use strict';

const utils = require('./utils-dd3b6f4c.js');
const index = require('./index-e07e3a7e.js');

function createComponentEvent(instance, registeredComponent, eventName = 'registerComponent') {
    return new CustomEvent(eventName, {
        bubbles: true,
        composed: true,
        detail: registeredComponent,
    });
}
function unregisterComponentEvent(instance, registeredComponent, eventName = 'unregisterComponent') {
    return new CustomEvent(eventName, {
        bubbles: true,
        composed: true,
        detail: registeredComponent,
    });
}
function RegisterComponent(config) {
    return (target, propKey) => {
        const componentName = config.name;
        utils.debug(`[${componentName}] Registering component ${componentName} being called on ${propKey}`);
        const originalComponentWillLoad = target.componentWillLoad;
        if (!originalComponentWillLoad) {
            utils.error(`[${componentName}] componentWillLoad lifecycle method in ${componentName} missing. Required for RegisterComponent decorator.`);
            return;
        }
        const originalConnectCallback = target.connectedCallback;
        if (!originalConnectCallback) {
            utils.error(`[${componentName}] connectedCallback lifecycle method in ${componentName} missing. Required for RegisterComponent decorator.`);
            return;
        }
        const originalDisconnectCallback = target.disconnectedCallback;
        if (!originalDisconnectCallback) {
            utils.error(`[${componentName}] disconnectedCallback lifecycle method in ${componentName} missing. Required for RegisterComponent decorator.`);
            return;
        }
        if (config.storeToProps && config.stateToProps) {
            const storeToPropsKeys = Array.from(config.storeToProps.values());
            const stateToPropsKeys = Array.from(config.stateToProps.values());
            const intersection = storeToPropsKeys.filter(key => stateToPropsKeys.includes(key));
            if (intersection.length > 0) {
                utils.error(`[${componentName}] Overlapping prop keys detected in ${componentName} for storeToProps and stateToProps. Make sure to only define them once. Overlapping keys: ${intersection.join(', ')}`);
                return;
            }
        }
        const eventToPropsMap = new Map();
        if (config.eventToProps) {
            Object.keys(config.eventToProps).forEach(key => {
                eventToPropsMap.set(key, config.eventToProps?.[key]);
            });
        }
        target.connectedCallback = function () {
            utils.debug(`[~${componentName}] connectedCallback called`);
            const origionalResult = originalConnectCallback?.call(this);
            const host = index.getElement(this);
            if (host.dataset.nylasId) {
                return origionalResult;
            }
            Object.defineProperty(host, 'registerNylasComponent', {
                get() {
                    return true;
                },
                enumerable: true,
            });
            Object.defineProperty(host, 'stateToProps', {
                get() {
                    return config.stateToProps;
                },
                enumerable: true,
            });
            Object.defineProperty(host, 'getStoresToProp', {
                get() {
                    return config.getStoresToProp;
                },
                enumerable: true,
            });
            Object.defineProperty(host, 'storeToProps', {
                get() {
                    return config.storeToProps;
                },
                enumerable: true,
            });
            Object.defineProperty(host, 'eventToProps', {
                get() {
                    return eventToPropsMap;
                },
                enumerable: true,
            });
            Object.defineProperty(host, 'authToProp', {
                get() {
                    return config.authToProp;
                },
                enumerable: true,
            });
            Object.defineProperty(host, 'connectorToProp', {
                get() {
                    return config.connectorToProp;
                },
                enumerable: true,
            });
            Object.defineProperty(host, 'localPropsToProp', {
                get() {
                    return config.localPropsToProp;
                },
                enumerable: true,
            });
            return origionalResult;
        };
        if (config.fireRegisterEvent) {
            target.componentWillLoad = function () {
                const origionalResult = originalComponentWillLoad?.call(this);
                const host = index.getElement(this);
                const registeredComponent = {
                    element: host,
                    ...config,
                    eventToProps: eventToPropsMap,
                };
                const event = createComponentEvent(target, registeredComponent, config.registrationEventName);
                if (host.dispatchEvent(event)) {
                    utils.debug(`[${componentName}] Component ${componentName} successfully fired registration event`);
                }
                return origionalResult;
            };
            target.disconnectedCallback = function () {
                const origionalResult = originalDisconnectCallback?.call(this);
                const host = index.getElement(this);
                const registeredComponent = {
                    element: host,
                    ...config,
                    eventToProps: eventToPropsMap,
                };
                const event = unregisterComponentEvent(target, registeredComponent, config.unregistrationEventName);
                if (host.dispatchEvent(event)) {
                    utils.debug(`[${componentName}] Component ${componentName} successfully fired unregistration event`);
                }
                return origionalResult;
            };
        }
    };
}

exports.RegisterComponent = RegisterComponent;

//# sourceMappingURL=register-component-70744713.js.map