import { h } from "@stencil/core";
import { sanitize } from "../../../utils/utils";
const DefaultPattern = {
    email: /^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/,
    phone_number: /^\+?\d{1,15}$/,
};
const DefaultPlaceholder = {
    email: 'name@example.com',
    phone_number: '1234567890',
};
export class InputComponent {
    constructor() {
        this.name = 'input';
        this.defaultValue = undefined;
        this.label = '';
        this.type = 'text';
        this.placeholder = DefaultPlaceholder[this.type];
        this.required = false;
        this.readOnly = false;
        this.autoFocus = false;
        this.pattern = undefined;
        this.maxLength = 255;
        this.patternError = '';
        this.requiredError = '';
        this.maxValue = undefined;
        this.minValue = undefined;
        this.value = undefined;
        this.error = '';
    }
    handleDefaultValueChange(newValue) {
        this.value = sanitize(newValue);
        if (this.value) {
            this.validatePattern(this.value);
        }
    }
    componentDidLoad() {
        this.value = sanitize(this.defaultValue || '');
        if (this.type !== 'text' && !this.pattern) {
            this.pattern = DefaultPattern[this.type];
        }
        if (this.value) {
            this.validatePattern(this.value);
        }
    }
    handleBookingFormSubmitted(event) {
        this.validatePattern(this.value);
        if (this.error) {
            event.preventDefault();
        }
    }
    async handleFormSubmitted(event) {
        if (this.el?.getAttribute('data-page-styling')) {
            this.validatePattern(this.value);
            if (this.error) {
                event.preventDefault();
            }
        }
    }
    handleInput(e) {
        this.error = '';
        const inputValue = e.target.value;
        if (this.type === 'number') {
            const numericValue = parseFloat(inputValue);
            if ((this.maxValue !== undefined && numericValue > this.maxValue) || (this.minValue !== undefined && numericValue < this.minValue)) {
                if (this.minValue === undefined) {
                    this.error = `Value must be less than ${this.maxValue}`;
                }
                else if (this.maxValue === undefined) {
                    this.error = `Value must be greater than ${this.minValue}`;
                }
                else {
                    this.error = `Value must be between ${this.minValue} and ${this.maxValue}`;
                }
            }
            else if (isNaN(numericValue)) {
                this.error = this.patternError || 'Invalid format.';
            }
        }
        this.value = sanitize(inputValue);
        this.nylasFormInputChanged.emit({
            value: this.value,
            name: this.name,
            label: this.label,
            error: this.error,
            type: this.type,
        });
    }
    handleBlur() {
        this.nylasFormInputBlurred.emit({
            value: this.value,
            name: this.name,
        });
    }
    handleFocus() {
        this.nylasFormInputFocused.emit({
            value: this.value,
            name: this.name,
        });
    }
    validatePattern(value) {
        this.error = '';
        if (this.required && !value) {
            this.error = this.requiredError || 'This field is required.';
            return;
        }
        if (this.type === 'number' && value) {
            const numericValue = parseFloat(value);
            if ((this.maxValue !== undefined && numericValue > this.maxValue) || (this.minValue !== undefined && numericValue < this.minValue)) {
                this.error = `Value must be between ${this.minValue} and ${this.maxValue}`;
                return;
            }
        }
        if (this.pattern && value && !this.pattern.test(value)) {
            this.error = this.patternError || 'Invalid format.';
        }
    }
    render() {
        return (h("label", { key: 'e497e200e704ef9eb22c79f0279b6b83a0a7c6b0', part: this.error ? 'ic__label ic__label--error' : 'ic__label', class: { error: !!this.error } }, this.label && (h("p", null, h("span", { class: "label" }, this.label), this.required && h("span", { class: "required" }, "*"))), h("div", { key: '989b4c98b0b91f3395cb5d746b8c34b4860b91a5', part: "ic__input_wrapper", class: "input_wrapper" }, h("input", { key: 'c78151f2f4725d01eb78275580d70ccec7554467', type: this.type, name: this.name, part: this.error ? 'ic__input ic__input--error' : 'ic__input', title: this.readOnly ? 'read-only field' : undefined, readOnly: this.readOnly, autoFocus: this.autoFocus, value: this.value, maxLength: this.maxLength, max: this.type === 'number' ? this.maxValue : undefined, min: this.type === 'number' ? this.minValue : undefined, placeholder: this.placeholder, class: { error: !!this.error }, onInput: e => this.handleInput(e), onFocus: () => this.handleFocus(), onBlur: () => this.handleBlur() }), h("slot", { key: '91d6020c7b7d57fc51842bb6bd9716f304369cc9', name: "additional-input" })), this.error && (h("span", { class: "error help-text", part: "ic__error_message" }, this.error))));
    }
    static get is() { return "input-component"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["input-component.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["input-component.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The name of the input. This is used to identify the input when submitting a form."
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'input'"
            },
            "defaultValue": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The default value of the input. This is the value that is displayed when the input is rendered."
                },
                "attribute": "default-value",
                "reflect": false
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The label of the input. This is displayed above the input."
                },
                "attribute": "label",
                "reflect": false,
                "defaultValue": "''"
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'text' | 'email' | 'phone_number' | 'number'",
                    "resolved": "\"email\" | \"number\" | \"phone_number\" | \"text\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The type of the input. This is used to determine the input's behavior.\nSupported types are 'text', 'email', and 'phone_number'."
                },
                "attribute": "type",
                "reflect": false,
                "defaultValue": "'text'"
            },
            "placeholder": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The placeholder of the input. This is displayed when the input is empty."
                },
                "attribute": "placeholder",
                "reflect": false,
                "defaultValue": "DefaultPlaceholder[this.type]"
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the input is required. If true, the input must have a value when submitting a form.\nDefault is false. If the input is required and the value is empty, an error message is displayed."
                },
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            },
            "readOnly": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the input is read-only. If true, the input cannot be edited.\nDefault is false."
                },
                "attribute": "read-only",
                "reflect": false,
                "defaultValue": "false"
            },
            "autoFocus": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the input should be focused when rendered.\nDefault is false. If true, the input is focused when rendered.\nUse this to set the focus on the first input in a form."
                },
                "attribute": "auto-focus",
                "reflect": false,
                "defaultValue": "false"
            },
            "pattern": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "RegExp",
                    "resolved": "RegExp | undefined",
                    "references": {
                        "RegExp": {
                            "location": "global",
                            "id": "global::RegExp"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The pattern to validate the input value. If the value does not match the pattern, an error message is displayed.\nDefault is null. If the pattern is not set, the pattern is determined by the input type for 'email' and 'phone_number'."
                }
            },
            "maxLength": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The maximum length of the input value. If the value is longer than the maximum length, an error message is displayed.\nDefault is 255."
                },
                "attribute": "max-length",
                "reflect": false,
                "defaultValue": "255"
            },
            "patternError": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The error message to display when the value does not match the pattern.\nDefault is 'Invalid <field> format.' where <field> is the input label."
                },
                "attribute": "pattern-error",
                "reflect": false,
                "defaultValue": "''"
            },
            "requiredError": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "This error message is displayed when the input value is empty and the input is required."
                },
                "attribute": "required-error",
                "reflect": false,
                "defaultValue": "''"
            },
            "maxValue": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "max-value",
                "reflect": false
            },
            "minValue": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "min-value",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "value": {},
            "error": {}
        };
    }
    static get events() {
        return [{
                "method": "nylasFormInputChanged",
                "name": "nylasFormInputChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the input value is changed.\nThe scheduling form listens for this event to validate the input value and submit the form.\nIf using outside of the scheduling form, listen for this event to validate the input value\nand handle the input value change."
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n    label: string;\n    type: string;\n    error: string;\n  }",
                    "resolved": "{ value: string; name: string; label: string; type: string; error: string; }",
                    "references": {}
                }
            }, {
                "method": "nylasFormInputFocused",
                "name": "nylasFormInputFocused",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n  }",
                    "resolved": "{ value: string; name: string; }",
                    "references": {}
                }
            }, {
                "method": "nylasFormInputBlurred",
                "name": "nylasFormInputBlurred",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n  }",
                    "resolved": "{ value: string; name: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "defaultValue",
                "methodName": "handleDefaultValueChange"
            }];
    }
    static get listeners() {
        return [{
                "name": "bookingFormSubmitted",
                "method": "handleBookingFormSubmitted",
                "target": "document",
                "capture": false,
                "passive": false
            }, {
                "name": "formSubmitted",
                "method": "handleFormSubmitted",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=input-component.js.map
