import { expect } from "@playwright/test";
import { test } from "@stencil/playwright";
test.setTimeout(30000);
test.describe('nylas-availability-picker', () => {
    async function waitForComponentReady(page) {
        await page.waitForSelector('nylas-availability-picker.hydrated', { timeout: 15000 });
        await page.waitForTimeout(1000);
    }
    test('should render and be hydrated', async ({ page }) => {
        await page.setContent(`<form id="availability-picker">
        <nylas-availability-picker name="availability"></nylas-availability-picker>
      </form>`);
        const component = page.locator('nylas-availability-picker');
        await expect(component).toBeVisible();
        await expect(component).toHaveClass(/hydrated/);
    });
    test('should render availability days', async ({ page }) => {
        await page.setContent(`<form id="availability-picker">
      <nylas-availability-picker name="availability"></nylas-availability-picker>
    </form>`);
        await waitForComponentReady(page);
        const availabilityDays = page.locator('nylas-availability-picker >> .availability-day');
        await expect(availabilityDays).toHaveCount(7);
    });
    test('should have correct default checked days', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const checkedDays = page.locator('nylas-availability-picker >> .availability-day input[type="checkbox"]:checked');
        await expect(checkedDays).toHaveCount(5);
    });
    test('should correctly mark specific days in default state', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const dayCheckboxes = page.locator('nylas-availability-picker >> .availability-day input[type="checkbox"]');
        await expect(dayCheckboxes.nth(0)).not.toBeChecked();
        await expect(dayCheckboxes.nth(1)).toBeChecked();
        await expect(dayCheckboxes.nth(2)).toBeChecked();
        await expect(dayCheckboxes.nth(3)).toBeChecked();
        await expect(dayCheckboxes.nth(4)).toBeChecked();
        await expect(dayCheckboxes.nth(5)).toBeChecked();
        await expect(dayCheckboxes.nth(6)).not.toBeChecked();
    });
    test('should display time inputs', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const timeInputs = page.locator('nylas-availability-picker >> .time-picker input');
        await expect(timeInputs.first()).toBeVisible();
    });
    test('should display and allow timezone selection', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const timezoneSelector = page.locator('nylas-availability-picker >> .select-timezone');
        await expect(timezoneSelector).toBeVisible();
        const timezoneButton = page.locator('nylas-availability-picker >> .select-timezone select-dropdown .dropdown button .selected-option');
        await expect(timezoneButton).toBeVisible();
        await timezoneButton.click();
        const timezoneInput = page.locator('nylas-availability-picker >> .select-timezone select-dropdown .dropdown-content input[type="text"]');
        await timezoneInput.type('Vancouver');
        const timezoneLi = page.locator('nylas-availability-picker >> .select-timezone select-dropdown .dropdown-content ul li').first();
        await timezoneLi.click();
        await expect(timezoneButton).toContainText('America / Vancouver');
    });
    test('should allow selecting and unselecting days', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const sundayCheckbox = page.locator('nylas-availability-picker >> .availability-day input[type="checkbox"]').first();
        await expect(sundayCheckbox).not.toBeChecked();
        await sundayCheckbox.click();
        await expect(sundayCheckbox).toBeChecked();
        await sundayCheckbox.click();
        await expect(sundayCheckbox).not.toBeChecked();
    });
    test('should allow updating time ranges', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const mondayStartTime = page
            .locator('nylas-availability-picker >> .availability-day')
            .nth(1)
            .locator('.time-ranges .time-range nylas-time-window-picker[id="MON:0_start"] .time-picker input');
        await expect(mondayStartTime).toHaveValue('09:00am');
        await mondayStartTime.click();
        await page.waitForSelector('.time-picker .times');
        const timeOption = page.locator('.time-picker .times li').filter({ hasText: '09:15am' });
        await timeOption.click();
        await expect(mondayStartTime).toHaveValue('09:15am');
        await mondayStartTime.click();
        await mondayStartTime.fill('01:00pm');
        const pmTimeOption = page.locator('.time-picker .times li').filter({ hasText: '01:00pm' });
        await pmTimeOption.click();
        await expect(mondayStartTime).toHaveValue('01:00pm');
    });
    test('should have correct default time ranges', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const mondayStartTime = page
            .locator('nylas-availability-picker >> .availability-day')
            .nth(1)
            .locator('.time-ranges .time-range nylas-time-window-picker[id="MON:0_start"] .time-picker input');
        const mondayEndTime = page
            .locator('nylas-availability-picker >> .availability-day')
            .nth(1)
            .locator('.time-ranges .time-range nylas-time-window-picker[id="MON:0_end"] .time-picker input');
        await expect(mondayStartTime).toHaveValue('09:00am');
        await expect(mondayEndTime).toHaveValue('05:00pm');
    });
    test('should allow adding and removing time ranges', async ({ page }) => {
        await page.setContent(`<nylas-availability-picker></nylas-availability-picker>`);
        await waitForComponentReady(page);
        const monday = page.locator('nylas-availability-picker >> .availability-day').nth(1);
        await monday.waitFor({ state: 'visible' });
        await expect(monday.locator('.time-range')).toHaveCount(1);
        const addButton = monday.locator('button[part="nap__add-time-range"]');
        await addButton.waitFor({ state: 'visible' });
        await addButton.click();
        await expect(monday.locator('.time-range')).toHaveCount(2);
        const removeButton = monday.locator('.time-range').nth(1).locator('button:has(close-icon)');
        await removeButton.waitFor({ state: 'visible' });
        await removeButton.click();
        await expect(monday.locator('.time-range')).toHaveCount(1);
    });
    test('should update form value when changes are made', async ({ page }) => {
        await page.setContent(`
      <form id="availability-picker">
        <nylas-availability-picker name="availability"></nylas-availability-picker>
      </form>
    `);
        await waitForComponentReady(page);
        const form = page.locator('#availability-picker');
        const picker = page.locator('nylas-availability-picker');
        await page.waitForTimeout(1000);
        const sundayCheckbox = picker.locator('.availability-day input[type="checkbox"]').first();
        await sundayCheckbox.waitFor({ state: 'visible' });
        await sundayCheckbox.click();
        await page.waitForTimeout(1000);
        const formData = await form.evaluate(form => {
            const data = new FormData(form).get('availability');
            try {
                const parsed = data ? JSON.parse(data) : null;
                return parsed;
            }
            catch (e) {
                return null;
            }
        });
        expect(formData).toBeTruthy();
        expect(formData.openHours).toBeDefined();
        expect(formData.openHours.some(h => h.days.includes(0))).toBe(true);
    });
});
//# sourceMappingURL=nylas-availability-picker.e2e.playwright.js.map
