import { NylasBaseProvider } from "../../../common/abstract-provider";
import { NylasIdentityRequestWrapper } from "../../../common/nylas-api-request";
import { NylasSchedulerConfigConnector } from "../../../connector/nylas-scheduler-config-connector/index";
import { CreateNylasSchedulerConfigStore } from "../../../stores/scheduler-config-store";
import { debug } from "../../../utils/utils";
import { NylasSessions } from "@nylas/identity";
import { Host, h } from "@stencil/core";
import { LoginRequired } from "./LoginRequired";
import ExpressFlow from "./ExpressFlow";
import i18next from "../../../utils/i18n";
import { CONFIGURATION_EVENT_TYPE, LANGUAGE_CODE, LANGUAGE_MAP } from "../../../common/constants";
export class NylasSchedulerEditor {
    constructor() {
        this.handleSchedulerConfigCloseClicked = (_event) => {
            const event = this.schedulerConfigCloseClicked.emit(this.host);
            if ('schedulerConfigCloseClicked' in this.eventOverrides) {
                this.eventOverrides.schedulerConfigCloseClicked(event, this.nylasSchedulerConfigConnector);
            }
            if (!event.defaultPrevented) {
                localStorage.removeItem('grant');
                localStorage.removeItem('user');
                window.location.reload();
            }
        };
        this.authenticationUrl = async (provider) => {
            if (!this.nylasApiRequest) {
                console.error(`[nylas-scheduler-editor] Nylas API Request is not initialized.`);
                return '';
            }
            const url = await this.nylasApiRequest.authenticationUrl({ provider });
            return url || '';
        };
        this.configurationId = undefined;
        this.nylasApiRequest = undefined;
        this.nylasSessionsConfig = undefined;
        this.defaultAuthArgs = undefined;
        this.eventOverrides = {};
        this.schedulerPreviewLink = '';
        this.defaultSchedulerConfigState = undefined;
        this.mode = 'app';
        this.additionalParticipants = undefined;
        this.hideEditorTabs = [];
        this.conferenceProviders = undefined;
        this.requiresSlug = false;
        this.enableUserFeedback = true;
        this.defaultLanguage = undefined;
        this.localization = undefined;
        this.nylasBranding = true;
        this.experimentalFeatures = undefined;
        this.enableEventTypes = {
            one_on_one: true,
            collective: true,
            max_fairness: true,
            max_availability: true,
            group: true,
        };
        this.automaticComponentRegistration = true;
        this.selectedLanguage = this.defaultLanguage || LANGUAGE_CODE.en;
        this.langVersion = 0;
        this.version = process.env.PACKAGE_VERSION || 'unknown';
    }
    connectedCallback() {
        debug(`[nylas-scheduler-editor] connectedCallback`);
    }
    async componentWillLoad() {
        debug(`[nylas-scheduler-editor] componentWillLoad`);
        const filteredAdditionalParticipants = this.additionalParticipants?.filter(participant => {
            const filteredCalendars = participant.calendars?.length > 0 ? participant.calendars.filter(calendar => calendar.id && calendar.name) : [];
            if (participant.name && participant.email && filteredCalendars.length > 0) {
                return {
                    name: participant.name,
                    email: participant.email,
                    calendars: filteredCalendars,
                };
            }
        });
        this.stores = {
            schedulerConfig: CreateNylasSchedulerConfigStore({
                ...this.defaultSchedulerConfigState,
                additionalParticipants: filteredAdditionalParticipants,
                conferenceProviders: this.conferenceProviders,
                requiresSlug: this.requiresSlug,
                selectedLanguage: this.defaultLanguage || LANGUAGE_CODE.en,
                nylasBranding: this.nylasBranding,
                experimentalFeatures: this.experimentalFeatures,
                enableEventTypes: this.enableEventTypes,
            }),
        };
        if (!this.nylasApiRequest && this.nylasSessionsConfig) {
            const nylasSession = new NylasSessions(this.nylasSessionsConfig);
            await nylasSession.isLoggedIn();
            nylasSession.onLoginSuccess(async () => {
                const currentUser = await this.nylasSchedulerConfigConnector?.schedulerConfig?.currentUser();
                if (currentUser) {
                    const loggedInEvent = this.loggedIn.emit(this.host);
                    if ('loggedIn' in this.eventOverrides) {
                        await this.eventOverrides.loggedIn(loggedInEvent, this.nylasSchedulerConfigConnector);
                    }
                    if (!loggedInEvent.defaultPrevented) {
                        await this.loggedInHandler(currentUser);
                    }
                }
            });
            nylasSession.onLoginFail(async () => {
                this.stores?.schedulerConfig?.set('currentUser', null);
                const loggedOutEvent = this.loggedOut.emit(this.host);
                if ('loggedOut' in this.eventOverrides) {
                    await this.eventOverrides.loggedOut(loggedOutEvent, this.nylasSchedulerConfigConnector);
                    if (loggedOutEvent.defaultPrevented) {
                        return;
                    }
                }
            });
            this.nylasApiRequest = new NylasIdentityRequestWrapper(nylasSession);
        }
        if (this.nylasApiRequest && this.defaultAuthArgs) {
            this.nylasApiRequest.setDefaultAuthArgs(this.defaultAuthArgs);
        }
        this.baseProvider = new NylasBaseProvider(this.host, this.stores, this.automaticComponentRegistration, this.eventOverrides);
        const nylasSchedulerConfigStore = this.baseProvider.getStore('schedulerConfig');
        this.nylasSchedulerConfigConnector = new NylasSchedulerConfigConnector({
            nylasApiRequest: this.nylasApiRequest,
            nylasSchedulerConfigStore: nylasSchedulerConfigStore,
        });
        const initEvent = this.init.emit(this.host);
        if ('init' in this.eventOverrides) {
            await this.eventOverrides.init(initEvent, this.nylasSchedulerConfigConnector);
        }
        if (!initEvent.defaultPrevented) {
            const currentUser = await this.nylasSchedulerConfigConnector?.schedulerConfig?.currentUser();
            if (currentUser) {
                const loggedInEvent = this.loggedIn.emit(this.host);
                if ('loggedIn' in this.eventOverrides) {
                    await this.eventOverrides.loggedIn(loggedInEvent, this.nylasSchedulerConfigConnector);
                }
                if (!loggedInEvent.defaultPrevented) {
                    await this.loggedInHandler(currentUser);
                }
            }
            else {
                this.stores?.schedulerConfig?.set('currentUser', null);
                const loggedOutEvent = this.loggedOut.emit(this.host);
                if ('loggedOut' in this.eventOverrides) {
                    await this.eventOverrides.loggedOut(loggedOutEvent, this.nylasSchedulerConfigConnector);
                    if (loggedOutEvent.defaultPrevented) {
                        return;
                    }
                }
            }
        }
        this.stores?.schedulerConfig?.onChange('selectedConfiguration', async (config) => {
            if (config && config.id) {
                this.configurationId = config.id;
            }
        });
        this.baseProvider?.componentWillLoad(this.nylasSchedulerConfigConnector);
    }
    async componentDidLoad() {
        debug(`[nylas-scheduler-editor] componentDidLoad`);
        await this.baseProvider?.componentDidLoad();
        this.updateLocalization(this.localization);
        this.version = process.env.PACKAGE_VERSION || 'unknown';
    }
    async componentDisconnected() {
        await this.baseProvider?.componentDisconnected();
    }
    async configurationIdChanged(newConfigurationId) {
        if (newConfigurationId) {
            await this.nylasSchedulerConfigConnector?.schedulerConfig?.getConfigurationById(newConfigurationId);
            this.stores?.schedulerConfig?.set('action', 'edit');
        }
        else {
            this.stores?.schedulerConfig?.set('selectedConfiguration', {});
            this.stores?.schedulerConfig?.set('action', null);
        }
    }
    updateLocalization(newVal) {
        if (!newVal) {
            return;
        }
        Object.keys(newVal).forEach(lang => {
            if (!(lang in LANGUAGE_CODE)) {
                return;
            }
            i18next.addResourceBundle(lang, 'translation', newVal[lang], false, true);
        });
        this.langVersion++;
    }
    updateNylasBranding(newVal) {
        this.stores?.schedulerConfig?.set('nylasBranding', newVal);
    }
    updateExperimentalFeatures(newVal) {
        this.stores?.schedulerConfig?.set('experimentalFeatures', newVal);
    }
    updateEnableEventTypes(newVal) {
        this.stores?.schedulerConfig?.set('enableEventTypes', newVal);
    }
    async store() {
        return this.stores?.schedulerConfig;
    }
    async schedulerConnector() {
        return this.nylasSchedulerConfigConnector;
    }
    async registerComponentHandler(event) {
        this.baseProvider?.registerComponent(event.detail);
    }
    async unregisterComponentHandler(event) {
        this.baseProvider?.unregisterComponent(event.detail);
    }
    nylasFormDropdownChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'language') {
            this.selectedLanguage = LANGUAGE_CODE[value];
            i18next.changeLanguage(this.selectedLanguage);
            this.stores?.schedulerConfig?.set('selectedLanguage', this.selectedLanguage);
        }
    }
    async loggedInHandler(currentUser) {
        this.stores?.schedulerConfig?.set('currentUser', currentUser);
        if (!this.nylasSchedulerConfigConnector) {
            return;
        }
        await this.nylasSchedulerConfigConnector.schedulerConfig?.getCalendars();
        if (this.configurationId) {
            const data = await this.nylasSchedulerConfigConnector.schedulerConfig?.getConfigurationById(this.configurationId);
            if (data && data[0]?.id) {
                this.stores?.schedulerConfig?.set('action', 'edit');
            }
        }
    }
    render() {
        const hasSlot = this.host.querySelector('[slot="custom-page-style-inputs"]');
        const selectedConfigId = this.stores?.schedulerConfig?.state.selectedConfiguration?.id;
        const languageOptions = Object.keys(LANGUAGE_MAP).map(key => ({
            label: LANGUAGE_MAP[key],
            value: key,
        }));
        const isGroupType = this.stores?.schedulerConfig?.state.selectedEventType === CONFIGURATION_EVENT_TYPE.group ||
            this.stores?.schedulerConfig?.state.selectedConfiguration?.type === CONFIGURATION_EVENT_TYPE.group;
        return (h(Host, { key: 'f2ff98b69f59cf94f68e0a72750db304d5f5781c' }, h("div", { key: '382bac7a0ba7735ce0c6704f825d8a18a3faf412', class: "scheduler-editor-header", part: "nse__header" }, h("h1", { key: 'eb011947ed70b8f7b2bd73a1d57c8de743782acd', class: "scheduler-editor-title", part: "nse__title" }, h("calendar-icon", { key: 'd6a3bdf5d3c7501e865c363a58cbfd78b9ee10b1', width: "18", height: "18" }), i18next.t('schedulerEditorTitle'), h("tooltip-component", { key: 'd2cde09b0b5ac91a306d81dba57838ce373cda92' }, h("info-icon", { key: 'af00e8fa6ca5ef8baaaf5a9abdf14a7138b030fd', slot: "tooltip-icon" }), h("span", { key: '24a185bac54f44abf7ffe9bf3cd2723dc363a12f', slot: "tooltip-content" }, this.version))), h("div", { key: '6fdf10c991b049d0a96a09faddf056de7b80a1de', class: {
                language: true,
            }, part: "nse__language" }, h("select-dropdown", { key: 'd733d65ad4fd639f94b5fde41ae32725949fe429', name: "language", searchPlaceholder: i18next.t('search'), options: languageOptions, withChevron: false, defaultSelectedOption: languageOptions.find(lang => lang.value == this.selectedLanguage), exportparts: "sd_dropdown: nse__language-dropdown, sd_dropdown-button: nse__language-drop-button, sd_dropdown-content: nse__language-drop-content, sd_dropdown_label: nse__language-drop-label" }, h("span", { key: '9ae3abafd8aa09ec54f70c9d950eb1569eff6870', slot: "select-icon" }, h("translate-icon", { key: 'e435ec08d11c784caca91cf97887e261409b559b', width: "20", height: "20" })))), h("button", { key: '2bd03fa6333f11f3da17f8ce1db6516a4f936a6f', class: "scheduler-editor-close", title: "logout", onClick: e => this.handleSchedulerConfigCloseClicked(e), part: "nse__close-button" }, h("close-icon", { key: 'b7e1ab191b7bfd4c892e101c5662ebeb42ad67a2', width: "18", height: "18" }))), h("div", { key: '3a19a2dde27979aa7428a388e68b9eb8c8d266a2', class: {
                'scheduler-editor-content': true,
                'scheduler-editor-content--group': isGroupType,
            }, part: "nse__content" }, this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === null && (h("div", { class: "list-configurations", part: "nse__list-configurations" }, h("nylas-list-configurations", { exportparts: "nlc__create-new-cta, actions__dropdown,  actions__dropdown-button, actions__dropdown-content, actions-Copy, actions-Preview, actions-Delete" }))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'create-select' && h("nylas-select-event-type", null), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'create' && isGroupType && (h("nylas-editor-tabs-group", { mode: "composable" }, h(ExpressFlow, { selectedEventType: this.stores?.schedulerConfig?.state?.selectedEventType || CONFIGURATION_EVENT_TYPE.one_on_one, currentUser: this.stores?.schedulerConfig?.state.currentUser, calendars: this.stores?.schedulerConfig?.state?.calendars, selectedConfiguration: this.stores?.schedulerConfig?.state?.selectedConfiguration }))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'create' && !isGroupType && (h("nylas-editor-tabs", { mode: "composable" }, h(ExpressFlow, { selectedEventType: this.stores?.schedulerConfig?.state?.selectedEventType || CONFIGURATION_EVENT_TYPE.one_on_one, currentUser: this.stores?.schedulerConfig?.state.currentUser, calendars: this.stores?.schedulerConfig?.state?.calendars, selectedConfiguration: this.stores?.schedulerConfig?.state?.selectedConfiguration }))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'edit' && isGroupType && (h("nylas-editor-tabs-group", { key: selectedConfigId, mode: this.mode }, this.mode === 'composable' && h("slot", null), this.mode === 'app' && hasSlot && (h("div", { style: { display: 'none' }, slot: "custom-page-style-inputs", key: selectedConfigId }, h("slot", { name: "custom-page-style-inputs" }))))), this.stores?.schedulerConfig?.state.currentUser && this.stores.schedulerConfig.state.action === 'edit' && !isGroupType && (h("nylas-editor-tabs", { key: selectedConfigId, mode: this.mode }, this.mode === 'composable' && h("slot", null), this.mode === 'app' && hasSlot && (h("div", { style: { display: 'none' }, slot: "custom-page-style-inputs", key: selectedConfigId }, h("slot", { name: "custom-page-style-inputs" }))))), !this.stores?.schedulerConfig?.state.currentUser && (h("slot", { name: "login-required" }, h(LoginRequired, { authenticationUrl: this.authenticationUrl }))))));
    }
    static get is() { return "nylas-scheduler-editor"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-scheduler-editor.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-scheduler-editor.css"]
        };
    }
    static get properties() {
        return {
            "configurationId": {
                "type": "string",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "*\nThe configuration id to use for the scheduler editor.\nIf provided, then the scheduler editor will try and fetch the configuration\nwith the provided id. If found, it will automatically load the editor\nwith the configuration settings for editing."
                },
                "attribute": "configuration-id",
                "reflect": false
            },
            "nylasApiRequest": {
                "type": "unknown",
                "mutable": true,
                "complexType": {
                    "original": "NylasApiRequest",
                    "resolved": "NylasApiRequest | undefined",
                    "references": {
                        "NylasApiRequest": {
                            "location": "import",
                            "path": "@/common/nylas-api-request",
                            "id": "src/common/nylas-api-request.ts::NylasApiRequest"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The Nylas Api Request instance.\nUsed to make requests to the Nylas API."
                }
            },
            "nylasSessionsConfig": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Config",
                    "resolved": "Config | undefined",
                    "references": {
                        "Config": {
                            "location": "import",
                            "path": "@nylas/identity",
                            "id": "../nylas-identity/esm/index.d.ts::Config"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The Nylas Sessions configuration.\nUsed to configure the Nylas Sessions instance."
                }
            },
            "defaultAuthArgs": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "AuthArgs[]",
                    "resolved": "AuthArgs[] | undefined",
                    "references": {
                        "AuthArgs": {
                            "location": "import",
                            "path": "@/common/nylas-api-request",
                            "id": "src/common/nylas-api-request.ts::AuthArgs"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The default authentication arguments to use when authenticating a user."
                }
            },
            "eventOverrides": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "SchedulerEditorEventOverride",
                    "resolved": "Partial<{ nylasSchedulerError: (event: CustomEvent<{ notification: Notification; host: HTMLElement; } | { notification: Notification; host: HTMLElement; }>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; formSubmitted: (event: CustomEvent<void>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; schedulerConfigChanged: (event: CustomEvent<SchedulerEventDetail>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; schedulerConfigCreated: (event: CustomEvent<SchedulerEventDetail>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; cancelButtonClick: (event: CustomEvent<void>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; previewButtonClicked: (event: CustomEvent<HTMLNylasEditorTabsElement>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; schedulerEditorFormUpdated: (event: CustomEvent<{ value: string; name: string; }>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; dismissNotification: (event: CustomEvent<{ id: string; host: HTMLNylasEditorTabsElement; } | { id: string; host: HTMLNylasListConfigurationsElement; }>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; initListConfigurations: (event: CustomEvent<{ host: HTMLNylasListConfigurationsElement; cursor?: string | undefined; }>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; createButtonClick: (event: CustomEvent<HTMLNylasListConfigurationsElement>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; editButtonClick: (event: CustomEvent<{ host: HTMLNylasListConfigurationsElement; configuration: Configuration | GroupConfiguration; }>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; deleteButtonClick: (event: CustomEvent<{ host: HTMLNylasListConfigurationsElement; configuration: Configuration | GroupConfiguration; }>, connector?: NylasSchedulerConfigConnectorInterface | undefined) => Promise<void>; }> & EventOverride<NylasSchedulerConfigConnectorInterface>",
                    "references": {
                        "SchedulerEditorEventOverride": {
                            "location": "import",
                            "path": "@/common/component-types",
                            "id": "src/common/component-types.ts::SchedulerEditorEventOverride"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "This provides a way to override the default event handlers."
                },
                "defaultValue": "{}"
            },
            "schedulerPreviewLink": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The scheduler preview link used when the user clicks the preview button.\nIf `requiresSlug` is true, you can use the placeholder `{slug}` to insert the slug in the link for Nylas hosted scheduling pages.\nAdditionally, you can use the placeholder `{config.id}` to insert the configuration ID anywhere in the link.\nFor example: `https://book.nylas.com/us/<YOUR_NYLAS_APP_CLIENT_ID>/{slug}`.\n`us` denotes the region. Replace it with the appropriate region of your application.\nReplace `<YOUR_NYLAS_APP_CLIENT_ID>` with your Nylas app client ID.\nNote: Nylas hosted scheduling pages are only available for public configurations."
                },
                "attribute": "scheduler-preview-link",
                "reflect": false,
                "defaultValue": "''"
            },
            "defaultSchedulerConfigState": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Partial<NylasSchedulerConfigStoreState>",
                    "resolved": "undefined | { selectedConfiguration?: RecursivePartial<Configuration> | RecursivePartial<GroupConfiguration> | undefined; configurations?: Configuration[] | undefined; calendars?: Calendar[] | undefined; currentUser?: User | null | undefined; action?: \"create\" | \"create-select\" | \"edit\" | null | undefined; additionalParticipants?: AdditionalParticipant[] | undefined; listConfigurationsNextCursor?: string | null | undefined; conferenceProviders?: Record<\"google\" | \"zoom\" | \"microsoft\", string> | undefined; requiresSlug?: boolean | undefined; selectedLanguage?: string | undefined; nylasBranding?: boolean | undefined; experimentalFeatures?: Record<EXPERIMENTAL_FEATURES, boolean> | undefined; enableEventTypes?: EnableEventTypes | undefined; selectedEventType?: CONFIGURATION_EVENT_TYPE | undefined; groupEvents?: GroupEventAPIData[] | undefined; selectedGroupEvent?: GroupEventAPIData | undefined; calendarViewDateRange?: { start_time: string; end_time: string; } | undefined; masterGroupEvents?: Record<string, EventDetails> | undefined; isLoading?: boolean | undefined; }",
                    "references": {
                        "Partial": {
                            "location": "global",
                            "id": "global::Partial"
                        },
                        "NylasSchedulerConfigStoreState": {
                            "location": "import",
                            "path": "@/stores/scheduler-config-store",
                            "id": "src/stores/scheduler-config-store.ts::NylasSchedulerConfigStoreState"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The default scheduler config store state.\nUsed to set the initial state of the scheduler config store.\nThis state can be used to pass defaults to newly created configurations."
                }
            },
            "mode": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'app' | 'composable'",
                    "resolved": "\"app\" | \"composable\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "This is used to set the mode for the scheduler config.\nThe mode can be 'app' or 'composable'.\nThe default mode is 'app'."
                },
                "attribute": "mode",
                "reflect": false,
                "defaultValue": "'app'"
            },
            "additionalParticipants": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "AdditionalParticipant[]",
                    "resolved": "AdditionalParticipant[] | undefined",
                    "references": {
                        "AdditionalParticipant": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::AdditionalParticipant"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "This prop is used to populate the additional participants and\ntheir availability in the scheduler editor."
                }
            },
            "hideEditorTabs": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Tab[]",
                    "resolved": "Tab[] | undefined",
                    "references": {
                        "Tab": {
                            "location": "import",
                            "path": "../nylas-editor-tabs/tab-contents",
                            "id": "src/components/scheduler-editor/nylas-editor-tabs/tab-contents.tsx::Tab"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "This optional prop is used to hide tabs in the editor. Available tabs are:\neventInfo, availability, participants, bookingOptions, bookingForm"
                },
                "defaultValue": "[]"
            },
            "conferenceProviders": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Record<string, string>",
                    "resolved": "undefined | { [x: string]: string; }",
                    "references": {
                        "Record": {
                            "location": "global",
                            "id": "global::Record"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "This prop will be used to populate the conference provider options in the editor.\nThe key is the provider name ('zoom') and the value is the grant id.\nWe currently support same provider ('google', 'microsoft') for all participants and 'zoom' for cross-provider conferencing."
                }
            },
            "requiresSlug": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Indicates if a slug is required for the configuration.\nWhen set to true, the user must enter a slug when creating or editing a configuration.\nThe slug is used for hosted pages. If using Nylas hosted scheduling pages, the `schedulerPreviewLink` prop can be set to redirect to a public configuration as follows:\n`https://book.nylas.com/us/<YOUR_NYLAS_APP_CLIENT_ID>/{slug}`.\n`us` denotes the region. Replace it with the appropriate region of your application.\nReplace `<YOUR_NYLAS_APP_CLIENT_ID>` with your Nylas app client ID. The `{slug}` placeholder is replaced with the appropriate slug when the scheduler preview button is clicked.\nNote: Nylas hosted scheduling pages are only available for public configurations."
                },
                "attribute": "requires-slug",
                "reflect": false,
                "defaultValue": "false"
            },
            "enableUserFeedback": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Indicates if the user feedback feature is enabled.\nBy default, this is set to true. When enabled, the user feedback\nfeature will be available in the edit mode.\nTo disable the user feedback feature, set this prop to false."
                },
                "attribute": "enable-user-feedback",
                "reflect": false,
                "defaultValue": "true"
            },
            "defaultLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "This prop will allow to set a default language for the Nylas scheduling page."
                },
                "attribute": "default-language",
                "reflect": false
            },
            "localization": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Partial<Record<LANGUAGE_CODE, Locale>>",
                    "resolved": "undefined | { en?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; es?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; fr?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; de?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; sv?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; zh?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; ja?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; nl?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; ko?: Partial<{ noDateSelected: string; rescheduleTitle: string; allDay: string; today: string; spotsLeft: string; search: string; selectOneOrMoreOptions: string; days: Partial<{ sunday: string; monday: string; tuesday: string; wednesday: string; thursday: string; friday: string; saturday: string; }>; time: Partial<{ hour: string; hours: string; minute: string; minutes: string; day: string; days: string; week: string; weeks: string; month: string; months: string; year: string; years: string; }>; months: Partial<{ january: string; february: string; march: string; april: string; may: string; june: string; july: string; august: string; september: string; october: string; november: string; december: string; }>; multipleOptionsSelected: string; selectAtLeastOneOption: string; nextButton: string; selectedDayAndYear: string; selectedTime: string; name: string; namePlaceholder: string; email: string; emailPlaceholder: string; guestEmail: string; guestEmailPlaceholder: string; addGuest: string; addAnotherGuest: string; backButton: string; bookNowButton: string; bookingConfirmed: string; bookingConfirmedDescription: string; bookingSent: string; bookingSentDescription: string; bookingRescheduled: string; bookingDateAndTimeHeader: string; cancelBookingButton: string; rescheduleBookingButton: string; rejectBookingButton: string; confirmBookingButton: string; bookingPendingTitle: string; bookingPendingDescription: string; confirmedEventCardTitle: string; confirmedEventCardDescription: string; cancelBookingTitle: string; cancelBookingMessage: string; reasonForCancellation: string; goBackButton: string; bookingCancelledTitle: string; bookingCancelledMessage: string; bookingCancelledMessage_theParticipants: string; closeButton: string; closingButton: string; fieldRequired: string; invalidInputFormat: string; createBookingErrorTitle: string; getAvailabilityErrorTitle: string; cancelBookingErrorTitle: string; rescheduleBookingErrorTitle: string; getUISettingErrorTitle: string; rejectBookingErrorTitle: string; confirmBookingErrorTitle: string; genericErrorTitle: string; schedulingComponentErrorTitle: string; sessionIdRequiredErrorMessage: string; publicConfigErrorMessage: string; invalidTimeslotErrorTitle: string; invalidTimeslotErrorMessage: string; cancellationErrorTitle: string; cancellationErrorMessage: string; minimumCancellationErrorMessage: string; cancelBokingFormError: string; feedbackFormTitle: string; feedbackFormDescription: string; feedbackMessageLabel: string; feedbackMessagePlaceholder: string; feedbackModalCloseButton: string; feedbackModalSubmitButton: string; deleteSchedulingPageTitle: string; deleteSchedulingPageDescription: string; deleteSchedulingPageConfirmButton: string; deleteSchedulingPageCancelButton: string; schedulerEditorTitle: string; allSchedulingPages: string; createAndManageSchedulingPages: string; createNewSchedulingPageButtonText: string; pageTitle: string; durationTitle: string; loading: string; required: string; optional: string; loadingPagesDescription: string; noSchedulingPages: string; createFirstSchedulingPage: string; editSchedulingPageButtonText: string; eventInfoTab: string; availabilityTab: string; participantsTab: string; bookingOptionsTab: string; returnToCalendarView: string; bookingFormTab: string; communicationsTab: string; pageStylesTab: string; savingButtonText: string; saveChangesButtonText: string; createButtonText: string; timePeriod_day: string; timePeriod_week: string; timePeriod_month: string; timePeriod_year: string; timeDuration_minute: string; timeDuration_hour: string; eventCommunicationsTitle: string; eventCommunicationsDescription: string; unsavedChangesLabel: string; changesSavedLabel: string; fixFormErrors: string; pageSettingsButton: string; nylasEditorTabs: { bookingFormError: string; bookingFormError_label: string; bookingFormError_option: string; }; nylasListConfigurations: Partial<{ previewButtonText: string; copyLinkButtonText: string; deleteButtonText: string; }>; nylasAdditionalParticipants: Partial<{ headerTitle: string; headerSubTitle: string; organizerAsParticipant: string; organizer: string; participant: string; addParticipant_first: string; addParticipant_next: string; error: string; tooltip: { includeOrganizer: string; includeOrganizerDesc: string; excludeOrganizer: string; excludeOrganizerDesc: string; }; }>; nylasAvailabilityPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectTimezone: string; unavailable: string; days: Record<\"SUN\" | \"MON\" | \"TUE\" | \"WED\" | \"THU\" | \"FRI\" | \"SAT\", string>; }>; nylasTimeWindowPicker: Partial<{ errors: { invalid: string; }; }>; nylasBookingCalendarPicker: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; selectOptionLabel: string; selectCalendarErrorMessage: string; }>; nylasBookingConfirmationRedirect: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; redirectOption_default: string; redirectOption_custom: string; }>; nylasBookingConfirmationType: Partial<{ dropdownLabel: string; tooltip: { desc: string; }; bookingOption_booking: string; bookingOption_organizerConfirmation: string; }>; nylasBookingFormConfig: Partial<{ headerTitle: string; headerSubTitle: string; dropdownButtonText: string; addOption: string; allOptionsHeader: string; fieldInTitleError: string; fieldInDescriptionError: string; label: string; defaultValue: string; fieldType: { text: string; multi_line_text: string; email: string; phone_number: string; dropdown: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; fieldLabel: { your_name: string; your_email: string; email: string; phone_number: string; dropdown: string; text: string; multi_line_text: string; radio_button: string; checkbox: string; date: string; metadata: string; multi_select: string; }; }>; nylasBufferTime: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; beforeBufferLabel: string; afterBufferLabel: string; minutesShort: string; previewHeader: string; }>; nylasCalendarPicker: Partial<{ calendarPickerLabel: string; selectAtLeastOneCalendar: string; }>; nylasCancellationPolicy: Partial<{ cancellationPolicyLabel: string; tooltip: { desc: string; }; }>; nylasConfirmationEmail: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; error: { invalidImageUrl: string; }; confirmationEmail: { label: string; tooltip: { desc: string; language: string; }; language: string; }; nylasBranding: { label: string; tooltip: { desc: string; }; }; companyLogoUrl: { label: string; tooltip: { desc: string; }; }; emailMessage: { header: string; label: string; tooltip: { desc: string; }; additionalInfoLabel: string; additionalInfoTooltip: string; additionalInfoPlaceholder: string; }; allHosts: string; immediatelyUponBooking: string; }>; nylasConnectedCalendars: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; participantCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasCustomBookingFlow: Partial<{ headerTitle: string; }>; nylasCustomEventSlug: Partial<{ headerTitle: string; headerSubTitle: string; eventSlugLabel: string; tooltip: { desc: string; }; copied: string; }>; nylasCustomizeBookingSettings: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; allowGuests: { label: string; }; hideReschedule: { label: string; tooltip: { desc: string; }; }; hideCancel: { label: string; tooltip: { desc: string; }; }; }>; nylasEventDescription: Partial<{ headerTitle: string; addAdditionalFields: { buttonText: string; tooltip: { desc: string; }; }; tooltip: { desc: string; }; }>; nylasEventDuration: Partial<{ headerTitle: string; error: { durationMustBeMultipleOf5: string; durationMustBeGreaterThan0: string; }; }>; nylasEventInfo: Partial<{ headerTitle: string; }>; nylasEventLimits: Partial<{ headerTitle: string; }>; nylasEventLocation: Partial<{ headerTitle: string; tooltip: { desc: string; }; conferenceOptions: { none: string; zoom: string; google: string; microsoft: string; custom: string; }; }>; nylasEventTitle: Partial<{ headerTitle: string; helpText_start: string; helpText_end: string; title: string; description: string; tooltip: { desc: string; }; eventTitleRequired: string; eventTitleTokenDescription: { invitee: string; inviteeEmail: string; duration: string; }; }>; nylasLimitFutureBookings: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinBookingNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasMinCancellationNotice: Partial<{ headerTitle: string; tooltip: { desc: string; }; }>; nylasPageName: Partial<{ headerTitle: string; headerSubTitle: string; pageNameError: string; tooltip: { desc: string; }; }>; nylasPageStyling: Partial<{ headerTitle: string; }>; nylasParticipantBookingCalendars: Partial<{ headerTitle: string; headerSubTitle: string; participantBookingCalendarTitle: string; selectAtLeastOneCalendar: string; }>; nylasParticipantCustomAvailability: Partial<{ headerTitle: string; headerSubTitle: string; participantOpenHoursTitle: string; }>; nylasReminderEmails: Partial<{ headerTitle: string; headerSubTitle: string; editButtonText: string; recipientOptions_all: string; recipientOptions_guest: string; recipientOptions_host: string; beforeTheEvent: string; emailRecipients: { label: string; }; sendConfirmation: { label: string; tooltip: { desc: string; }; }; emailSubject: { label: string; placeholder: string; }; reminderMinutesValidationError: string; newReminderButtonText: string; }>; nylasSchedulingMethod: Partial<{ headerTitle: string; headerSubTitle: string; tooltip: { standard: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; }; schedulingMethodOptions_collective: string; schedulingMethodOptions_maxFairness: string; schedulingMethodOptions_maxAvailability: string; }>; nylasTimeslotInterval: Partial<{ headerTitle: string; minutesShort: string; lengthOfMeeting: string; timeslotInterval: { label: string; }; timeslotRounding: { label: string; tooltip: { desc: string; }; }; timeslotRoundingOptions: { rounding: { label: string; desc: string; }; noRounding: { label: string; desc: string; }; }; }>; nylasEventTimeslot: { recurrenceOptions: { none: string; daily: string; weekly: string; monthly: string; monthOnDay: string; yearly: string; custom: string; }; recurrenceLabel: string; endDate: string; customRecurrence: { repeatEvery: string; repeatOn: string; ends: string; endsOptions: { never: string; after: string; on: string; }; occurrences: string; }; dateTimeLabel: string; errors: { invalidTimeRange: string; startTimeSameAsEndTime: string; startTimeBeforeCurrentDate: string; invalid: string; }; }; nylasEventCapacity: { headerTitle: string; headerSubTitle: string; tooltip: { desc: string; }; attendees: string; }; nylasSelectEventType: { returnToAllSchedulingPages: string; createEventHeaderTitle: string; eventTypeHeaderTitle: string; noEventTypesEnabled: string; eventTypeOptions: { oneOnOne: { label: string; desc: string; }; collective: { label: string; desc: string; }; maxFairness: { label: string; desc: string; }; maxAvailability: { label: string; desc: string; }; group: { label: string; desc: string; }; }; }; nylasEventCalendar: { createEventDetails: { headerTitle: string; closeButtonTooltip: string; cancelButton: string; createButton: string; }; discardChanges: { headerTitle: string; cancelButton: string; discardButton: string; }; unsavedChanges: string; editEventDetails: { headerTitle: string; closeButtonTooltip: string; deleteButton: string; saveButton: string; pastEventTooltip: string; }; importEvent: { closeButtonTooltip: string; importButton: string; participantsLabel: string; }; deleteEvent: { closeButtonTooltip: string; deleting: string; }; editOptions: { headerTitle: string; closeButtonTooltip: string; deleting: string; import: string; edit: string; deleteThis: string; deleteAll: string; }; updateOptions: { updateThis: string; updateAll: string; updateFuture: string; }; deleteOptions: { deleteThis: string; deleteFuture: string; deleteAll: string; }; }; }> | undefined; }",
                    "references": {
                        "Partial": {
                            "location": "global",
                            "id": "global::Partial"
                        },
                        "Record": {
                            "location": "global",
                            "id": "global::Record"
                        },
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        },
                        "Locale": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::Locale"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "This prop will allow to override the default localization strings for each language.\nNylas scheduling page currently support the following language codes: en, es, fr, de, sv, zh, ja, nl."
                }
            },
            "nylasBranding": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "This prop will allow to show / hide the option to manage nylas branding in the email template.\nBy default, this is set to true. When enabled, the option to show/hide nylas branding will be shown in the email template.\nTo disable the option to show/hide nylas branding, set this prop to false."
                },
                "attribute": "nylas-branding",
                "reflect": false,
                "defaultValue": "true"
            },
            "experimentalFeatures": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Record<EXPERIMENTAL_FEATURES, boolean>",
                    "resolved": "undefined | { [x: number]: boolean; }",
                    "references": {
                        "Record": {
                            "location": "global",
                            "id": "global::Record"
                        },
                        "EXPERIMENTAL_FEATURES": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::EXPERIMENTAL_FEATURES"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "This prop is to opt in to experimental features.\nEx: { 'group_events': true }"
                }
            },
            "enableEventTypes": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "EnableEventTypes",
                    "resolved": "undefined | { one_on_one: boolean; collective: boolean; max_fairness: boolean; max_availability: boolean; group: boolean; }",
                    "references": {
                        "EnableEventTypes": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::EnableEventTypes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Controls which event types are enabled in the Scheduler.\n\n- By default, all event types are enabled and users will see a selection screen when creating a new event.\n- You can disable specific event types by setting them to `false`.\n- At least one event type must remain enabled at all times.\n- If only one event type is enabled, the event type selection screen will be skipped."
                },
                "defaultValue": "{\n    one_on_one: true,\n    collective: true,\n    max_fairness: true,\n    max_availability: true,\n    group: true,\n  }"
            }
        };
    }
    static get states() {
        return {
            "automaticComponentRegistration": {},
            "selectedLanguage": {},
            "langVersion": {},
            "version": {}
        };
    }
    static get events() {
        return [{
                "method": "init",
                "name": "init",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the provider is initialized.\nBy default, this event handles determining if the user is logged in or not.\nIn addition, it fetches the provided configuration if a valid configuration id is provided."
                },
                "complexType": {
                    "original": "HTMLNylasSchedulerEditorElement",
                    "resolved": "HTMLNylasSchedulerEditorElement",
                    "references": {
                        "HTMLNylasSchedulerEditorElement": {
                            "location": "global",
                            "id": "global::HTMLNylasSchedulerEditorElement"
                        }
                    }
                }
            }, {
                "method": "loggedIn",
                "name": "loggedIn",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the the NylasAuth isAuthenticated state changes\nto true."
                },
                "complexType": {
                    "original": "HTMLNylasSchedulerEditorElement",
                    "resolved": "HTMLNylasSchedulerEditorElement",
                    "references": {
                        "HTMLNylasSchedulerEditorElement": {
                            "location": "global",
                            "id": "global::HTMLNylasSchedulerEditorElement"
                        }
                    }
                }
            }, {
                "method": "loggedOut",
                "name": "loggedOut",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the the NylasAuth isAuthenticated state changes\nto false."
                },
                "complexType": {
                    "original": "HTMLNylasSchedulerEditorElement",
                    "resolved": "HTMLNylasSchedulerEditorElement",
                    "references": {
                        "HTMLNylasSchedulerEditorElement": {
                            "location": "global",
                            "id": "global::HTMLNylasSchedulerEditorElement"
                        }
                    }
                }
            }, {
                "method": "schedulerConfigCloseClicked",
                "name": "schedulerConfigCloseClicked",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the close button on scheduler config is clicked."
                },
                "complexType": {
                    "original": "HTMLNylasSchedulerEditorElement",
                    "resolved": "HTMLNylasSchedulerEditorElement",
                    "references": {
                        "HTMLNylasSchedulerEditorElement": {
                            "location": "global",
                            "id": "global::HTMLNylasSchedulerEditorElement"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "store": {
                "complexType": {
                    "signature": "() => Promise<NylasSchedulerConfigStoreType | undefined>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "NylasSchedulerConfigStoreType": {
                            "location": "import",
                            "path": "@/stores/scheduler-config-store",
                            "id": "src/stores/scheduler-config-store.ts::NylasSchedulerConfigStoreType"
                        }
                    },
                    "return": "Promise<CreateNylasSchedulerConfigStoreReturnType | undefined>"
                },
                "docs": {
                    "text": "This method is used to get the NylasSchedulerConfigStore instance.\nYou can use this instance to update or get the state of the store.",
                    "tags": [{
                            "name": "returns",
                            "text": "Promise<NylasSchedulerConfigStoreType | undefined>"
                        }]
                }
            },
            "schedulerConnector": {
                "complexType": {
                    "signature": "() => Promise<NylasSchedulerConfigConnector | undefined>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "NylasSchedulerConfigConnector": {
                            "location": "import",
                            "path": "@/connector/nylas-scheduler-config-connector",
                            "id": "src/connector/nylas-scheduler-config-connector/index.ts::NylasSchedulerConfigConnector"
                        }
                    },
                    "return": "Promise<NylasSchedulerConfigConnector | undefined>"
                },
                "docs": {
                    "text": "This method is used to get the NylasSchedulerConfigConnector instance.\nYou can use this instance to make requests to the Nylas API.",
                    "tags": [{
                            "name": "returns",
                            "text": "Promise<NylasSchedulerConfigConnector | undefined>"
                        }]
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "configurationId",
                "methodName": "configurationIdChanged"
            }, {
                "propName": "localization",
                "methodName": "updateLocalization"
            }, {
                "propName": "nylasBranding",
                "methodName": "updateNylasBranding"
            }, {
                "propName": "experimentalFeatures",
                "methodName": "updateExperimentalFeatures"
            }, {
                "propName": "enableEventTypes",
                "methodName": "updateEnableEventTypes"
            }];
    }
    static get listeners() {
        return [{
                "name": "registerComponent",
                "method": "registerComponentHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "unregisterComponent",
                "method": "unregisterComponentHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormDropdownChanged",
                "method": "nylasFormDropdownChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=nylas-scheduler-editor.js.map
