import { newSpecPage } from "@stencil/core/testing";
import { NylasSchedulerEditor } from "../nylas-scheduler-editor";
import { h } from "@stencil/core";
import { selectedConfiguration } from "../../../../utils/test-utils";
import { NylasListConfigurations } from "../../nylas-list-configurations/nylas-list-configurations";
import { NylasAvailabilityPicker } from "../../nylas-availability-picker/nylas-availability-picker";
class MockNylasApiRequest {
    constructor() {
        this.configs = [selectedConfiguration];
    }
    async request(args) {
        console.log('####args', args, args.path);
        switch (true) {
            case args.path === 'calendars?limit=50': {
                return [
                    {
                        data: [
                            {
                                id: '123',
                                name: 'John Doe',
                                email: 'johndoe@example.com',
                            },
                        ],
                    },
                    null,
                ];
            }
            case args.path === 'scheduling/configurations?limit=50': {
                return [
                    {
                        data: this.configs,
                    },
                    null,
                ];
            }
            case args.path === 'scheduling/configurations': {
                const newConfig = { ...this.configs[0], id: String(this.configs.length) };
                this.configs.push(newConfig);
                return [
                    {
                        data: newConfig,
                    },
                    null,
                ];
            }
            case args.path.startsWith('scheduling/configurations/'): {
                const config = this.configs.find(c => c.id === args.path.split('/')[2]);
                config.availability.availability_rules.default_open_hours = [
                    {
                        days: [1, 3],
                        timezone: 'America/Vancouver',
                        start: '09:00',
                        end: '17:00',
                    },
                    {
                        days: [4, 5],
                        timezone: 'America/Vancouver',
                        start: '08:00',
                        end: '16:00',
                    },
                ];
                return [
                    {
                        data: this.configs.find(c => c.id === args.path.split('/')[2]),
                    },
                    null,
                ];
            }
            default:
                return [
                    {
                        data: null,
                    },
                    null,
                ];
        }
    }
    async currentUser() {
        return {
            id: '123',
            email: 'johndoe@example.com',
            name: 'John Doe',
        };
    }
    async authenticationUrl() {
        return 'https://example.com/auth';
    }
    setDefaultAuthArgs(_args) { }
}
describe('nylas-scheduler-editor', () => {
    it('renders with mock API request', async () => {
        const mockNylasApiRequest = new MockNylasApiRequest();
        const page = await newSpecPage({
            components: [NylasSchedulerEditor],
            template: () => {
                return h("nylas-scheduler-editor", { nylasApiRequest: mockNylasApiRequest });
            },
        });
        await page.waitForChanges();
        expect(page.root).toBeTruthy();
        expect(page.root).toMatchSnapshot();
    });
    it('loads configurations on initialization', async () => {
        const mockNylasApiRequest = new MockNylasApiRequest();
        const page = await newSpecPage({
            components: [NylasSchedulerEditor, NylasListConfigurations],
            template: () => {
                return h("nylas-scheduler-editor", { nylasApiRequest: mockNylasApiRequest });
            },
        });
        await page.waitForChanges();
        expect(page.root).toBeTruthy();
        expect(page.root).toMatchSnapshot();
    });
    it('handles re-registration correctly', async () => {
        const mockNylasApiRequest = new MockNylasApiRequest();
        const page = await newSpecPage({
            components: [NylasSchedulerEditor, NylasAvailabilityPicker],
            template: () => {
                return (h("nylas-scheduler-editor", { mode: "composable", nylasApiRequest: mockNylasApiRequest, configurationId: "config-id" }, h("nylas-availability-picker", null)));
            },
        });
        await page.waitForChanges();
        expect(page.root).toBeTruthy();
        const availabilityPicker = page.root?.querySelector('nylas-availability-picker');
        expect(availabilityPicker).toBeTruthy();
        const tuesdayCheckbox = availabilityPicker?.shadowRoot?.querySelector('input#TUE');
        expect(tuesdayCheckbox.checked).toBeFalsy();
        const tuesdayTimeRanges = availabilityPicker?.shadowRoot?.querySelector('input#TUE')?.closest('.availability-day')?.querySelector('.time-ranges');
        const tuesdayUnavailable = tuesdayTimeRanges?.querySelector('.unavailable');
        expect(tuesdayUnavailable).toBeTruthy();
        expect(tuesdayUnavailable?.textContent?.trim()).toBe('Unavailable');
        const fridayCheckbox = availabilityPicker?.shadowRoot?.querySelector('input#FRI');
        expect(fridayCheckbox.checked).toBeTruthy();
        const fridayStartTime = availabilityPicker?.shadowRoot?.querySelector('#FRI\\:0_start');
        expect(fridayStartTime?.getAttribute('time')).toBe('08:00am');
        const fridayEndTime = availabilityPicker?.shadowRoot?.querySelector('#FRI\\:0_end');
        expect(fridayEndTime?.getAttribute('time')).toBe('04:00pm');
        const mondayCheckbox = availabilityPicker?.shadowRoot?.querySelector('input#MON');
        expect(mondayCheckbox.checked).toBeTruthy();
        const mondayStartTime = availabilityPicker?.shadowRoot?.querySelector('#MON\\:0_start');
        expect(mondayStartTime?.getAttribute('time')).toBe('09:00am');
        const mondayEndTime = availabilityPicker?.shadowRoot?.querySelector('#MON\\:0_end');
        expect(mondayEndTime?.getAttribute('time')).toBe('05:00pm');
    });
});
//# sourceMappingURL=nylas-scheduler-editor.spec.js.map
