import { newSpecPage } from "@stencil/core/testing";
import { NylasDatePicker } from "../nylas-date-picker";
import { h } from "@stencil/core";
describe('nylas-date-picker', () => {
    beforeEach(() => {
        jest.clearAllMocks();
    });
    it('renders correctly and generates dates for the current month', async () => {
        const page = await newSpecPage({
            components: [NylasDatePicker],
            html: `<nylas-date-picker></nylas-date-picker>`,
        });
        if (!page.root) {
            throw new Error('Component did not render.');
        }
        expect(page.rootInstance.dates.length).toBeGreaterThan(0);
    });
    it('emits dateSelected event with the correct date on date selection', async () => {
        const selectedDate = new Date();
        const page = await newSpecPage({
            components: [NylasDatePicker],
            html: `<nylas-date-picker></nylas-date-picker>`,
        });
        const spyEvent = jest.fn();
        page.win.addEventListener('dateSelected', spyEvent);
        page.rootInstance.selectDate(selectedDate);
        await page.waitForChanges();
        expect(spyEvent).toHaveBeenCalledWith(expect.objectContaining({ detail: selectedDate }));
    });
    it('changes the month and emits monthChanged event on month navigation', async () => {
        const page = await newSpecPage({
            components: [NylasDatePicker],
            html: `<nylas-date-picker></nylas-date-picker>`,
        });
        const spyEvent = jest.fn();
        page.win.addEventListener('monthChanged', spyEvent);
        const nextMonthButton = page?.root?.shadowRoot?.querySelector('.chevron-right');
        nextMonthButton.click();
        await page.waitForChanges();
        expect(spyEvent).toHaveBeenCalled();
        const currentMonth = new Date().getMonth();
        const expectedMonth = (currentMonth + 1) % 12;
        expect(page.rootInstance.month.getMonth()).toBe(expectedMonth);
    });
    it('disables dates not in selectableDates', async () => {
        const selectableDates = [new Date()];
        const page = await newSpecPage({
            components: [NylasDatePicker],
            html: `<nylas-date-picker></nylas-date-picker>`,
        });
        if (!page.root) {
            throw new Error('Component did not render.');
        }
        page.root.selectableDates = selectableDates;
        page.root.isLoading = false;
        await page.waitForChanges();
        const dates = page?.root?.shadowRoot?.querySelectorAll('button.date.current-month');
        const disabledDates = page?.root?.shadowRoot?.querySelectorAll('button.date.current-month[disabled]');
        expect(disabledDates.length).toBe(dates.length - selectableDates.length);
    });
    it('displays loading state and disables date selection', async () => {
        const page = await newSpecPage({
            components: [NylasDatePicker],
            html: `<nylas-date-picker is-loading="true"></nylas-date-picker>`,
        });
        await page.waitForChanges();
        const dates = page?.root?.shadowRoot?.querySelectorAll('button.date');
        const loadingDates = page?.root?.shadowRoot?.querySelectorAll('button.date.day-skeleton');
        const allDatesLoading = loadingDates.length === dates.length;
        expect(allDatesLoading).toBe(true);
    });
    it('displays the correct dates and month based on the selected date passed in defaultSchedulerState', async () => {
        const selectedDate = new Date(2119635000 * 1000);
        const selectableDates = [new Date(2119635000 * 1000), new Date(2119636800 * 1000), new Date(2119874400 * 1000)];
        const page = await newSpecPage({
            components: [NylasDatePicker],
            template: () => {
                return h("nylas-date-picker", { selectedDate: selectedDate, selectableDates: selectableDates });
            },
        });
        await page.waitForChanges();
        const dates = page?.root?.shadowRoot?.querySelectorAll('button.date.current-month');
        expect(dates.length).toBe(31);
        expect(page.rootInstance.month.getTime()).toBe(selectedDate.getTime());
        expect(page.root).toMatchSnapshot();
        const selectedDateButton = page?.root?.shadowRoot?.querySelector('button.selected');
        expect(selectedDateButton.textContent).toBe('2');
        const monthHeader = page?.root?.shadowRoot?.querySelector('h2[part="ndp__month-header"]');
        expect(monthHeader.textContent).toBe('March 2037');
    });
    it('display the correct dates and timeslots based on the selected timezone', async () => {
        const selectedDate = new Date(2025, 0, 4, 10, 0);
        const selectableDates = [
            new Date(2025, 0, 4, 10, 0),
            new Date(2025, 0, 5, 14, 0),
            new Date(2025, 0, 6, 23, 0),
            new Date(2025, 0, 8, 18, 0),
        ];
        const originalResolvedOptions = Intl.DateTimeFormat.prototype.resolvedOptions;
        Intl.DateTimeFormat.prototype.resolvedOptions = jest.fn().mockReturnValue({
            ...originalResolvedOptions.call(new Intl.DateTimeFormat()),
            timeZone: 'Asia/Tokyo',
        });
        const page = await newSpecPage({
            components: [NylasDatePicker],
            template: () => {
                return (h("nylas-date-picker", { themeConfig: {
                        '--nylas-primary': '#000000',
                    }, selectedTimezone: "Asia/Tokyo", selectedDate: selectedDate }));
            },
        });
        if (!page.root) {
            throw new Error('Component did not render.');
        }
        page.root.selectableDates = selectableDates;
        page.root.selectedTimezone = 'Asia/Tokyo';
        await page.waitForChanges();
        expect(page.root).toMatchSnapshot();
        const jan6ButtonInTokyo = Array.from(page?.root?.shadowRoot?.querySelectorAll('button.date.current-month') || []).find(btn => btn.textContent === '6');
        expect(jan6ButtonInTokyo).not.toBeNull();
        expect(jan6ButtonInTokyo).toHaveAttribute('disabled');
        page.root.selectedTimezone = 'America/Toronto';
        await page.waitForChanges();
        expect(page.root).toMatchSnapshot();
        const jan6ButtonInToronto = Array.from(page?.root?.shadowRoot?.querySelectorAll('button.date.current-month') || []).find(btn => btn.textContent === '6');
        expect(jan6ButtonInToronto).not.toBeNull();
        expect(jan6ButtonInToronto).not.toHaveAttribute('disabled');
        Intl.DateTimeFormat.prototype.resolvedOptions = originalResolvedOptions;
    });
});
//# sourceMappingURL=nylas-date-picker.spec.js.map
