import { dataResponse, getCalendarRange } from "../../../utils/utils";
import { isNylasErrorResponse, } from "@nylas/core";
import dayjs from "dayjs";
import utc from "dayjs/plugin/utc";
import timezone from "dayjs/plugin/timezone";
dayjs.extend(utc);
dayjs.extend(timezone);
export class NylasSchedulerConfigAPIConnector {
    constructor({ nylasApiRequest, nylasSchedulerConfigStore }) {
        this.groupEventsCache = new Map();
        this.CACHE_DURATION = 1 * 60 * 1000;
        this.nylasApiRequest = nylasApiRequest;
        this.nylasSchedulerConfigStore = nylasSchedulerConfigStore;
    }
    async currentUser() {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return null;
        }
        return this.nylasApiRequest.currentUser();
    }
    async getCalendars() {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error fetching calendars: Nylas API Request is not initialized',
            });
        }
        const allCalendars = [];
        let cursor = null;
        const limit = 50;
        do {
            const [response, error] = await this.nylasApiRequest.request({
                method: 'GET',
                path: `calendars?limit=${limit}${cursor ? `&page_token=${cursor}` : ''}`,
            });
            if (error) {
                return dataResponse(null, {
                    message: 'Error fetching calendars: ' + error.message,
                });
            }
            if (isNylasErrorResponse(response)) {
                return dataResponse(null, {
                    message: 'Error fetching calendars: ' + response.error?.message,
                });
            }
            allCalendars.push(...response.data);
            cursor = response.next_cursor || null;
        } while (cursor);
        this.nylasSchedulerConfigStore.state.calendars = allCalendars;
        return dataResponse(allCalendars);
    }
    async getConfigurationById(configurationId, forceFetch = false) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error fetching configuration: Nylas API Request is not initialized',
            });
        }
        if (!forceFetch) {
            const existingConfig = this.nylasSchedulerConfigStore.state.configurations.find(c => c.id === configurationId);
            if (existingConfig) {
                this.nylasSchedulerConfigStore.state.selectedConfiguration = existingConfig;
                return dataResponse(existingConfig);
            }
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `scheduling/configurations/${configurationId}`,
        });
        if (error) {
            return dataResponse(null, {
                message: 'Error fetching configuration: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            return dataResponse(null, {
                message: 'Error fetching configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedConfiguration = response.data;
        if (this.nylasSchedulerConfigStore.state.configurations.find(c => c.id === configurationId)) {
            this.nylasSchedulerConfigStore.state.configurations = this.nylasSchedulerConfigStore.state.configurations.map(c => (c.id === configurationId ? response.data : c));
        }
        else {
            this.nylasSchedulerConfigStore.state.configurations = [...this.nylasSchedulerConfigStore.state.configurations, response.data];
        }
        return dataResponse(response.data);
    }
    async getConfigurations(cursor) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error fetching configurations: Nylas API Request is not initialized',
            });
        }
        const limit = 50;
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `scheduling/configurations?limit=${limit}${cursor ? `&page_token=${cursor}` : ''}`,
        });
        if (error) {
            return dataResponse(null, {
                message: 'Error fetching configurations: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            return dataResponse(null, {
                message: 'Error fetching configurations: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.configurations = response.data;
        this.nylasSchedulerConfigStore.state.listConfigurationsNextCursor = response.next_cursor || null;
        return dataResponse(response.data);
    }
    async getMasterEventById(masterEventId) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error fetching master event: Nylas API Request is not initialized',
            });
        }
        const selectedGroupEvent = this.nylasSchedulerConfigStore.state.selectedGroupEvent;
        const calendar_id = selectedGroupEvent?.event?.calendar_id;
        if (!calendar_id) {
            console.warn('Calendar ID is not present');
            return dataResponse(null, {
                message: 'Error fetching master event: Calendar ID is not present',
            });
        }
        const queryParamsObject = new URLSearchParams();
        queryParamsObject.append('calendar_id', calendar_id);
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `events/${masterEventId}?${queryParamsObject.toString()}`,
        });
        if (error) {
            return dataResponse(null, {
                message: 'Error fetching master event: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            return dataResponse(null, {
                message: 'Error fetching master event: ' + response.error?.message,
            });
        }
        const masterGroupEvents = this.nylasSchedulerConfigStore.state.masterGroupEvents;
        if (masterGroupEvents[masterEventId]) {
            this.nylasSchedulerConfigStore.state.masterGroupEvents[masterEventId] = response.data;
        }
        else {
            this.nylasSchedulerConfigStore.state.masterGroupEvents = { ...masterGroupEvents, [masterEventId]: response.data };
        }
        return dataResponse(response.data);
    }
    async createConfiguration(configuration) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error creating configuration: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'POST',
            path: `scheduling/configurations`,
            body: configuration,
        });
        if (error) {
            return dataResponse(null, {
                message: 'Error creating configuration: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            return dataResponse(null, {
                message: 'Error creating configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedConfiguration = response.data;
        this.nylasSchedulerConfigStore.state.configurations = [...this.nylasSchedulerConfigStore.state.configurations, response.data];
        return dataResponse(response.data);
    }
    async updateConfiguration(configuration) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error updating configuration: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'PUT',
            path: `scheduling/configurations/${configuration.id}`,
            body: configuration,
        });
        if (error) {
            return dataResponse(null, {
                message: 'Error updating configuration: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            return dataResponse(null, {
                message: 'Error updating configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedConfiguration = response.data;
        if (this.nylasSchedulerConfigStore.state.configurations.find(c => c.id === configuration.id)) {
            this.nylasSchedulerConfigStore.state.configurations = this.nylasSchedulerConfigStore.state.configurations.map(c => (c.id === configuration.id ? response.data : c));
        }
        else {
            this.nylasSchedulerConfigStore.state.configurations = [...this.nylasSchedulerConfigStore.state.configurations, response.data];
        }
        return dataResponse(response.data);
    }
    async deleteConfiguration(configurationId) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error deleting configuration: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'DELETE',
            path: `scheduling/configurations/${configurationId}`,
        });
        if (error) {
            return dataResponse(null, {
                message: 'Error deleting configuration: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            return dataResponse(null, {
                message: 'Error deleting configuration: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.configurations = this.nylasSchedulerConfigStore.state.configurations.filter(c => c.id !== configurationId);
        if (this.nylasSchedulerConfigStore.state.selectedConfiguration?.id === configurationId) {
            this.nylasSchedulerConfigStore.resetSelectedConfiguration();
        }
        return dataResponse(response.data);
    }
    async createGroupEvent(eventDetails, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error creating group event: Nylas API Request is not initialized',
            });
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'POST',
            path: `scheduling/configurations/${configurationId}/group-events`,
            body: eventDetails,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error creating group event: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error creating group event: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedGroupEvent = response.data;
        await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return dataResponse(response.data);
    }
    async getGroupEvents(configurationId, selectedConfiguration) {
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error fetching group events: Nylas API Request is not initialized',
            });
        }
        const queryParamsObject = new URLSearchParams();
        queryParamsObject.append('show_all', 'true');
        const calendarViewDateRange = this.nylasSchedulerConfigStore.state.calendarViewDateRange;
        let startTime;
        let endTime;
        if (calendarViewDateRange) {
            startTime = calendarViewDateRange.start_time;
            endTime = calendarViewDateRange.end_time;
        }
        else {
            const range = getCalendarRange(new Date().toISOString(), 'week');
            startTime = range.startTime.toString();
            endTime = range.endTime.toString();
        }
        const cacheKey = `${configurationId}-${startTime}-${endTime}`;
        const cachedData = this.groupEventsCache.get(cacheKey);
        if (cachedData && Date.now() - cachedData.timestamp < this.CACHE_DURATION) {
            this.nylasSchedulerConfigStore.state.groupEvents = cachedData.data;
            return dataResponse(cachedData.data);
        }
        queryParamsObject.append('start_time', startTime);
        queryParamsObject.append('end_time', endTime);
        const calendar_id = selectedConfiguration?.group_booking?.calendar_id;
        if (calendar_id) {
            queryParamsObject.append('calendar_id', calendar_id);
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'GET',
            path: `scheduling/configurations/${configurationId}/group-events?${queryParamsObject.toString()}`,
        });
        if (error) {
            return dataResponse(null, {
                message: 'Error fetching group events: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            return dataResponse(null, {
                message: 'Error fetching group events: ' + response.error?.message,
            });
        }
        this.groupEventsCache.set(cacheKey, {
            data: response.data,
            timestamp: Date.now(),
        });
        this.cleanupExpiredCache();
        this.nylasSchedulerConfigStore.state.groupEvents = response.data;
        return dataResponse(response.data);
    }
    cleanupExpiredCache() {
        const now = Date.now();
        for (const [key, value] of this.groupEventsCache.entries()) {
            if (now - value.timestamp > this.CACHE_DURATION) {
                this.groupEventsCache.delete(key);
            }
        }
    }
    async updateGroupEventById(groupEventDetails, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error updating group event: Nylas API Request is not initialized',
            });
        }
        const groupEventId = groupEventDetails.id;
        delete groupEventDetails.id;
        const [response, error] = await this.nylasApiRequest.request({
            method: 'PATCH',
            path: `scheduling/configurations/${configurationId}/group-events/${groupEventId}`,
            body: groupEventDetails,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error updating group event: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error updating group event: ' + response.error?.message,
            });
        }
        this.nylasSchedulerConfigStore.state.selectedGroupEvent = response.data;
        await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return dataResponse(response.data);
    }
    async updateGroupEvent(groupEventDetails, chosenOption, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        const selectedGroupEvent = this.nylasSchedulerConfigStore.state.selectedGroupEvent;
        const masterEventId = selectedGroupEvent?.event?.master_event_id;
        const selectedGroupEventId = selectedGroupEvent?.event?.id;
        const selectedGroupEventStartTime = selectedGroupEvent?.event?.when?.start_time;
        const rruleString = selectedGroupEvent?.group_event_info?.rrule?.[0];
        const rruleStringWithoutUntil = rruleString
            ? rruleString
                .split(';')
                .filter(s => !s.startsWith('UNTIL'))
                .join(';')
            : '';
        const until = selectedGroupEventStartTime
            ? dayjs(selectedGroupEventStartTime * 1000)
                .subtract(1, 'minute')
                .format('YYYYMMDDTHHmmss[Z]')
            : '';
        if (chosenOption === 'this') {
            return this.updateGroupEventById({
                ...groupEventDetails,
                id: selectedGroupEventId,
                recurrence: masterEventId ? undefined : groupEventDetails.recurrence,
            }, configurationId);
        }
        else if (chosenOption === 'future' && masterEventId) {
            const newRecurrenceEvent = await this.createGroupEvent(groupEventDetails, configurationId);
            const updatedMasterEvent = {
                location: selectedGroupEvent?.event?.location,
                conferencing: selectedGroupEvent?.event?.conferencing,
                title: selectedGroupEvent?.event?.title,
                description: selectedGroupEvent?.event?.description,
                capacity: selectedGroupEvent?.group_event_info?.capacity,
                calendar_id: selectedGroupEvent?.event?.calendar_id,
                recurrence: rruleStringWithoutUntil ? [rruleStringWithoutUntil + ';UNTIL=' + until] : [`RRULE:FREQ=DAILY;UNTIL=${until}`],
            };
            await this.updateGroupEventById({
                ...updatedMasterEvent,
                id: masterEventId,
            }, configurationId);
            return [updatedMasterEvent, newRecurrenceEvent];
        }
        else if (chosenOption === 'all') {
            const groupEventDetailsWhen = groupEventDetails?.when;
            const selectedGroupEventWhen = selectedGroupEvent?.event?.when;
            const masterEvent = this.nylasSchedulerConfigStore.state.masterGroupEvents?.[masterEventId];
            let when = masterEvent?.when;
            if (groupEventDetailsWhen?.start_time !== selectedGroupEventWhen?.start_time) {
                when = {
                    ...when,
                    start_time: groupEventDetailsWhen?.start_time || when?.start_time,
                };
            }
            if (groupEventDetailsWhen?.end_time !== selectedGroupEventWhen?.end_time) {
                when = {
                    ...when,
                    end_time: groupEventDetailsWhen?.end_time || when?.end_time,
                };
            }
            if (groupEventDetailsWhen?.start_timezone !== selectedGroupEventWhen?.start_timezone) {
                when = {
                    ...when,
                    start_timezone: groupEventDetailsWhen?.start_timezone || when?.start_timezone,
                };
            }
            if (groupEventDetailsWhen?.end_timezone !== selectedGroupEventWhen?.end_timezone) {
                when = {
                    ...when,
                    end_timezone: groupEventDetailsWhen?.end_timezone || when?.end_timezone,
                };
            }
            return this.updateGroupEventById({
                ...groupEventDetails,
                when: when,
                id: masterEventId,
            }, configurationId);
        }
        this.nylasSchedulerConfigStore.state.isLoading = false;
        throw new Error('Invalid option');
    }
    async deleteGroupEvent(_groupEventDetails, chosenOption, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        const selectedGroupEvent = this.nylasSchedulerConfigStore.state.selectedGroupEvent;
        const masterEventId = selectedGroupEvent?.event?.master_event_id;
        const selectedGroupEventId = selectedGroupEvent?.event?.id;
        const selectedGroupEventStartTime = selectedGroupEvent?.event?.when?.start_time;
        const rruleString = selectedGroupEvent?.group_event_info?.rrule?.[0];
        const rruleStringWithoutUntil = rruleString
            ? rruleString
                .split(';')
                .filter(s => !s.startsWith('UNTIL'))
                .join(';')
            : '';
        const until = selectedGroupEventStartTime ? dayjs(selectedGroupEventStartTime * 1000).format('YYYYMMDDTHHmmss[Z]') : '';
        const updatedMasterEvent = {
            location: selectedGroupEvent?.event?.location,
            conferencing: selectedGroupEvent?.event?.conferencing,
            title: selectedGroupEvent?.event?.title,
            description: selectedGroupEvent?.event?.description,
            capacity: selectedGroupEvent?.group_event_info?.capacity,
            calendar_id: selectedGroupEvent?.event?.calendar_id,
            recurrence: rruleStringWithoutUntil ? [rruleStringWithoutUntil + ';UNTIL=' + until] : [`RRULE:UNTIL=${until}`],
        };
        if (chosenOption === 'this' && selectedGroupEventId) {
            return this.deleteGroupEventById(selectedGroupEventId, configurationId);
        }
        else if (chosenOption === 'future' && masterEventId && selectedGroupEventId) {
            await this.deleteGroupEventById(selectedGroupEventId, configurationId);
            return await this.updateGroupEventById({
                ...updatedMasterEvent,
                id: masterEventId,
            }, configurationId);
        }
        else if (chosenOption === 'all' && masterEventId) {
            return this.deleteGroupEventById(masterEventId, configurationId);
        }
        this.nylasSchedulerConfigStore.state.isLoading = false;
        throw new Error('Invalid option');
    }
    async deleteGroupEventById(groupEventId, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error deleting group event: Nylas API Request is not initialized',
            });
        }
        const queryParamsObject = new URLSearchParams();
        const calendar_id = this.nylasSchedulerConfigStore.state.selectedConfiguration?.group_booking?.calendar_id;
        if (calendar_id) {
            queryParamsObject.append('calendar_id', calendar_id);
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'DELETE',
            path: `scheduling/configurations/${configurationId}/group-events/${groupEventId}?calendar_id=${calendar_id}`,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error deleting group event: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error deleting group event: ' + response.error?.message,
            });
        }
        await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return dataResponse(response.data);
    }
    async importGroupEvent(groupEventDetails, configurationId) {
        this.nylasSchedulerConfigStore.state.isLoading = true;
        if (!this.nylasApiRequest) {
            console.warn('Nylas API Request is not initialized');
            return dataResponse(null, {
                message: 'Error importing group event: Nylas API Request is not initialized',
            });
        }
        const queryParamsObject = new URLSearchParams();
        const calendar_id = this.nylasSchedulerConfigStore.state.selectedConfiguration?.group_booking?.calendar_id;
        if (calendar_id) {
            queryParamsObject.append('calendar_id', calendar_id);
        }
        const [response, error] = await this.nylasApiRequest.request({
            method: 'POST',
            path: `scheduling/configurations/${configurationId}/import-group-events?${queryParamsObject.toString()}`,
            body: groupEventDetails,
        });
        if (error) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error importing group event: ' + error.message,
            });
        }
        if (isNylasErrorResponse(response)) {
            this.nylasSchedulerConfigStore.state.isLoading = false;
            return dataResponse(null, {
                message: 'Error importing group event: ' + response.error?.message,
            });
        }
        if (response.data?.imported_events?.length > 0) {
            await this.getGroupEvents(configurationId, this.nylasSchedulerConfigStore.state.selectedConfiguration);
        }
        this.nylasSchedulerConfigStore.state.isLoading = false;
        return dataResponse(response.data);
    }
}
//# sourceMappingURL=scheduler-config.js.map
